@@ -190,8 +190,8 @@ public:
           listeningToModifiers(false),
           angleSnapStrategy(0),
           angleSnappingDelta(15),
-          angleSnapStatus(false),
-          strokeWidget(0) {
+          angleSnapStatus(false)
+    {
     }
 
     KoPathShape *shape;
@@ -206,10 +206,11 @@ public:
     KoPathPoint *hoveredPoint; ///< an existing path end point the mouse is hovering on
     bool listeningToModifiers; //  Fine tune when to begin processing modifiers at the beginning of a stroke.
 
+    QPointF dragStartPoint;
+
     AngleSnapStrategy *angleSnapStrategy;
     int angleSnappingDelta;
     bool angleSnapStatus;
-    KoStrokeConfigWidget *strokeWidget;
 
     void repaintActivePoint() const {
         const bool isFirstPoint = (activePoint == firstPoint);
