@@ -30,6 +30,7 @@
 #include <QSize>
 #include <QPoint>
 #include <QPointF>
+#include <QPointer>
 
 class KActionCollection;
 class QRect;
@@ -78,7 +79,7 @@ public:
     };
 
     // proxy QObject: use this to connect to slots and signals.
-    KoCanvasControllerProxyObject *proxyObject;
+    QPointer<KoCanvasControllerProxyObject> proxyObject;
 
     /**
      * Constructor.
@@ -254,6 +255,26 @@ public:
      */
     virtual void pan(const QPoint &distance) = 0;
 
+    /**
+     * Move the canvas up. This behaves the same as \sa pan() with a positive y coordinate.
+     */
+    virtual void panUp() = 0;
+
+    /**
+     * Move the canvas down. This behaves the same as \sa pan() with a negative y coordinate.
+     */
+    virtual void panDown() = 0;
+
+    /**
+     * Move the canvas to the left. This behaves the same as \sa pan() with a positive x coordinate.
+     */
+    virtual void panLeft() = 0;
+
+    /**
+     * Move the canvas to the right. This behaves the same as \sa pan() with a negative x coordinate.
+     */
+    virtual void panRight() = 0;
+
     /**
      * Get the position of the scrollbar
      */
@@ -299,6 +320,12 @@ public:
 
     QPoint documentOffset() const;
 
+    /**
+     * @return the current position of the cursor fetched from QCursor::pos() and
+     *         converted into document coordinates
+     */
+    virtual QPointF currentCursorPosition() const = 0;
+
 protected:
     void setDocumentSize(const QSize &sz);
     QSize documentSize() const;
@@ -460,11 +487,16 @@ public:
     void setPreferredCenter(const QPointF &/*viewPoint*/) override {}
     QPointF preferredCenter() const override {return QPointF();}
     void pan(const QPoint &/*distance*/) override {}
+    void panUp() override {}
+    void panDown() override {}
+    void panLeft() override {}
+    void panRight() override {}
     QPoint scrollBarValue() const override {return QPoint();}
     void setScrollBarValue(const QPoint &/*value*/) override {}
     void updateDocumentSize(const QSize &/*sz*/, bool /*recalculateCenter*/) override {}
     void setZoomWithWheel(bool /*zoom*/) override {}
     void setVastScrolling(qreal /*factor*/) override {}
+    QPointF currentCursorPosition() const override { return QPointF(); }
 
 };
 
