@@ -144,10 +144,12 @@ void KoCanvasControllerWidget::Private::activate()
     if (!observerProvider) {
         return;
     }
+
+    KoCanvasBase *canvas = q->canvas();
     Q_FOREACH (KoCanvasObserverBase *docker, observerProvider->canvasObservers()) {
         KoCanvasObserverBase *observer = dynamic_cast<KoCanvasObserverBase*>(docker);
         if (observer) {
-            observer->setObservedCanvas(q->canvas());
+            observer->setObservedCanvas(canvas);
         }
     }
 
@@ -165,8 +167,10 @@ void KoCanvasControllerWidget::Private::unsetCanvas()
     }
     Q_FOREACH (KoCanvasObserverBase *docker, observerProvider->canvasObservers()) {
         KoCanvasObserverBase *observer = dynamic_cast<KoCanvasObserverBase*>(docker);
-        if (observer && observer->observedCanvas() == q->canvas()) {
-            observer->unsetObservedCanvas();
+       if (observer) {
+            if (observer->observedCanvas() == q->canvas()) {
+                observer->unsetObservedCanvas();
+            }
         }
     }
 }
@@ -177,7 +181,7 @@ KoCanvasControllerWidget::KoCanvasControllerWidget(KActionCollection * actionCol
     , KoCanvasController(actionCollection)
     , d(new Private(this))
 {
-    // We need to set this as QDeclarativeView sets them a bit differnt from QAbstractScrollArea
+    // We need to set this as QDeclarativeView sets them a bit different from QAbstractScrollArea
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
     // And then our own Viewport
@@ -193,7 +197,7 @@ KoCanvasControllerWidget::KoCanvasControllerWidget(KActionCollection * actionCol
       Fixes:   apps starting at zero zoom.
       Details: Since the document is set on the mainwindow before loading commences the inial show/layout can choose
           to set the document to be very small, even to be zero pixels tall.  Setting a sane minimum size on the
-          widget means we no loger get rounding errors in zooming and we no longer end up with zero-zoom.
+          widget means we no longer get rounding errors in zooming and we no longer end up with zero-zoom.
       Note: KoPage apps should probably startup with a sane document size; for Krita that's impossible
      */
     setMinimumSize(QSize(50, 50));
@@ -207,7 +211,6 @@ KoCanvasControllerWidget::KoCanvasControllerWidget(KActionCollection * actionCol
 
 KoCanvasControllerWidget::~KoCanvasControllerWidget()
 {
-    d->unsetCanvas();
     delete d;
 }
 
@@ -245,27 +248,30 @@ void KoCanvasControllerWidget::resizeEvent(QResizeEvent *resizeEvent)
 
 void KoCanvasControllerWidget::setCanvas(KoCanvasBase *canvas)
 {
-    Q_ASSERT(canvas); // param is not null
     if (d->canvas) {
         d->unsetCanvas();
         proxyObject->emitCanvasRemoved(this);
-        canvas->setCanvasController(0);
+        d->canvas->setCanvasController(0);
         d->canvas->canvasWidget()->removeEventFilter(this);
     }
-    canvas->setCanvasController(this);
+
     d->canvas = canvas;
 
-    changeCanvasWidget(canvas->canvasWidget());
+    if (d->canvas) {
+        d->canvas->setCanvasController(this);
+        changeCanvasWidget(d->canvas->canvasWidget());
 
-    proxyObject->emitCanvasSet(this);
-    QTimer::singleShot(0, this, SLOT(activate()));
+        proxyObject->emitCanvasSet(this);
+        QTimer::singleShot(0, this, SLOT(activate()));
 
-    setPreferredCenterFractionX(0);
-    setPreferredCenterFractionY(0);
+        setPreferredCenterFractionX(0);
+        setPreferredCenterFractionY(0);
+    }
 }
 
 KoCanvasBase* KoCanvasControllerWidget::canvas() const
 {
+    if (d->canvas.isNull()) return 0;
     return d->canvas;
 }
 
@@ -480,12 +486,39 @@ void KoCanvasControllerWidget::setVastScrolling(qreal factor)
     d->vastScrollingFactor = factor;
 }
 
+QPointF KoCanvasControllerWidget::currentCursorPosition() const
+{
+    QWidget *canvasWidget = d->canvas->canvasWidget();
+    const KoViewConverter *converter = d->canvas->viewConverter();
+    return converter->viewToDocument(canvasWidget->mapFromGlobal(QCursor::pos()) + d->canvas->canvasController()->documentOffset() - canvasWidget->pos());
+}
+
 void KoCanvasControllerWidget::pan(const QPoint &distance)
 {
     QPoint sourcePoint = scrollBarValue();
     setScrollBarValue(sourcePoint + distance);
 }
 
+void KoCanvasControllerWidget::panUp()
+{
+    pan(QPoint(0, verticalScrollBar()->singleStep()));
+}
+
+void KoCanvasControllerWidget::panDown()
+{
+    pan(QPoint(0, -verticalScrollBar()->singleStep()));
+}
+
+void KoCanvasControllerWidget::panLeft()
+{
+    pan(QPoint(horizontalScrollBar()->singleStep(), 0));
+}
+
+void KoCanvasControllerWidget::panRight()
+{
+    pan(QPoint(-horizontalScrollBar()->singleStep(), 0));
+}
+
 void KoCanvasControllerWidget::setPreferredCenter(const QPointF &viewPoint)
 {
     setPreferredCenterFractionX(viewPoint.x() / documentSize().width());
@@ -527,11 +560,6 @@ void KoCanvasControllerWidget::dragLeaveEvent(QDragLeaveEvent *event)
     d->viewportWidget->handleDragLeaveEvent(event);
 }
 
-void KoCanvasControllerWidget::keyPressEvent(QKeyEvent *event)
-{
-    KoToolManager::instance()->priv()->switchToolByShortcut(event);
-}
-
 void KoCanvasControllerWidget::wheelEvent(QWheelEvent *event)
 {
     if (d->zoomWithWheel != ((event->modifiers() & Qt::ControlModifier) == Qt::ControlModifier)) {
