@@ -21,6 +21,8 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include <limits>
+
 #include "KoShape.h"
 #include "KoShape_p.h"
 #include "KoShapeContainer.h"
@@ -159,14 +161,25 @@ KoShapePrivate::KoShapePrivate(const KoShapePrivate &rhs, KoShape *q)
 KoShapePrivate::~KoShapePrivate()
 {
     Q_Q(KoShape);
-    if (parent) {
+
+    /**
+     * The shape must have already been detached from all the parents and
+     * shape managers. Otherwise we migh accidentally request some RTTI
+     * information, which is not available anymore (we are in d-tor).
+     *
+     * TL;DR: fix the code that caused this destruction without unparenting
+     *        instead of trying to remove these assert!
+     */
+    KIS_SAFE_ASSERT_RECOVER (!parent) {
         parent->removeShape(q);
     }
 
-    Q_FOREACH (KoShapeManager *manager, shapeManagers) {
-        manager->shapeInterface()->notifyShapeDestructed(q);
+    KIS_SAFE_ASSERT_RECOVER (shapeManagers.isEmpty()) {
+        Q_FOREACH (KoShapeManager *manager, shapeManagers) {
+            manager->shapeInterface()->notifyShapeDestructed(q);
+        }
+        shapeManagers.clear();
     }
-    shapeManagers.clear();
 
     if (shadow && !shadow->deref())
         delete shadow;
@@ -291,6 +304,10 @@ QString KoShapePrivate::getStyleProperty(const char *property, KoShapeLoadingCon
 
 
 // ======== KoShape
+
+const qint16 KoShape::maxZIndex = std::numeric_limits<qint16>::max();
+const qint16 KoShape::minZIndex = std::numeric_limits<qint16>::min();
+
 KoShape::KoShape()
     : d_ptr(new KoShapePrivate(this))
 {
@@ -404,7 +421,8 @@ bool KoShape::hitTest(const QPointF &position) const
         return false;
 
     QPointF point = absoluteTransformation(0).inverted().map(position);
-    QRectF bb(QPointF(), size());
+    QRectF bb = outlineRect();
+
     if (d->stroke) {
         KoInsets insets;
         d->stroke->strokeInsets(this, insets);
@@ -679,7 +697,26 @@ bool KoShape::inheritsTransformFromAny(const QList<KoShape *> ancestorsInQuestio
     return result;
 }
 
-int KoShape::zIndex() const
+bool KoShape::hasCommonParent(const KoShape *shape) const
+{
+    const KoShape *thisShape = this;
+    while (thisShape) {
+
+        const KoShape *otherShape = shape;
+        while (otherShape) {
+            if (thisShape == otherShape) {
+                return true;
+            }
+            otherShape = otherShape->parent();
+        }
+
+        thisShape = thisShape->parent();
+    }
+
+    return false;
+}
+
+qint16 KoShape::zIndex() const
 {
     Q_D(const KoShape);
     return d->zIndex;
@@ -772,7 +809,7 @@ void KoShape::copySettings(const KoShape *shape)
     Q_FOREACH (const KoConnectionPoint &point, shape->connectionPoints())
         addConnectionPoint(point);
     d->zIndex = shape->zIndex();
-    d->visible = shape->isVisible();
+    d->visible = shape->isVisible(false);
 
     // Ensure printable is true by default
     if (!d->visible)
@@ -1112,7 +1149,7 @@ bool KoShape::inheritBackground() const
     return d->inheritBackground;
 }
 
-void KoShape::setZIndex(int zIndex)
+void KoShape::setZIndex(qint16 zIndex)
 {
     Q_D(KoShape);
     if (d->zIndex == zIndex)
@@ -1150,11 +1187,11 @@ bool KoShape::isVisible(bool recursive) const
         return false;
 
     KoShapeContainer * parentShape = parent();
-    while (parentShape) {
-        if (! parentShape->isVisible())
-            return false;
-        parentShape = parentShape->parent();
+
+    if (parentShape) {
+        return parentShape->isVisible(true);
     }
+
     return true;
 }
 
@@ -1382,14 +1419,15 @@ void KoShape::waitUntilReady(const KoViewConverter &converter, bool asynchronous
     Q_UNUSED(asynchronous);
 }
 
-bool KoShape::isEditable() const
+bool KoShape::isShapeEditable(bool recursive) const
 {
     Q_D(const KoShape);
     if (!d->visible || d->geometryProtected)
         return false;
 
-    if (d->parent && d->parent->isChildLocked(this))
-        return false;
+    if (recursive && d->parent) {
+        return d->parent->isShapeEditable(true);
+    }
 
     return true;
 }
