@@ -581,7 +581,7 @@ public:
      * @return the z-index of this shape.
      * @see setZIndex()
      */
-    int zIndex() const;
+    qint16 zIndex() const;
 
     /**
      * Set the z-coordinate of this shape.
@@ -594,7 +594,17 @@ public:
      * and probably depends on the order in which they are added to the shape manager.
      * @param zIndex the new z-index;
      */
-    void setZIndex(int zIndex);
+    void setZIndex(qint16 zIndex);
+
+    /**
+     * Maximum value of z-index
+     */
+    static const qint16 maxZIndex;
+
+    /**
+     * Minimum value of z-index
+     */
+    static const qint16 minZIndex;
 
     /**
      * Retrieve the run through property of this shape.
@@ -626,7 +636,7 @@ public:
      * @return current visibility state of this shape.
      * @see isGeometryProtected(), isContentProtected(), isSelectable()
      */
-    bool isVisible(bool recursive = false) const;
+    bool isVisible(bool recursive = true) const;
 
     /**
      * Changes the shape to be printable or not. The default is true.
@@ -717,6 +727,11 @@ public:
      */
     bool inheritsTransformFromAny(const QList<KoShape*> ancestorsInQuestion) const;
 
+    /**
+     * @return true if this shape has a common parent with \p shape
+     */
+    bool hasCommonParent(const KoShape *shape) const;
+
     /**
      * Request a repaint to be queued.
      * The repaint will be of the entire Shape, including its selection handles should this
@@ -1039,7 +1054,7 @@ public:
     virtual void waitUntilReady(const KoViewConverter &converter, bool asynchronous = true) const;
 
     /// checks recursively if the shape or one of its parents is not visible or locked
-    bool isEditable() const;
+    virtual bool isShapeEditable(bool recursive = true) const;
 
     /**
      * Adds a shape which depends on this shape.
