@@ -183,14 +183,6 @@ public:
     /// @return the active canvas controller
     KoCanvasController *activeCanvasController() const;
 
-    /**
-     * Connect all the tools for the given canvas to the new shape controller.
-     *
-     * @param shapecontroller the new shape controller
-     * @param canvasController the canvas
-     */
-    void updateShapeControllerBase(KoShapeBasedDocumentBase *shapeController, KoCanvasController *canvasController);
-
     /**
      * Return the tool that is able to create shapes for this param canvas.
      * This is typically used by the KoShapeSelector to set which shape to create next.
@@ -201,7 +193,7 @@ public:
     KoCreateShapesTool *shapeCreatorTool(KoCanvasBase *canvas) const;
 
     /**
-     * Returns the tool for the given tool id.
+     * Returns the tool for the given tool id. The tool may be 0
      * @param canvas the canvas that is a child of a previously registered controller
      *    who's tool you want.
      * @see addController()
@@ -212,7 +204,7 @@ public:
     KoInputDevice currentInputDevice() const;
 
     /**
-     * For the list of shapes find out which tool is the highest priorty tool that can handle it.
+     * For the list of shapes find out which tool is the highest priority tool that can handle it.
      * @returns the toolId for the shapes.
      * @param shapes a list of shapes, a selection for example, that is used to look for the tool.
      */
@@ -230,9 +222,6 @@ public:
     /// Request tool activation for the given canvas controller
     void requestToolActivation(KoCanvasController *controller);
 
-    /// Injects an input event from a plugin based input device
-    void injectDeviceEvent(KoInputDeviceHandlerEvent *event);
-
     /// Returns the toolId of the currently active tool
     QString activeToolId() const;
 
@@ -257,11 +246,6 @@ public Q_SLOTS:
      */
     void switchInputDeviceRequested(const KoInputDevice &id);
 
-    /**
-     * a new tool has become known to mankind
-     */
-    void addDeferredToolFactory(KoToolFactoryBase *toolFactory);
-
     /**
      * Request for temporary switching the tools.
      * This switch can be later reverted with switchBackRequested().
