@@ -95,8 +95,10 @@ void KoToolProxyPrivate::checkAutoScroll(const KoPointerEvent &event)
     if (!activeTool) return;
     if (!activeTool->wantsAutoScroll()) return;
     if (!event.isAccepted()) return;
+    if (!isToolPressed) return;
     if (event.buttons() != Qt::LeftButton) return;
 
+
     widgetScrollPoint = event.pos();
 
     if (! scrollTimer.isActive())
@@ -118,7 +120,7 @@ bool KoToolProxyPrivate::isActiveLayerEditable()
 
     KoShapeManager * shapeManager = activeTool->canvas()->shapeManager();
     KoShapeLayer * activeLayer = shapeManager->selection()->activeLayer();
-    if (activeLayer && !activeLayer->isEditable())
+    if (activeLayer && !activeLayer->isShapeEditable())
         return false;
     return true;
 }
@@ -205,8 +207,22 @@ void KoToolProxy::mousePressEvent(KoPointerEvent *ev)
     KoToolManager::instance()->priv()->switchInputDevice(id);
     d->mouseDownPoint = ev->pos();
 
-    if (d->tabletPressed) // refuse to send a press unless there was a release first.
+
+    // this tries to make sure another mouse press event doesn't happen
+    // before a release event happens
+    if (d->isToolPressed) {
+        mouseReleaseEvent(ev);
+        d->tabletPressed = false;
+        d->scrollTimer.stop();
+
+        if (d->activeTool) {
+            d->activeTool->mouseReleaseEvent(ev);
+        }
+
+        d->isToolPressed = false;
+
         return;
+    }
 
     QPointF globalPoint = ev->globalPos();
     if (d->multiClickGlobalPoint != globalPoint) {
@@ -243,6 +259,8 @@ void KoToolProxy::mousePressEvent(KoPointerEvent *ev)
         d->multiClickCount = 0;
         ev->ignore();
     }
+
+    d->isToolPressed = true;
 }
 
 void KoToolProxy::mousePressEvent(QMouseEvent *event, const QPointF &point)
@@ -305,6 +323,8 @@ void KoToolProxy::mouseReleaseEvent(KoPointerEvent* event)
     } else {
         event->ignore();
     }
+
+    d->isToolPressed = false;
 }
 
 void KoToolProxy::keyPressEvent(QKeyEvent *event)
@@ -321,6 +341,8 @@ void KoToolProxy::keyReleaseEvent(QKeyEvent *event)
         d->activeTool->keyReleaseEvent(event);
     else
         event->ignore();
+
+    d->isToolPressed = false;
 }
 
 void KoToolProxy::explicitUserStrokeEndRequest()
@@ -389,61 +411,11 @@ void KoToolProxy::copy() const
 bool KoToolProxy::paste()
 {
     bool success = false;
-    KoCanvasBase *canvas = d->controller->canvas();
 
     if (d->activeTool && d->isActiveLayerEditable()) {
         success = d->activeTool->paste();
     }
 
-    if (!success) {
-        const QMimeData *data = QApplication::clipboard()->mimeData();
-
-        QList<QImage> imageList;
-
-        QImage image = QApplication::clipboard()->image();
-
-        if (!image.isNull()) {
-            imageList << image;
-        }
-        else if (data->hasUrls()) {
-            QList<QUrl> urls = QApplication::clipboard()->mimeData()->urls();
-            foreach (const QUrl &url, urls) {
-                QImage image;
-                image.load(url.toLocalFile());
-                if (!image.isNull()) {
-                    imageList << image;
-                }
-            }
-        }
-
-        KoShapeFactoryBase *factory = KoShapeRegistry::instance()->value("PictureShape");
-        QWidget *canvasWidget = canvas->canvasWidget();
-        const KoViewConverter *converter = canvas->viewConverter();
-        if (imageList.length() > 0 && factory && canvasWidget) {
-            KUndo2Command *cmd = new KUndo2Command(kundo2_i18n("Paste Image"));
-            QList<KoShape*> pastedShapes;
-
-            Q_FOREACH (const QImage &image, imageList) {
-                if (!image.isNull()) {
-                    QPointF p = converter->viewToDocument(canvasWidget->mapFromGlobal(QCursor::pos()) + canvas->canvasController()->documentOffset()- canvasWidget->pos());
-                    KoProperties params;
-                    params.setProperty("qimage", image);
-
-                    KoShape *shape = factory->createShape(&params, canvas->shapeController()->resourceManager());
-                    shape->setPosition(p);
-                    pastedShapes << shape;
-
-                    success = true;
-                }
-            }
-
-            if (!pastedShapes.isEmpty()) {
-                // add shape to the document
-                canvas->shapeController()->addShapesDirect(pastedShapes, 0, cmd);
-                canvas->addCommand(cmd);
-            }
-        }
-    }
     return success;
 }
 
