@@ -27,6 +27,7 @@
 
 class KoShapeBasedDocumentBase;
 class KoPathShape;
+class KoPathPointData;
 
 /// The undo / redo command for combining two or more paths into one
 class KRITAFLAKE_EXPORT KoPathCombineCommand : public KUndo2Command
@@ -45,6 +46,9 @@ public:
     /// revert the actions done in redo
     void undo() override;
 
+    KoPathShape *combinedPath() const;
+    KoPathPointData originalToCombined(KoPathPointData pd) const;
+
 private:
     class Private;
     Private * const d;
