@@ -22,6 +22,7 @@
 
 #include "kritaflake_export.h"
 
+#include <boost/operators.hpp>
 #include <kundo2command.h>
 #include <QList>
 
@@ -32,6 +33,18 @@ class KoShapeReorderCommandPrivate;
 /// This command allows you to change the zIndex of a number of shapes.
 class KRITAFLAKE_EXPORT KoShapeReorderCommand : public KUndo2Command
 {
+public:
+    struct KRITAFLAKE_EXPORT IndexedShape : boost::less_than_comparable<IndexedShape> {
+        IndexedShape();
+        IndexedShape(KoShape *_shape);
+
+        bool operator<(const IndexedShape &rhs) const;
+
+        int zIndex = 0;
+        KoShape *shape = 0;
+    };
+
+
 public:
     /**
      * Constructor.
@@ -41,6 +54,7 @@ public:
      * @param parent the parent command used for macro commands
      */
     KoShapeReorderCommand(const QList<KoShape*> &shapes, QList<int> &newIndexes, KUndo2Command *parent = 0);
+    KoShapeReorderCommand(const QList<IndexedShape> &shapes, KUndo2Command *parent = 0);
     ~KoShapeReorderCommand() override;
 
     /// An enum for defining what kind of reordering to use.
@@ -77,6 +91,31 @@ public:
     static KoShapeReorderCommand *mergeInShape(QList<KoShape*> shapes, KoShape *newShape,
                                                KUndo2Command *parent = 0);
 
+    /**
+     * Recalculates the attached z-indexes of \p shapes so that all indexes go
+     * strictly in ascending order and no shapes have repetitive indexes. The
+     * physical order of the shapes in the array is not changed, on the indexes
+     * in IndexedShape are corrected.
+     */
+    static
+    QList<KoShapeReorderCommand::IndexedShape>
+    homogenizeZIndexes(QList<IndexedShape> shapes);
+
+    /**
+     * Convenience version of homogenizeZIndexes() that removes all the IndexedShape
+     * objects, which z-index didn't change during homogenization. In a result
+     * you get a list that can be passed to KoShapeReorderCommand directly.
+     */
+    static
+    QList<KoShapeReorderCommand::IndexedShape>
+    homogenizeZIndexesLazy(QList<IndexedShape> shapes);
+
+    /**
+     * Put all the shapes in \p shapesAbove above the shapes in \p shapesBelow, adjusting their
+     * z-index values.
+     */
+    static QList<IndexedShape> mergeDownShapes(QList<KoShape*> shapesBelow, QList<KoShape*> shapesAbove);
+
     /// redo the command
     void redo() override;
     /// revert the actions done in redo
@@ -86,4 +125,6 @@ private:
     KoShapeReorderCommandPrivate * const d;
 };
 
+KRITAFLAKE_EXPORT QDebug operator<<(QDebug dbg, const KoShapeReorderCommand::IndexedShape &indexedShape);
+
 #endif
