@@ -77,7 +77,7 @@ void SvgStyleWriter::saveSvgStyle(KoShape *shape, SvgSavingContext &context)
 
 void SvgStyleWriter::saveSvgBasicStyle(KoShape *shape, SvgSavingContext &context)
 {
-    if (! shape->isVisible()) {
+    if (! shape->isVisible(false)) {
         context.shapeWriter().addAttribute("display", "none");
     } if (shape->transparency() > 0.0) {
         context.shapeWriter().addAttribute("opacity", 1.0 - shape->transparency());
