@@ -34,12 +34,12 @@ void TestShapePainting::testPaintShape()
 {
     MockShape *shape1 = new MockShape();
     MockShape *shape2 = new MockShape();
-    MockContainer *container = new MockContainer();
+    QScopedPointer<MockContainer> container(new MockContainer());
 
     container->addShape(shape1);
     container->addShape(shape2);
-    QCOMPARE(shape1->parent(), container);
-    QCOMPARE(shape2->parent(), container);
+    QCOMPARE(shape1->parent(), container.data());
+    QCOMPARE(shape2->parent(), container.data());
     container->setClipped(shape1, false);
     container->setClipped(shape2, false);
     QCOMPARE(container->isClipped(shape1), false);
@@ -47,7 +47,7 @@ void TestShapePainting::testPaintShape()
 
     MockCanvas canvas;
     KoShapeManager manager(&canvas);
-    manager.addShape(container);
+    manager.addShape(container.data());
     QCOMPARE(manager.shapes().count(), 3);
 
     QImage image(100, 100,  QImage::Format_Mono);
@@ -87,17 +87,17 @@ void TestShapePainting::testPaintShape()
     // with this shape being clipped, the container will paint it for us.
     QCOMPARE(shape2->paintedCount, 1);
     QCOMPARE(container->paintedCount, 1);
-
-    delete container;
 }
 
 void TestShapePainting::testPaintHiddenShape()
 {
+    QScopedPointer<MockContainer> top(new MockContainer());
+
     MockShape *shape = new MockShape();
     MockContainer *fourth = new MockContainer();
     MockContainer *thirth = new MockContainer();
     MockContainer *second = new MockContainer();
-    MockContainer *top = new MockContainer();
+
 
     top->addShape(second);
     second->addShape(thirth);
@@ -108,7 +108,7 @@ void TestShapePainting::testPaintHiddenShape()
 
     MockCanvas canvas;
     KoShapeManager manager(&canvas);
-    manager.addShape(top);
+    manager.addShape(top.data());
     QCOMPARE(manager.shapes().count(), 5);
 
     QImage image(100, 100,  QImage::Format_Mono);
@@ -121,8 +121,6 @@ void TestShapePainting::testPaintHiddenShape()
     QCOMPARE(thirth->paintedCount, 0);
     QCOMPARE(fourth->paintedCount, 0);
     QCOMPARE(shape->paintedCount, 0);
-
-    delete top;
 }
 
 void TestShapePainting::testPaintOrder()
@@ -147,110 +145,111 @@ void TestShapePainting::testPaintOrder()
 
     QList<MockShape*> order;
 
-    MockContainer *top = new MockContainer();
-    top->setZIndex(2);
-    OrderedMockShape *shape1 = new OrderedMockShape(order);
-    shape1->setZIndex(5);
-    OrderedMockShape *shape2 = new OrderedMockShape(order);
-    shape2->setZIndex(0);
-    top->addShape(shape1);
-    top->addShape(shape2);
+    {
+        QScopedPointer<MockContainer> top(new MockContainer());
+        top->setZIndex(2);
+        OrderedMockShape *shape1 = new OrderedMockShape(order);
+        shape1->setZIndex(5);
+        OrderedMockShape *shape2 = new OrderedMockShape(order);
+        shape2->setZIndex(0);
+        top->addShape(shape1);
+        top->addShape(shape2);
 
-    MockContainer *bottom = new MockContainer();
-    bottom->setZIndex(1);
-    OrderedMockShape *shape3 = new OrderedMockShape(order);
-    shape3->setZIndex(-1);
-    OrderedMockShape *shape4 = new OrderedMockShape(order);
-    shape4->setZIndex(9);
-    bottom->addShape(shape3);
-    bottom->addShape(shape4);
+        QScopedPointer<MockContainer> bottom(new MockContainer());
+        bottom->setZIndex(1);
+        OrderedMockShape *shape3 = new OrderedMockShape(order);
+        shape3->setZIndex(-1);
+        OrderedMockShape *shape4 = new OrderedMockShape(order);
+        shape4->setZIndex(9);
+        bottom->addShape(shape3);
+        bottom->addShape(shape4);
 
-    MockCanvas canvas;
-    KoShapeManager manager(&canvas);
-    manager.addShape(top);
-    manager.addShape(bottom);
-    QCOMPARE(manager.shapes().count(), 6);
+        MockCanvas canvas;
+        KoShapeManager manager(&canvas);
+        manager.addShape(top.data());
+        manager.addShape(bottom.data());
+        QCOMPARE(manager.shapes().count(), 6);
 
-    QImage image(100, 100,  QImage::Format_Mono);
-    QPainter painter(&image);
-    KoViewConverter vc;
-    manager.paint(painter, vc, false);
-    QCOMPARE(top->paintedCount, 1);
-    QCOMPARE(bottom->paintedCount, 1);
-    QCOMPARE(shape1->paintedCount, 1);
-    QCOMPARE(shape2->paintedCount, 1);
-    QCOMPARE(shape3->paintedCount, 1);
-    QCOMPARE(shape4->paintedCount, 1);
+        QImage image(100, 100,  QImage::Format_Mono);
+        QPainter painter(&image);
+        KoViewConverter vc;
+        manager.paint(painter, vc, false);
+        QCOMPARE(top->paintedCount, 1);
+        QCOMPARE(bottom->paintedCount, 1);
+        QCOMPARE(shape1->paintedCount, 1);
+        QCOMPARE(shape2->paintedCount, 1);
+        QCOMPARE(shape3->paintedCount, 1);
+        QCOMPARE(shape4->paintedCount, 1);
 
-    QCOMPARE(order.count(), 4);
-    QVERIFY(order[0] == shape3); // lowest first
-    QVERIFY(order[1] == shape4);
-    QVERIFY(order[2] == shape2);
-    QVERIFY(order[3] == shape1);
+        QCOMPARE(order.count(), 4);
+        QVERIFY(order[0] == shape3); // lowest first
+        QVERIFY(order[1] == shape4);
+        QVERIFY(order[2] == shape2);
+        QVERIFY(order[3] == shape1);
 
-    // again, with clipping.
-    order.clear();
-    painter.setClipRect(0, 0, 100, 100);
-    manager.paint(painter, vc, false);
-    QCOMPARE(top->paintedCount, 2);
-    QCOMPARE(bottom->paintedCount, 2);
-    QCOMPARE(shape1->paintedCount, 2);
-    QCOMPARE(shape2->paintedCount, 2);
-    QCOMPARE(shape3->paintedCount, 2);
-    QCOMPARE(shape4->paintedCount, 2);
+        // again, with clipping.
+        order.clear();
+        painter.setClipRect(0, 0, 100, 100);
+        manager.paint(painter, vc, false);
+        QCOMPARE(top->paintedCount, 2);
+        QCOMPARE(bottom->paintedCount, 2);
+        QCOMPARE(shape1->paintedCount, 2);
+        QCOMPARE(shape2->paintedCount, 2);
+        QCOMPARE(shape3->paintedCount, 2);
+        QCOMPARE(shape4->paintedCount, 2);
 
-    QCOMPARE(order.count(), 4);
-    QVERIFY(order[0] == shape3); // lowest first
-    QVERIFY(order[1] == shape4);
-    QVERIFY(order[2] == shape2);
-    QVERIFY(order[3] == shape1);
+        QCOMPARE(order.count(), 4);
+        QVERIFY(order[0] == shape3); // lowest first
+        QVERIFY(order[1] == shape4);
+        QVERIFY(order[2] == shape2);
+        QVERIFY(order[3] == shape1);
+
+    }
 
     order.clear();
 
-    MockContainer *root = new MockContainer();
-    root->setZIndex(0);
+    {
+        QScopedPointer<MockContainer> root(new MockContainer());
+        root->setZIndex(0);
 
-    MockContainer *branch1 = new MockContainer();
-    branch1->setZIndex(1);
-    OrderedMockShape *child1_1 = new OrderedMockShape(order);
-    child1_1->setZIndex(1);
-    OrderedMockShape *child1_2 = new OrderedMockShape(order);
-    child1_2->setZIndex(2);
-    branch1->addShape(child1_1);
-    branch1->addShape(child1_2);
+        MockContainer *branch1 = new MockContainer();
+        branch1->setZIndex(1);
+        OrderedMockShape *child1_1 = new OrderedMockShape(order);
+        child1_1->setZIndex(1);
+        OrderedMockShape *child1_2 = new OrderedMockShape(order);
+        child1_2->setZIndex(2);
+        branch1->addShape(child1_1);
+        branch1->addShape(child1_2);
 
-    MockContainer *branch2 = new MockContainer();
-    branch2->setZIndex(2);
-    OrderedMockShape *child2_1 = new OrderedMockShape(order);
-    child2_1->setZIndex(1);
-    OrderedMockShape *child2_2 = new OrderedMockShape(order);
-    child2_2->setZIndex(2);
-    branch2->addShape(child2_1);
-    branch2->addShape(child2_2);
- 
-    root->addShape(branch1);
-    root->addShape(branch2);
-    
-    QList<KoShape*> sortedShapes;
-    sortedShapes.append(root);
-    sortedShapes.append(branch1);
-    sortedShapes.append(branch2);
-    sortedShapes.append(branch1->shapes());
-    sortedShapes.append(branch2->shapes());
-    
-    std::sort(sortedShapes.begin(), sortedShapes.end(), KoShape::compareShapeZIndex);
-    QCOMPARE(sortedShapes.count(), 7);
-    QVERIFY(sortedShapes[0] == root);
-    QVERIFY(sortedShapes[1] == branch1);
-    QVERIFY(sortedShapes[2] == child1_1);
-    QVERIFY(sortedShapes[3] == child1_2);
-    QVERIFY(sortedShapes[4] == branch2);
-    QVERIFY(sortedShapes[5] == child2_1);
-    QVERIFY(sortedShapes[6] == child2_2);
+        MockContainer *branch2 = new MockContainer();
+        branch2->setZIndex(2);
+        OrderedMockShape *child2_1 = new OrderedMockShape(order);
+        child2_1->setZIndex(1);
+        OrderedMockShape *child2_2 = new OrderedMockShape(order);
+        child2_2->setZIndex(2);
+        branch2->addShape(child2_1);
+        branch2->addShape(child2_2);
 
-    delete top;
-    delete bottom;
-    delete root;
+        root->addShape(branch1);
+        root->addShape(branch2);
+
+        QList<KoShape*> sortedShapes;
+        sortedShapes.append(root.data());
+        sortedShapes.append(branch1);
+        sortedShapes.append(branch2);
+        sortedShapes.append(branch1->shapes());
+        sortedShapes.append(branch2->shapes());
+
+        std::sort(sortedShapes.begin(), sortedShapes.end(), KoShape::compareShapeZIndex);
+        QCOMPARE(sortedShapes.count(), 7);
+        QVERIFY(sortedShapes[0] == root.data());
+        QVERIFY(sortedShapes[1] == branch1);
+        QVERIFY(sortedShapes[2] == child1_1);
+        QVERIFY(sortedShapes[3] == child1_2);
+        QVERIFY(sortedShapes[4] == branch2);
+        QVERIFY(sortedShapes[5] == child2_1);
+        QVERIFY(sortedShapes[6] == child2_2);
+    }
 }
 #include <kundo2command.h>
 #include <KoShapeController.h>
@@ -259,11 +258,13 @@ void TestShapePainting::testPaintOrder()
 #include "kis_debug.h"
 void TestShapePainting::testGroupUngroup()
 {
-    MockShape *shape1 = new MockShape();
-    MockShape *shape2 = new MockShape();
+    QScopedPointer<MockContainer> shapesFakeLayer(new MockContainer);
+    MockShape *shape1(new MockShape());
+    MockShape *shape2(new MockShape());
     shape1->setName("shape1");
     shape2->setName("shape2");
-
+    shape1->setParent(shapesFakeLayer.data());
+    shape2->setParent(shapesFakeLayer.data());
 
     QList<KoShape*> groupedShapes = {shape1, shape2};
 
@@ -280,17 +281,16 @@ void TestShapePainting::testGroupUngroup()
     painter.setClipRect(image.rect());
     KoViewConverter vc;
 
-    KoShapeGroup *group = 0;
-
-
     for (int i = 0; i < 3; i++) {
+        KoShapeGroup *group = new KoShapeGroup();
+        group->setParent(shapesFakeLayer.data());
+
         {
-            group = new KoShapeGroup();
             group->setName("group");
 
             KUndo2Command groupingCommand;
             canvas.shapeController()->addShapeDirect(group, 0, &groupingCommand);
-            new KoShapeGroupCommand(group, groupedShapes, false, true, true, &groupingCommand);
+            new KoShapeGroupCommand(group, groupedShapes, true, &groupingCommand);
 
             groupingCommand.redo();
 
@@ -314,10 +314,9 @@ void TestShapePainting::testGroupUngroup()
             QCOMPARE(shape1->paintedCount, 2 * i + 2);
             QCOMPARE(shape2->paintedCount, 2 * i + 2);
             QCOMPARE(manager->shapes().size(), 2);
-
-            group = 0;
         }
 
+        group->setParent(0);
     }
 }
 
