@@ -981,7 +981,7 @@ void TestSvgText::testConvertToStrippedSvgNullOrigin()
     QVERIFY(converter.convertToSvg(&svgText, &stylesText));
 
     QCOMPARE(stylesText, QString("<defs/>"));
-    QCOMPARE(svgText, QString("<text fill=\"#0000ff\" font-family=\"Verdana\" font-size=\"15\"><tspan>S</tspan><tspan fill=\"#ff0000\">A</tspan><tspan>some stuff&lt;&gt;&lt;&gt;&lt;&lt;&lt;&gt;</tspan></text>"));
+    QCOMPARE(svgText, QString("<text fill=\"#0000ff\" font-family=\"Verdana\" font-size=\"15\"><tspan x=\"0\" y=\"0\">S</tspan><tspan fill=\"#ff0000\">A</tspan><tspan>some stuff&lt;&gt;&lt;&gt;&lt;&lt;&lt;&gt;</tspan></text>"));
 }
 
 void TestSvgText::testConvertFromIncorrectStrippedSvg()
@@ -1077,5 +1077,131 @@ void TestSvgText::testConvertHtmlToSvg()
 
 }
 
+void TestSvgText::testTextWithMultipleRelativeOffsets()
+{
+    const QString data =
+            "<svg width=\"100px\" height=\"30px\""
+            "    xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">"
+
+            "<g id=\"test\">"
+            "    <text id=\"testRect\" x=\"10\" y=\"40\""
+            "        font-family=\"Verdana\" font-size=\"15\" "
+            "        dy=\"0 -3 -3 -3 -3 3 3 3 3 0 -3 -3 -3 -3 3 3 3 3 0 -3 -3 -3 -3 3 3 3 3 0 -3 -3 -3 -3 3 3 3 3 0\">"
+            "        Lorem ipsum dolor sit amet"
+            "    </text>"
+
+            "</g>"
+
+            "</svg>";
+
+    SvgRenderTester t (data);
+    t.test_standard("text_multiple_relative_offsets", QSize(300, 80), 72.0);
+}
+
+void TestSvgText::testTextWithMultipleAbsoluteOffsetsArabic()
+{
+    /**
+     * According to the standard, each **absolute** offset defines a
+     * new text chunk, therefore, the arabic text must become
+     * ltr reordered
+     */
+
+    const QString data =
+            "<svg width=\"100px\" height=\"30px\""
+            "    xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">"
+
+            "<g id=\"test\">"
+            "    <text id=\"testRect\" x=\"10\" y=\"40\""
+            "        font-family=\"Verdana\" font-size=\"15\" "
+            "        y=\"40 45 50 55 50 45 40 35 30 25 30 35 40 45 50 55 50 45 40 35 30 25 30 35 40 45 50 55 50 45 40 35 30 25 30 35 40 45 50 55 50 45 40 35 30 25 30 35 40 45 50 55 50 45 40 35 30 25 30 35 40 45 50 55 50 45 40 35 30 25 30 35 \">"
+            "        Lo rem اللغة العربية المعيارية الحديثة ip sum"
+            "    </text>"
+
+            "</g>"
+
+            "</svg>";
+
+    SvgRenderTester t (data);
+    t.test_standard("text_multiple_absolute_offsets_arabic", QSize(530, 70), 72.0);
+}
+
+void TestSvgText::testTextWithMultipleRelativeOffsetsArabic()
+{
+    /**
+     * According to the standard, **relative** offsets must not define a new
+     * text chunk, therefore, the arabic text must be written in native rtl order,
+     * even though the individual letters are split.
+     */
+
+    const QString data =
+            "<svg width=\"100px\" height=\"30px\""
+            "    xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">"
+
+            "<g id=\"test\">"
+            "    <text id=\"testRect\" x=\"10\" y=\"40\""
+            "        font-family=\"Verdana\" font-size=\"15\" "
+            "        dy=\"0 -3 -3 -3 -3 3 3 3 3 0 -3 -3 -3 -3 3 3 3 3 0 -3 -3 -3 -3 3 3 3 3 0 -3 -3 -3 -3 3 3 3 3 0 -3 -3 -3 -3 3 3 3 3 0\">"
+            "        Lo rem اللغة العربية المعيارية الحديثة ip sum"
+            "    </text>"
+
+            "</g>"
+
+            "</svg>";
+
+    SvgRenderTester t (data);
+
+
+    QEXPECT_FAIL("", "WARNING: in Krita relative offsets also define a new text chunk, that doesn't comply with SVG standard and must be fixed", Continue);
+    t.test_standard("text_multiple_relative_offsets_arabic", QSize(530, 70), 72.0);
+}
+
+void TestSvgText::testTextOutline()
+{
+    const QString data =
+            "<svg width=\"100px\" height=\"30px\""
+            "    xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">"
+
+            "<g id=\"test\">"
+
+            "    <rect id=\"boundingRect\" x=\"4\" y=\"5\" width=\"89\" height=\"19\""
+            "        fill=\"none\" stroke=\"red\"/>"
+
+            "    <text id=\"testRect\" x=\"7\" y=\"27\""
+            " "
+            "        font-family=\"Verdana\" font-size=\"15\" fill=\"blue\" >"
+            "        normal "
+            "        <tspan text-decoration=\"line-through\">strikethrough</tspan>"
+            "        <tspan text-decoration=\"overline\">overline</tspan>"
+            "        <tspan text-decoration=\"underline\">underline</tspan>"
+            "    </text>"
+
+            "</g>"
+
+            "</svg>";
+
+    QRect renderRect(0, 0, 450, 40);
+
+    SvgRenderTester t (data);
+    t.test_standard("text_outline", renderRect.size(), 72.0);
+
+    KoShape *shape = t.findShape("testRect");
+    KoSvgTextChunkShape *chunkShape = dynamic_cast<KoSvgTextChunkShape*>(shape);
+    QVERIFY(chunkShape);
+
+    KoSvgTextShape *textShape = dynamic_cast<KoSvgTextShape*>(shape);
+
+    QImage canvas(renderRect.size(), QImage::Format_ARGB32);
+    canvas.fill(0);
+    QPainter gc(&canvas);
+    gc.setPen(Qt::NoPen);
+    gc.setBrush(Qt::black);
+    gc.setRenderHint(QPainter::Antialiasing, true);
+    gc.drawPath(textShape->textOutline());
+
+    QVERIFY(TestUtil::checkQImage(canvas, "svg_render", "load_text_outline", "converted_to_path", 3, 5));
+}
+
+
+
 
 QTEST_MAIN(TestSvgText)
