@@ -232,8 +232,10 @@ struct KoSvgTextChunkShapePrivate::LayoutInterface : public KoSvgTextChunkShapeL
                     int subChunkLength = 1;
 
                     for (int j = i + 1; j < transforms.size(); j++) {
-                        if (transforms[j] == baseTransform) {
+                        if (transforms[j].isNull()) {
                             subChunkLength++;
+                        } else {
+                            break;
                         }
                     }
 
@@ -599,10 +601,15 @@ void KoSvgTextChunkShape::resetTextShape()
     d->localTransformations.clear();
     d->text.clear();
 
-    // all the subchunks are destroyed!
-    qDeleteAll(shapes());
-}
 
+    // all the subchunks are destroyed!
+    // (first detach, then destroy)
+    QList<KoShape*> shapesToReset = shapes();
+    Q_FOREACH (KoShape *shape, shapesToReset) {
+        shape->setParent(0);
+        delete shape;
+    }
+}
 
 bool KoSvgTextChunkShape::loadSvg(const KoXmlElement &e, SvgLoadingContext &context)
 {
