@@ -41,7 +41,9 @@
 #include "commands/KoSubpathJoinCommand.h"
 #include <commands/KoMultiPathPointMergeCommand.h>
 #include <commands/KoMultiPathPointJoinCommand.h>
+#include <commands/KoKeepShapesSelectedCommand.h>
 #include "KoParameterShape.h"
+#include <text/KoSvgTextShape.h>
 #include "KoPathPoint.h"
 #include "KoPathPointRubberSelectStrategy.h"
 #include "KoPathSegmentChangeStrategy.h"
@@ -55,6 +57,7 @@
 #include <KisHandlePainterHelper.h>
 #include <KoShapeStrokeModel.h>
 #include "kis_command_utils.h"
+#include "kis_pointer_utils.h"
 
 
 #include <KoIcon.h>
@@ -360,14 +363,61 @@ void KoPathTool::segmentToCurve()
 void KoPathTool::convertToPath()
 {
     Q_D(KoToolBase);
-    QList<KoParameterShape*> shapesToConvert;
+
+    KoSelection *selection = canvas()->selectedShapesProxy()->selection();
+
+    QList<KoParameterShape*> parameterShapes;
+
     Q_FOREACH (KoShape *shape, m_pointSelection.selectedShapes()) {
-        KoParameterShape * parameterShape = dynamic_cast<KoParameterShape*>(shape);
-        if (parameterShape && parameterShape->isParametricShape())
-            shapesToConvert.append(parameterShape);
+        KoParameterShape * parameteric = dynamic_cast<KoParameterShape*>(shape);
+        if (parameteric && parameteric->isParametricShape()) {
+            parameterShapes.append(parameteric);
+        }
     }
-    if (shapesToConvert.count())
-        d->canvas->addCommand(new KoParameterToPathCommand(shapesToConvert));
+
+    if (!parameterShapes.isEmpty()) {
+        d->canvas->addCommand(new KoParameterToPathCommand(parameterShapes));
+    }
+
+    QList<KoSvgTextShape*> textShapes;
+    Q_FOREACH (KoShape *shape, selection->selectedEditableShapes()) {
+        if (KoSvgTextShape *text = dynamic_cast<KoSvgTextShape*>(shape)) {
+            textShapes.append(text);
+        }
+    }
+
+    if (!textShapes.isEmpty()) {
+        KUndo2Command *cmd = new KUndo2Command(kundo2_i18n("Convert to Path")); // TODO: reuse the text from KoParameterToPathCommand
+        const QList<KoShape*> oldSelectedShapes = implicitCastList<KoShape*>(textShapes);
+
+
+        new KoKeepShapesSelectedCommand(oldSelectedShapes, {}, canvas()->selectedShapesProxy(), false, cmd);
+
+        QList<KoShape*> newSelectedShapes;
+        Q_FOREACH (KoSvgTextShape *shape, textShapes) {
+            const QPainterPath path = shape->textOutline();
+            if (path.isEmpty()) continue;
+
+            KoPathShape *pathShape = KoPathShape::createShapeFromPainterPath(path);
+
+            pathShape->setBackground(shape->background());
+            pathShape->setStroke(shape->stroke());
+            pathShape->setZIndex(shape->zIndex());
+            pathShape->setTransformation(shape->transformation());
+
+            KoShapeContainer *parent = shape->parent();
+            canvas()->shapeController()->addShapeDirect(pathShape, parent, cmd);
+
+            newSelectedShapes << pathShape;
+        }
+
+        canvas()->shapeController()->removeShapes(oldSelectedShapes, cmd);
+
+        new KoKeepShapesSelectedCommand({}, newSelectedShapes, canvas()->selectedShapesProxy(), true, cmd);
+
+        canvas()->addCommand(cmd);
+    }
+
     updateOptionsWidget();
 }
 
@@ -564,6 +614,7 @@ void KoPathTool::mousePressEvent(KoPointerEvent *event)
                 KoSelection *selection = shapeManager->selection();
 
                 KoShape *shape = shapeManager->shapeAt(event->point, KoFlake::ShapeOnTop);
+
                 if (shape && !selection->isSelected(shape)) {
 
                     if (!(event->modifiers() & Qt::ShiftModifier)) {
@@ -829,14 +880,16 @@ void KoPathTool::mouseDoubleClickEvent(KoPointerEvent *event)
     // check if we are doing something else at the moment
     if (m_currentStrategy) return;
 
-    QScopedPointer<PathSegment> s(segmentAtPoint(event->point));
-
-    if (s && s->isValid()) {
+    if (!m_activeHandle && m_activeSegment && m_activeSegment->isValid()) {
         QList<KoPathPointData> segments;
-        segments.append(KoPathPointData(s->path, s->path->pathPointIndex(s->segmentStart)));
-        KoPathPointInsertCommand *cmd = new KoPathPointInsertCommand(segments, s->positionOnSegment);
+        segments.append(
+            KoPathPointData(m_activeSegment->path,
+                            m_activeSegment->path->pathPointIndex(m_activeSegment->segmentStart)));
+
+        KoPathPointInsertCommand *cmd = new KoPathPointInsertCommand(segments, m_activeSegment->positionOnSegment);
         d->canvas->addCommand(cmd);
 
+        m_pointSelection.clear();
         foreach (KoPathPoint * p, cmd->insertedPoints()) {
             m_pointSelection.add(p, false);
         }
@@ -844,18 +897,23 @@ void KoPathTool::mouseDoubleClickEvent(KoPointerEvent *event)
         event->accept();
     } else if (!m_activeHandle && !m_activeSegment && m_activatedTemporarily) {
         emit done();
+        event->accept();
+    } else if (!m_activeHandle && !m_activeSegment) {
+        KoShapeManager *shapeManager = canvas()->shapeManager();
+        KoSelection *selection = shapeManager->selection();
+
+        selection->deselectAll();
+        event->accept();
     }
 }
 
 KoPathTool::PathSegment* KoPathTool::segmentAtPoint(const QPointF &point)
 {
     Q_D(KoToolBase);
-    const int clickProximity = 5;
 
-    // convert click proximity to point using the current zoom level
-    QPointF clickOffset = d->canvas->viewConverter()->viewToDocument(QPointF(clickProximity, clickProximity));
     // the max allowed distance from a segment
-    const qreal maxSquaredDistance = clickOffset.x()*clickOffset.x();
+    const QRectF grabRoi = handleGrabRect(point);
+    const qreal distanceThreshold = 0.5 * KisAlgebra2D::maxDimension(grabRoi);
 
     QScopedPointer<PathSegment> segment(new PathSegment);
 
@@ -865,23 +923,25 @@ KoPathTool::PathSegment* KoPathTool::segmentAtPoint(const QPointF &point)
             continue;
 
         // convert document point to shape coordinates
-        QPointF p = shape->documentToShape(point);
+        const QPointF p = shape->documentToShape(point);
         // our region of interest, i.e. a region around our mouse position
-        QRectF roi(p - clickOffset, p + clickOffset);
+        const QRectF roi = shape->documentToShape(grabRoi);
+
+        qreal minDistance = std::numeric_limits<qreal>::max();
 
-        qreal minSqaredDistance = HUGE_VAL;
         // check all segments of this shape which intersect the region of interest
-        QList<KoPathSegment> segments = shape->segmentsAt(roi);
+        const QList<KoPathSegment> segments = shape->segmentsAt(roi);
+
         foreach (const KoPathSegment &s, segments) {
-            qreal nearestPointParam = s.nearestPoint(p);
-            QPointF nearestPoint = s.pointAt(nearestPointParam);
-            QPointF diff = p - nearestPoint;
-            qreal squaredDistance = diff.x()*diff.x() + diff.y()*diff.y();
+            const qreal nearestPointParam = s.nearestPoint(p);
+            const QPointF nearestPoint = s.pointAt(nearestPointParam);
+            const qreal distance = kisDistance(p, nearestPoint);
+
             // are we within the allowed distance ?
-            if (squaredDistance > maxSquaredDistance)
+            if (distance > distanceThreshold)
                 continue;
             // are we closer to the last closest point ?
-            if (squaredDistance < minSqaredDistance) {
+            if (distance < minDistance) {
                 segment->path = shape;
                 segment->segmentStart = s.first();
                 segment->positionOnSegment = nearestPointParam;
@@ -911,6 +971,7 @@ void KoPathTool::activate(ToolActivation activation, const QSet<KoShape*> &shape
     useCursor(m_selectCursor);
     m_canvasConnections.addConnection(d->canvas->selectedShapesProxy(), SIGNAL(selectionChanged()), this, SLOT(slotSelectionChanged()));
     m_canvasConnections.addConnection(d->canvas->selectedShapesProxy(), SIGNAL(selectionContentChanged()), this, SLOT(updateActions()));
+    m_shapeFillResourceConnector.connectToCanvas(d->canvas);
 
     initializeWithShapes(shapes.toList());
 }
@@ -934,17 +995,22 @@ void KoPathTool::clearActivePointSelectionReferences()
     m_pointSelection.clear();
 }
 
+#include "kis_pointer_utils.h"
+
 void KoPathTool::initializeWithShapes(const QList<KoShape*> shapes)
 {
     QList<KoPathShape*> selectedShapes;
     Q_FOREACH (KoShape *shape, shapes) {
         KoPathShape *pathShape = dynamic_cast<KoPathShape*>(shape);
 
-        if (pathShape && pathShape->isEditable()) {
+        if (pathShape && pathShape->isShapeEditable()) {
             selectedShapes.append(pathShape);
         }
     }
 
+    const QRectF oldBoundingRect =
+        KoShape::boundingRect(implicitCastList<KoShape*>(m_pointSelection.selectedShapes()));
+
     if (selectedShapes != m_pointSelection.selectedShapes()) {
         clearActivePointSelectionReferences();
         m_pointSelection.setSelectedShapes(selectedShapes);
@@ -957,6 +1023,7 @@ void KoPathTool::initializeWithShapes(const QList<KoShape*> shapes)
         // current canvas
         repaint(shape->boundingRect());
     }
+    repaint(oldBoundingRect);
 
     updateOptionsWidget();
     updateActions();
@@ -1064,12 +1131,26 @@ void KoPathTool::updateActions()
 
     m_actionBreakSegment->setEnabled(canSplitAtSegment);
 
+    KoSelection *selection = canvas()->selectedShapesProxy()->selection();
+    bool haveConvertibleShapes = false;
+    Q_FOREACH (KoShape *shape, selection->selectedEditableShapes()) {
+        KoParameterShape * parameterShape = dynamic_cast<KoParameterShape*>(shape);
+        KoSvgTextShape *textShape = dynamic_cast<KoSvgTextShape*>(shape);
+        if (textShape ||
+            (parameterShape && parameterShape->isParametricShape())) {
+
+            haveConvertibleShapes = true;
+            break;
+        }
+    }
+    m_actionConvertToPath->setEnabled(haveConvertibleShapes);
 }
 
 void KoPathTool::deactivate()
 {
     Q_D(KoToolBase);
 
+    m_shapeFillResourceConnector.disconnect();
     m_canvasConnections.clear();
     m_pointSelection.clear();
     m_pointSelection.setSelectedShapes(QList<KoPathShape*>());
