@@ -23,10 +23,12 @@
 #include <QTime>
 
 #include "kis_global.h"
-#include "kis_vec.h"
 #include "kritaimage_export.h"
 #include <kis_distance_information.h>
 #include "kis_random_source.h"
+#include "KisPerStrokeRandomSource.h"
+#include "kis_spacing_information.h"
+#include "kis_timing_information.h"
 
 
 class QDomDocument;
@@ -107,13 +109,21 @@ public:
     template <class PaintOp>
     void paintAt(PaintOp &op, KisDistanceInformation *distanceInfo) {
         KisSpacingInformation spacingInfo;
-
+        KisTimingInformation timingInfo;
         {
             DistanceInformationRegistrar r = registerDistanceInformation(distanceInfo);
             spacingInfo = op.paintAt(*this);
+            timingInfo = op.updateTimingImpl(*this);
+
+            // Initiate the process of locking the drawing angle. The locked value will
+            // always be present in the internals, but it will be requested but the users
+            // with a special parameter of drawingAngle() only.
+            if (!this->isHoveringMode()) {
+                distanceInfo->lockCurrentDrawingAngle(*this);
+            }
         }
 
-        distanceInfo->registerPaintedDab(*this, spacingInfo);
+        distanceInfo->registerPaintedDab(*this, spacingInfo, timingInfo);
     }
 
     const QPointF& pos() const;
@@ -137,7 +147,13 @@ public:
     /// XXX !!! :-| Please add dox!
     qreal drawingAngleSafe(const KisDistanceInformation &distance) const;
 
-    /// XXX !!! :-| Please add dox!
+    /**
+     * Causes the specified distance information to be temporarily registered with this
+     * KisPaintInformation object, so that the KisPaintInformation can compute certain values that
+     * may be needed at painting time, such as the drawing direction. When the returned object is
+     * destroyed, the KisDistanceInformation will be unregistered. At most one
+     * KisDistanceInformation can be registered with a given KisPaintInformation at a time.
+     */
     DistanceInformationRegistrar registerDistanceInformation(KisDistanceInformation *distance);
 
     /**
@@ -146,14 +162,7 @@ public:
      * WARNING: this method is available *only* inside paintAt() call,
      * that is when the distance information is registered.
      */
-    qreal drawingAngle() const;
-
-    /**
-     * Lock current drawing angle for the rest of the stroke. If some
-     * value has already been locked, \p alpha shown the coefficient
-     * with which the new velue should be blended in.
-     */
-    void lockCurrentDrawingAngle(qreal alpha) const;
+    qreal drawingAngle(bool considerLockedAngle = false) const;
 
     /**
      * Current brush direction vector computed from the cursor movement
@@ -191,6 +200,12 @@ public:
     /// Number of ms since the beginning of the stroke
     qreal currentTime() const;
 
+    /// Number of dabs painted since the beginning of the stroke
+    int currentDabSeqNo() const;
+
+    /// The length of the stroke **before** painting the current dab
+    qreal totalStrokeLength() const;
+
     // random source for generating in-stroke effects
     KisRandomSourceSP randomSource() const;
 
@@ -198,8 +213,15 @@ public:
     // paint info objects, otherwise it shows a warning
     void setRandomSource(KisRandomSourceSP value);
 
+    // random source for generating in-stroke effects, generates one(!) value per stroke
+    KisPerStrokeRandomSourceSP perStrokeRandomSource() const;
+
+    // the stroke should initialize per stroke random source of all the used
+    // paint info objects, otherwise it shows a warning
+    void setPerStrokeRandomSource(KisPerStrokeRandomSourceSP value);
+
     // set level of detail which info object has been generated for
-    void setLevelOfDetail(int levelOfDetail) const;
+    void setLevelOfDetail(int levelOfDetail);
 
     /**
      * The paint information may be generated not only during real
@@ -239,28 +261,43 @@ public:
      *set the canvas rotation.
      */
     void setCanvasRotation(int rotation);
-    
+
     /*
      *Whether the canvas is mirrored for the paint-operation.
      */
     bool canvasMirroredH() const;
-    
+
     /*
      *Set whether the canvas is mirrored for the paint-operation.
      */
     void setCanvasHorizontalMirrorState(bool mir);
-    
+
     void toXML(QDomDocument&, QDomElement&) const;
 
     static KisPaintInformation fromXML(const QDomElement&);
 
+    // TODO: Refactor the static mix functions to non-static in-place mutation
+    //       versions like mixOtherOnlyPosition and mixOtherWithoutTime.
+    // Heap allocation on Windows is awfully slow and will fragment the memory
+    // badly. Since KisPaintInformation allocates on the heap, we should re-use
+    // existing instance whenever possible, especially in loops.
+    // Ref: https://phabricator.kde.org/D6578
+
     /// (1-t) * p1 + t * p2
     static KisPaintInformation mixOnlyPosition(qreal t, const KisPaintInformation& mixedPi, const KisPaintInformation& basePi);
     static KisPaintInformation mix(const QPointF& p, qreal t, const KisPaintInformation& p1, const KisPaintInformation& p2);
     static KisPaintInformation mix(qreal t, const KisPaintInformation& pi1, const KisPaintInformation& pi2);
+    static KisPaintInformation mixWithoutTime(const QPointF &p, qreal t, const KisPaintInformation &p1, const KisPaintInformation &p2);
+    static KisPaintInformation mixWithoutTime(qreal t, const KisPaintInformation &pi1, const KisPaintInformation &pi2);
+    void mixOtherOnlyPosition(qreal t, const KisPaintInformation& other);
+    void mixOtherWithoutTime(qreal t, const KisPaintInformation& other);
     static qreal tiltDirection(const KisPaintInformation& info, bool normalize = true);
     static qreal tiltElevation(const KisPaintInformation& info, qreal maxTiltX = 60.0, qreal maxTiltY = 60.0, bool normalize = true);
 
+private:
+    static KisPaintInformation mixImpl(const QPointF &p, qreal t, const KisPaintInformation &p1, const KisPaintInformation &p2, bool posOnly, bool mixTime);
+    void mixOtherImpl(const QPointF &p, qreal t, const KisPaintInformation &other, bool posOnly, bool mixTime);
+
 private:
     struct Private;
     Private* const d;
