@@ -45,7 +45,7 @@ public:
 
     KisPaintOpPreset(const QString& filename);
 
-    ~KisPaintOpPreset();
+    ~KisPaintOpPreset() override;
 
     KisPaintOpPresetSP clone() const;
 
@@ -63,11 +63,11 @@ public:
     KisPaintOpSettingsSP settings() const;
     KisPaintOpSettingsSP originalSettings() const;
 
-    bool load();
-    bool loadFromDevice(QIODevice *dev);
+    bool load() override;
+    bool loadFromDevice(QIODevice *dev) override;
 
-    bool save();
-    bool saveToDevice(QIODevice* dev) const;
+    bool save() override;
+    bool saveToDevice(QIODevice* dev) const override;
 
     void toXML(QDomDocument& doc, QDomElement& elt) const;
 
@@ -77,7 +77,7 @@ public:
         return true;
     }
 
-    QString defaultFileExtension() const {
+    QString defaultFileExtension() const override {
         return ".kpp";
     }
     void setPresetDirty(bool value);
@@ -90,7 +90,7 @@ public:
      * hard-to-tack-down bugs when the dirty state will not be
      * restored on jumps like 'return', 'break' or exception.
      */
-    class DirtyStateSaver {
+    class KRITAIMAGE_EXPORT DirtyStateSaver {
     public:
         DirtyStateSaver(KisPaintOpPreset *preset)
             : m_preset(preset), m_isDirty(preset->isPresetDirty())
@@ -110,7 +110,7 @@ public:
      * @brief The UpdatedPostponer class
      * @see KisPaintopSettingsUpdateProxy::postponeSettingsChanges()
      */
-    class UpdatedPostponer{
+    class KRITAIMAGE_EXPORT UpdatedPostponer{
     public:
         UpdatedPostponer(KisPaintOpPreset *preset);
 
@@ -127,6 +127,19 @@ public:
 
     QList<KisUniformPaintOpPropertySP> uniformProperties();
 
+    /**
+     * @return true if this preset demands a secondary masked brush running
+     *         alongside it
+     */
+    bool hasMaskingPreset() const;
+
+    /**
+     * @return a newly created preset of the masked brush that should be run
+     *         alongside the current brush
+     */
+    KisPaintOpPresetSP createMaskingPreset() const;
+
+
 private:
 
     struct Private;
