@@ -156,6 +156,13 @@ public:
      */
     virtual KisPaintDeviceSP projection() const = 0;
 
+    /**
+     * @return a special device from where the color picker tool should pick
+     * color when in layer-only mode. For most of the nodes just shortcuts
+     * to projection() device. TODO: can it be null?
+     */
+    virtual KisPaintDeviceSP colorPickSourceDevice() const;
+
     virtual const KoColorSpace *colorSpace() const = 0;
 
     /**
@@ -368,7 +375,7 @@ public:
      * @param visible the new visibility state
      * @param isLoading if true, the property is set during loading.
      */
-    virtual void setVisible(bool visibile, bool loading = false);
+    virtual void setVisible(bool visible, bool loading = false);
 
     /**
      * Return the locked status of this node. Locked nodes cannot be
@@ -380,7 +387,7 @@ public:
      * Set the locked status of this node. Locked nodes cannot be
      * edited.
      */
-    void setUserLocked(bool l);
+    virtual void setUserLocked(bool l);
 
     /**
      * @return true if the node can be edited:
