@@ -43,7 +43,7 @@ class KisConfigWidget;
 /**
  * Base class for classes that process areas of pixels.
  * Processors can either read in pixels and write out pixels
- * or just write out pixels, using a certain set of configuation
+ * or just write out pixels, using a certain set of configuration
  * pixels.
  *
  * in-out processing is typically filtering: @see KisFilter.
@@ -72,7 +72,7 @@ public:
      *
      * @return the default configuration of this widget
      */
-    KisFilterConfigurationSP  defaultConfiguration(const KisPaintDeviceSP) const;
+    KisFilterConfigurationSP  defaultConfiguration() const;
 
     /**
      * @return the bookmark manager for this processor
@@ -139,7 +139,7 @@ public:
     ColorSpaceIndependence colorSpaceIndependence() const;
 
     /// @return the default configuration as defined by whoever wrote the plugin
-    virtual KisFilterConfigurationSP factoryConfiguration(const KisPaintDeviceSP) const;
+    virtual KisFilterConfigurationSP factoryConfiguration() const;
 
 protected:
 
