@@ -111,6 +111,14 @@ public:
     bool useLodForColorizeMask(bool requestDefault = false) const;
     void setUseLodForColorizeMask(bool value);
 
+    int maxNumberOfThreads(bool defaultValue = false) const;
+    void setMaxNumberOfThreads(int value);
+
+    int frameRenderingClones(bool defaultValue = false) const;
+    void setFrameRenderingClones(int value);
+
+    int fpsLimit(bool defaultValue = false) const;
+    void setFpsLimit(int value);
 
 private:
     Q_DISABLE_COPY(KisImageConfig)
