@@ -192,7 +192,7 @@ KisNode::KisNode(const KisNode & rhs)
 
     // HACK ALERT: we create opacity channel in KisBaseNode, but we cannot
     //             initialize its node from there! So workaround it here!
-    QMap<QString, KisKeyframeChannel*> channels = rhs.keyframeChannels();
+    QMap<QString, KisKeyframeChannel*> channels = keyframeChannels();
     for (auto it = channels.begin(); it != channels.end(); ++it) {
         it.value()->setNode(this);
     }
@@ -249,7 +249,7 @@ QRect KisNode::accessRect(const QRect &rect, PositionToFilthy pos) const
     return rect;
 }
 
-void KisNode::childNodeChanged(KisNodeSP changedChildNode)
+void KisNode::childNodeChanged(KisNodeSP /*changedChildNode*/)
 {
 }
 
@@ -604,12 +604,12 @@ void KisNode::setDirty(const QRect & rect)
 
 void KisNode::setDirtyDontResetAnimationCache()
 {
-    setDirtyDontResetAnimationCache({extent()});
+    setDirtyDontResetAnimationCache(QVector<QRect>({extent()}));
 }
 
 void KisNode::setDirtyDontResetAnimationCache(const QRect &rect)
 {
-    setDirtyDontResetAnimationCache({rect});
+    setDirtyDontResetAnimationCache(QVector<QRect>({rect}));
 }
 
 void KisNode::setDirtyDontResetAnimationCache(const QVector<QRect> &rects)
