@@ -114,7 +114,7 @@ public:
      * this percolates up to parent nodes all the way to the root
      * node.
      */
-    virtual void setDirty(const QRect & rect);
+    void setDirty(const QRect & rect);
 
     /**
      * Add the given rects to the set of dirty rects for this node;
@@ -128,7 +128,28 @@ public:
      * this percolates up to parent nodes all the way to the root
      * node, if propagate is true;
      */
-    virtual void setDirty(const QRegion &region);
+    void setDirty(const QRegion &region);
+
+    /**
+     * Convenience override of multirect version of setDirtyDontResetAnimationCache()
+     *
+     * @see setDirtyDontResetAnimationCache(const QVector<QRect> &rects)
+     */
+    void setDirtyDontResetAnimationCache();
+
+    /**
+     * Convenience override of multirect version of setDirtyDontResetAnimationCache()
+     *
+     * @see setDirtyDontResetAnimationCache(const QVector<QRect> &rects)
+     */
+    void setDirtyDontResetAnimationCache(const QRect &rect);
+
+    /**
+     * @brief setDirtyDontResetAnimationCache does almost the same thing as usual
+     * setDirty() call, but doesn't reset the animation cache (since onlion skins are
+     * not used when rendering animation.
+     */
+    void setDirtyDontResetAnimationCache(const QVector<QRect> &rects);
 
     /**
      * Informs that the frames in the given range are no longer valid
@@ -225,6 +246,13 @@ protected:
      */
     virtual QRect accessRect(const QRect &rect, PositionToFilthy pos = N_FILTHY) const;
 
+    /**
+     * Called each time direct child nodes are added or removed under this
+     * node as parent. This does not track changes inside the child nodes
+     * or the child nodes' properties.
+     */
+    virtual void childNodeChanged(KisNodeSP changedChildNode);
+
 public: // Graph methods
 
     /**
