@@ -425,10 +425,6 @@ public:
 
         if (m_data) {
             imageData += estimateDataSize(m_data.data());
-
-            if (!m_frames.isEmpty()) {
-                qWarning() << "WARNING: Extra data object:" << estimateDataSize(m_data.data());
-            }
         }
 
         if (m_lodData) {
@@ -1238,6 +1234,10 @@ QRect calculateExactBoundsImpl(const KisPaintDevice *device, const QRect &startR
 {
     if (startRect == endRect) return startRect;
 
+    // the passed extent might have weird invalid structure that
+    // can overflow integer precision when calling startRect.right()
+    if (!startRect.isValid()) return QRect();
+
     // Solution n°2
     int  x, y, w, h;
     int boundLeft, boundTop, boundRight, boundBottom;
@@ -1443,7 +1443,7 @@ void KisPaintDevice::clear(const QRect & rc)
 
 void KisPaintDevice::fill(const QRect & rc, const KoColor &color)
 {
-    Q_ASSERT(*color.colorSpace() == *colorSpace());
+    KIS_ASSERT_RECOVER_RETURN(*color.colorSpace() == *colorSpace());
     m_d->currentStrategy()->fill(rc, color.data());
 }
 
