@@ -33,6 +33,7 @@
 #include "kis_types.h"
 #include <KoColor.h>
 #include <KoColorModelStandardIds.h>
+#include <KoColorSpaceRegistry.h>
 
 struct Q_DECL_HIDDEN KisPropertiesConfiguration::Private {
     QMap<QString, QVariant> properties;
@@ -94,15 +95,17 @@ void KisPropertiesConfiguration::fromXML(const QDomElement& e)
                     QString type = e.attribute("type");
                     QString name = e.attribute("name");
                     QString value = e.text();
-                    if(type == "bytearray")
-                    {
+
+                    if (type == "bytearray") {
                         d->properties[name] = QVariant(QByteArray::fromBase64(value.toLatin1()));
                     }
-                    else
+                    else {
                         d->properties[name] = value;
+                    }
                 }
-                else
+                else {
                     d->properties[e.attribute("name")] = QVariant(e.text());
+                }
             }
         }
         n = n.nextSibling();
@@ -257,18 +260,53 @@ KisCubicCurve KisPropertiesConfiguration::getCubicCurve(const QString & name, co
 KoColor KisPropertiesConfiguration::getColor(const QString& name, const KoColor& color) const
 {
     QVariant v = getProperty(name);
+
     if (v.isValid()) {
-        if (v.type() == QVariant::UserType && v.userType() == qMetaTypeId<KoColor>()) {
-            return v.value<KoColor>();
-        } else {
-            QDomDocument doc;
-            doc.setContent(v.toString());
-            QDomElement e = doc.documentElement().firstChild().toElement();
-            bool ok;
-            KoColor c = KoColor::fromXML(e, Integer16BitsColorDepthID.id(), &ok);
-            if (ok) {
-                return c;
+        switch(v.type()) {
+        case QVariant::UserType:
+        {
+            if (v.userType() == qMetaTypeId<KoColor>()) {
+                return v.value<KoColor>();
             }
+            break;
+        }
+        case QVariant::String:
+        {
+            QDomDocument doc;
+            if (doc.setContent(v.toString())) {
+                QDomElement e = doc.documentElement().firstChild().toElement();
+                bool ok;
+                KoColor c = KoColor::fromXML(e, Integer16BitsColorDepthID.id(), &ok);
+                if (ok) {
+                    return c;
+                }
+            }
+            else {
+                QColor c(v.toString());
+                if (c.isValid()) {
+                    KoColor kc(c, KoColorSpaceRegistry::instance()->rgb8());
+                    return kc;
+                }
+            }
+            break;
+        }
+        case QVariant::Color:
+        {
+            QColor c = v.value<QColor>();
+            KoColor kc(c, KoColorSpaceRegistry::instance()->rgb8());
+            return kc;
+        }
+        case QVariant::Int:
+        {
+            QColor c(v.toInt());
+            if (c.isValid()) {
+                KoColor kc(c, KoColorSpaceRegistry::instance()->rgb8());
+                return kc;
+            }
+            break;
+        }
+        default:
+            ;
         }
     }
     return color;
@@ -278,7 +316,7 @@ void KisPropertiesConfiguration::dump() const
 {
     QMap<QString, QVariant>::Iterator it;
     for (it = d->properties.begin(); it != d->properties.end(); ++it) {
-        dbgKrita << it.key() << " = " << it.value();
+        qDebug() << it.key() << " = " << it.value() << it.value().typeName();
     }
 
 }
