@@ -42,6 +42,7 @@ struct Q_DECL_HIDDEN KisSelectionBasedLayer::Private
 {
 public:
     Private() : useSelectionInProjection(true) {}
+    Private(const Private &rhs) : useSelectionInProjection(rhs.useSelectionInProjection) {}
 
     KisSelectionSP selection;
     KisPaintDeviceSP paintDevice;
@@ -62,16 +63,19 @@ KisSelectionBasedLayer::KisSelectionBasedLayer(KisImageWSP image,
         initSelection();
     else
         setInternalSelection(selection);
-
-    m_d->paintDevice = new KisPaintDevice(this, image->colorSpace(), new KisDefaultBounds(image));
-    connect(image.data(), SIGNAL(sigSizeChanged(QPointF,QPointF)), SLOT(slotImageSizeChanged()));
+    KisImageSP imageSP = image.toStrongRef();
+    if (!imageSP) {
+        return;
+    }
+    m_d->paintDevice = KisPaintDeviceSP(new KisPaintDevice(this, imageSP->colorSpace(), KisDefaultBoundsSP(new KisDefaultBounds(image))));
+    connect(imageSP.data(), SIGNAL(sigSizeChanged(QPointF,QPointF)), SLOT(slotImageSizeChanged()));
 }
 
 KisSelectionBasedLayer::KisSelectionBasedLayer(const KisSelectionBasedLayer& rhs)
         : KisLayer(rhs)
         , KisIndirectPaintingSupport()
         , KisNodeFilterInterface(rhs)
-        , m_d(new Private())
+        , m_d(new Private(*rhs.m_d))
 {
     setInternalSelection(rhs.m_d->selection);
 
@@ -86,7 +90,7 @@ KisSelectionBasedLayer::~KisSelectionBasedLayer()
 
 void KisSelectionBasedLayer::initSelection()
 {
-    m_d->selection = new KisSelection(new KisDefaultBounds(image()));
+    m_d->selection = KisSelectionSP(new KisSelection(KisDefaultBoundsSP(new KisDefaultBounds(image()))));
     m_d->selection->pixelSelection()->setDefaultPixel(KoColor(Qt::white, m_d->selection->pixelSelection()->colorSpace()));
     m_d->selection->setParentNode(this);
     m_d->selection->updateProjection();
@@ -106,7 +110,7 @@ void KisSelectionBasedLayer::slotImageSizeChanged()
 
 void KisSelectionBasedLayer::setImage(KisImageWSP image)
 {
-    m_d->paintDevice->setDefaultBounds(new KisDefaultBounds(image));
+    m_d->paintDevice->setDefaultBounds(KisDefaultBoundsSP(new KisDefaultBounds(image)));
     KisLayer::setImage(image);
 
     connect(image.data(), SIGNAL(sigSizeChanged(QPointF,QPointF)), SLOT(slotImageSizeChanged()));
@@ -140,7 +144,7 @@ void KisSelectionBasedLayer::setUseSelectionInProjection(bool value) const
 
 KisSelectionSP KisSelectionBasedLayer::fetchComposedInternalSelection(const QRect &rect) const
 {
-    if (!m_d->selection) return 0;
+    if (!m_d->selection) return KisSelectionSP();
     m_d->selection->updateProjection(rect);
 
     KisSelectionSP tempSelection = m_d->selection;
@@ -170,9 +174,14 @@ void KisSelectionBasedLayer::copyOriginalToProjection(const KisPaintDeviceSP ori
 
     if (m_d->useSelectionInProjection) {
         tempSelection = fetchComposedInternalSelection(rect);
+
+        /**
+         * When we paint with a selection, the deselected areas will *not* be
+         * overwritten by copyAreaOptimized(), so we need to clear them beforehand
+         */
+        projection->clear(rect);
     }
 
-    projection->clear(rect);
     KisPainter::copyAreaOptimized(rect.topLeft(), original, projection, rect, tempSelection);
 }
 
@@ -189,15 +198,15 @@ QRect KisSelectionBasedLayer::needRect(const QRect &rect, PositionToFilthy pos)
     return rect;
 }
 
-void KisSelectionBasedLayer::resetCache(const KoColorSpace *colorSpace)
+void KisSelectionBasedLayer::resetCache()
 {
-    if (!colorSpace)
-        colorSpace = image()->colorSpace();
+    KisImageSP imageSP = image().toStrongRef();
+    if (!imageSP) {
+        return;
+    }
 
-    if (!m_d->paintDevice ||
-            *m_d->paintDevice->colorSpace() != *colorSpace) {
-
-        m_d->paintDevice = new KisPaintDevice(this, colorSpace, new KisDefaultBounds(image()));
+    if (!m_d->paintDevice || *m_d->paintDevice->colorSpace() != *imageSP->colorSpace()) {
+        m_d->paintDevice = KisPaintDeviceSP(new KisPaintDevice(KisNodeWSP(this), imageSP->colorSpace(), new KisDefaultBounds(image())));
     } else {
         m_d->paintDevice->clear();
     }
@@ -218,11 +227,15 @@ void KisSelectionBasedLayer::setInternalSelection(KisSelectionSP selection)
         m_d->selection = 0;
     }
 
-    if (selection->pixelSelection()->defaultBounds()->bounds() != image()->bounds()) {
+    KisImageSP imageSP = image().toStrongRef();
+    if (!imageSP) {
+        return;
+    }
+    if (selection->pixelSelection()->defaultBounds()->bounds() != imageSP->bounds()) {
         qWarning() << "WARNING: KisSelectionBasedLayer::setInternalSelection"
                    << "New selection has suspicious default bounds";
         qWarning() << "WARNING:" << ppVar(selection->pixelSelection()->defaultBounds()->bounds());
-        qWarning() << "WARNING:" << ppVar(image()->bounds());
+        qWarning() << "WARNING:" << ppVar(imageSP->bounds());
     }
 }
 
@@ -250,11 +263,6 @@ void KisSelectionBasedLayer::setY(qint32 y)
     }
 }
 
-void KisSelectionBasedLayer::setDirty(const QRect & rect)
-{
-    KisLayer::setDirty(rect);
-}
-
 KisKeyframeChannel *KisSelectionBasedLayer::requestKeyframeChannel(const QString &id)
 {
     if (id == KisKeyframeChannel::Content.id()) {
@@ -269,24 +277,34 @@ KisKeyframeChannel *KisSelectionBasedLayer::requestKeyframeChannel(const QString
 void KisSelectionBasedLayer::setDirty()
 {
     Q_ASSERT(image());
-
-    setDirty(image()->bounds());
+    KisImageSP imageSP = image().toStrongRef();
+    if (!imageSP) {
+        return;
+    }
+    setDirty(imageSP->bounds());
 }
 
 QRect KisSelectionBasedLayer::extent() const
 {
     Q_ASSERT(image());
-
+    KisImageSP imageSP = image().toStrongRef();
+    if (!imageSP) {
+        return QRect();
+    }
     return m_d->selection ?
-           m_d->selection->selectedRect() : image()->bounds();
+           m_d->selection->selectedRect() : imageSP->bounds();
 }
 
 QRect KisSelectionBasedLayer::exactBounds() const
 {
     Q_ASSERT(image());
+    KisImageSP imageSP = image().toStrongRef();
+    if (!imageSP) {
+        return QRect();
+    }
 
     return m_d->selection ?
-           m_d->selection->selectedExactRect() : image()->bounds();
+           m_d->selection->selectedExactRect() : imageSP->bounds();
 }
 
 QImage KisSelectionBasedLayer::createThumbnail(qint32 w, qint32 h)
