@@ -52,7 +52,7 @@ public:
      */
     KisSelectionBasedLayer(KisImageWSP image, const QString &name, KisSelectionSP selection, KisFilterConfigurationSP filterConfig, bool useGeneratorRegistry = false);
     KisSelectionBasedLayer(const KisSelectionBasedLayer& rhs);
-    virtual ~KisSelectionBasedLayer();
+    ~KisSelectionBasedLayer() override;
 
 
     /**
@@ -85,7 +85,6 @@ public:
      * as our extent() function doesn't fit for this
      */
     void setDirty() override;
-    void setDirty(const QRect & rect) override;
 
 public:
 
