@@ -35,7 +35,7 @@ class KRITAIMAGE_EXPORT KisTimedSignalThreshold : public QObject
     Q_OBJECT
 public:
     KisTimedSignalThreshold(int delay, int cancelDelay = -1, QObject *parent = 0);
-    ~KisTimedSignalThreshold();
+    ~KisTimedSignalThreshold() override;
 
 public Q_SLOTS:
     /**
@@ -62,7 +62,7 @@ public Q_SLOTS:
 
 
     /**
-     * The peiod of time, after which the the signal will be emitted
+     * The peiod of time, after which the signal will be emitted
      */
     void setDelayThreshold(int delay, int cancelDelay = -1);
 
