@@ -28,9 +28,11 @@
 #include "kis_strokes_queue.h"
 
 #include "kis_queues_progress_updater.h"
+#include "KisUpdateSchedulerConfigNotifier.h"
 
 #include <QReadWriteLock>
 #include "kis_lazy_wait_condition.h"
+#include <mutex>
 
 //#define DEBUG_BALANCING
 
@@ -48,6 +50,7 @@
 struct Q_DECL_HIDDEN KisUpdateScheduler::Private {
     Private(KisUpdateScheduler *_q, KisProjectionUpdateListener *p)
         : q(_q)
+        , updaterContext(KisImageConfig().maxNumberOfThreads(), q)
         , projectionUpdateListener(p)
     {}
 
@@ -57,17 +60,23 @@ struct Q_DECL_HIDDEN KisUpdateScheduler::Private {
     KisStrokesQueue strokesQueue;
     KisUpdaterContext updaterContext;
     bool processingBlocked = false;
-    qreal balancingRatio = 1.0; // updates-queue-size/strokes-queue-size
+    qreal defaultBalancingRatio = 1.0; // desired strokes-queue-size / updates-queue-size
     KisProjectionUpdateListener *projectionUpdateListener;
     KisQueuesProgressUpdater *progressUpdater = 0;
 
     QAtomicInt updatesLockCounter;
     QReadWriteLock updatesStartLock;
     KisLazyWaitCondition updatesFinishedCondition;
+
+    qreal balancingRatio() const {
+        const qreal strokeRatioOverride = strokesQueue.balancingRatioOverride();
+        return strokeRatioOverride > 0 ? strokeRatioOverride : defaultBalancingRatio;
+    }
 };
 
-KisUpdateScheduler::KisUpdateScheduler(KisProjectionUpdateListener *projectionUpdateListener)
-    : m_d(new Private(this, projectionUpdateListener))
+KisUpdateScheduler::KisUpdateScheduler(KisProjectionUpdateListener *projectionUpdateListener, QObject *parent)
+    : QObject(parent),
+      m_d(new Private(this, projectionUpdateListener))
 {
     updateSettings();
     connectSignals();
@@ -84,6 +93,28 @@ KisUpdateScheduler::~KisUpdateScheduler()
     delete m_d;
 }
 
+void KisUpdateScheduler::setThreadsLimit(int value)
+{
+    KIS_SAFE_ASSERT_RECOVER_RETURN(!m_d->processingBlocked);
+
+    /**
+     * Thread limit can be changed without the full-featured barrier
+     * lock, we can avoid waiting for all the jobs to complete. We
+     * should just ensure there is no more jobs in the updater context.
+     */
+    lock();
+    m_d->updaterContext.lock();
+    m_d->updaterContext.setThreadsLimit(value);
+    m_d->updaterContext.unlock();
+    unlock(false);
+}
+
+int KisUpdateScheduler::threadsLimit() const
+{
+    std::lock_guard<KisUpdaterContext> l(m_d->updaterContext);
+    return m_d->updaterContext.threadsLimit();
+}
+
 void KisUpdateScheduler::connectSignals()
 {
     connect(&m_d->updaterContext, SIGNAL(sigContinueUpdate(const QRect&)),
@@ -95,13 +126,16 @@ void KisUpdateScheduler::connectSignals()
 
     connect(&m_d->updaterContext, SIGNAL(sigSpareThreadAppeared()),
             SLOT(spareThreadAppeared()), Qt::DirectConnection);
+
+    connect(KisUpdateSchedulerConfigNotifier::instance(), SIGNAL(configChanged()),
+            SLOT(updateSettings()));
 }
 
 void KisUpdateScheduler::setProgressProxy(KoProgressProxy *progressProxy)
 {
     delete m_d->progressUpdater;
     m_d->progressUpdater = progressProxy ?
-        new KisQueuesProgressUpdater(progressProxy) : 0;
+        new KisQueuesProgressUpdater(progressProxy, this) : 0;
 }
 
 void KisUpdateScheduler::progressUpdate()
@@ -126,7 +160,13 @@ void KisUpdateScheduler::progressUpdate()
     }
 }
 
-void KisUpdateScheduler::updateProjection(KisNodeSP node, const QRect& rc, const QRect &cropRect)
+void KisUpdateScheduler::updateProjection(KisNodeSP node, const QVector<QRect> &rects, const QRect &cropRect)
+{
+    m_d->updatesQueue.addUpdateJob(node, rects, cropRect, currentLevelOfDetail());
+    processQueues();
+}
+
+void KisUpdateScheduler::updateProjection(KisNodeSP node, const QRect &rc, const QRect &cropRect)
 {
     m_d->updatesQueue.addUpdateJob(node, rc, cropRect, currentLevelOfDetail());
     processQueues();
@@ -280,7 +320,9 @@ void KisUpdateScheduler::updateSettings()
     m_d->updatesQueue.updateSettings();
 
     KisImageConfig config;
-    m_d->balancingRatio = config.schedulerBalancingRatio();
+    m_d->defaultBalancingRatio = config.schedulerBalancingRatio();
+
+    setThreadsLimit(config.maxNumberOfThreads());
 }
 
 void KisUpdateScheduler::lock()
@@ -325,13 +367,15 @@ void KisUpdateScheduler::waitForDone()
 
 bool KisUpdateScheduler::tryBarrierLock()
 {
-    if(!m_d->updatesQueue.isEmpty() || !m_d->strokesQueue.isEmpty())
+    if(!m_d->updatesQueue.isEmpty() || !m_d->strokesQueue.isEmpty()) {
         return false;
+    }
 
     m_d->processingBlocked = true;
     m_d->updaterContext.waitForDone();
     if(!m_d->updatesQueue.isEmpty() || !m_d->strokesQueue.isEmpty()) {
         m_d->processingBlocked = false;
+        processQueues();
         return false;
     }
 
@@ -363,7 +407,7 @@ void KisUpdateScheduler::processQueues()
             tryProcessUpdatesQueue();
         }
     }
-    else if(m_d->balancingRatio * m_d->strokesQueue.sizeMetric() > m_d->updatesQueue.sizeMetric()) {
+    else if(m_d->balancingRatio() * m_d->strokesQueue.sizeMetric() > m_d->updatesQueue.sizeMetric()) {
         DEBUG_BALANCING_METRICS("STROKES", "N");
         m_d->strokesQueue.processQueue(m_d->updaterContext,
                                         !m_d->updatesQueue.isEmpty());
