@@ -39,8 +39,18 @@ class KRITAIMAGE_EXPORT KisUpdateScheduler : public QObject, public KisStrokesFa
     Q_OBJECT
 
 public:
-    KisUpdateScheduler(KisProjectionUpdateListener *projectionUpdateListener);
-    virtual ~KisUpdateScheduler();
+    KisUpdateScheduler(KisProjectionUpdateListener *projectionUpdateListener, QObject *parent = 0);
+    ~KisUpdateScheduler() override;
+
+    /**
+     * Set the number of threads used by the scheduler
+     */
+    void setThreadsLimit(int value);
+
+    /**
+     * Return the number of threads available to the scheduler
+     */
+    int threadsLimit() const;
 
     /**
      * Sets the proxy that is going to be notified about the progress
@@ -69,11 +79,6 @@ public:
      */
     void unlock(bool resetLodLevels = true);
 
-    /**
-     * Called when it is necessary to reread configuration
-     */
-    void updateSettings();
-
     /**
      * Waits until all the running jobs are finished.
      *
@@ -130,16 +135,17 @@ public:
      */
     void unblockUpdates();
 
-    void updateProjection(KisNodeSP node, const QRect& rc, const QRect &cropRect);
+    void updateProjection(KisNodeSP node, const QVector<QRect> &rects, const QRect &cropRect);
+    void updateProjection(KisNodeSP node, const QRect &rc, const QRect &cropRect);
     void updateProjectionNoFilthy(KisNodeSP node, const QRect& rc, const QRect &cropRect);
     void fullRefreshAsync(KisNodeSP root, const QRect& rc, const QRect &cropRect);
     void fullRefresh(KisNodeSP root, const QRect& rc, const QRect &cropRect);
     void addSpontaneousJob(KisSpontaneousJob *spontaneousJob);
 
-    KisStrokeId startStroke(KisStrokeStrategy *strokeStrategy);
-    void addJob(KisStrokeId id, KisStrokeJobData *data);
-    void endStroke(KisStrokeId id);
-    bool cancelStroke(KisStrokeId id);
+    KisStrokeId startStroke(KisStrokeStrategy *strokeStrategy) override;
+    void addJob(KisStrokeId id, KisStrokeJobData *data) override;
+    void endStroke(KisStrokeId id) override;
+    bool cancelStroke(KisStrokeId id) override;
 
     /**
      * Sets the desired level of detail on which the strokes should
@@ -204,6 +210,12 @@ protected:
     void connectSignals();
     void processQueues();
 
+protected Q_SLOTS:
+    /**
+     * Called when it is necessary to reread configuration
+     */
+    void updateSettings();
+
 private Q_SLOTS:
     void continueUpdate(const QRect &rect);
     void doSomeUsefulWork();
