@@ -391,7 +391,7 @@ void KisRecordedPaintActionFactory::setupPaintAction(KisRecordedPaintAction* act
         KisFilterConfigurationSP config = 0;
         if (g)
         {
-            config = g->defaultConfiguration(0);
+            config = g->defaultConfiguration();
             QDomElement paramsElt = elt.firstChildElement("Generator");
             if (config && !paramsElt.isNull()) {
                 config->fromXML(paramsElt);
@@ -437,7 +437,7 @@ KoColor KisRecordedPaintActionFactory::colorFromXML(const QDomElement& elt, cons
     KoColor bC;
 
     if (!colorElt.isNull()) {
-        bC = KoColor::fromXML(colorElt.firstChildElement(), Integer8BitsColorDepthID.id(), QHash<QString, QString>());
+        bC = KoColor::fromXML(colorElt.firstChildElement(), Integer8BitsColorDepthID.id());
         bC.setOpacity(quint8(255));
         dbgImage << elementName << " color : " << bC.toQColor();
     } else {
