@@ -68,15 +68,15 @@ public:
     {
     }
 
-    void run() {
+    void run() override {
     }
 
-    bool overrides(const KisSpontaneousJob *otherJob) {
+    bool overrides(const KisSpontaneousJob *otherJob) override {
         Q_UNUSED(otherJob);
         return m_overridesEverything;
     }
 
-    int levelOfDetail() const {
+    int levelOfDetail() const override {
         return m_lod;
     }
 
@@ -95,13 +95,14 @@ public:
       m_isMarked(false)
     {}
 
-    void run(KisStrokeJobData *data) {
+    void run(KisStrokeJobData *data) override {
         Q_UNUSED(data);
 
         globalExecutedDabs << m_name;
     }
 
-    QString name() {
+    virtual QString name(KisStrokeJobData *data) const {
+        Q_UNUSED(data);
         return m_name;
     }
 
@@ -122,22 +123,71 @@ class KisTestingStrokeJobData : public KisStrokeJobData
 {
 public:
     KisTestingStrokeJobData(Sequentiality sequentiality = SEQUENTIAL,
-                             Exclusivity exclusivity = NORMAL)
-        : KisStrokeJobData(sequentiality, exclusivity)
+                            Exclusivity exclusivity = NORMAL,
+                            bool addMutatedJobs = false,
+                            const QString &customSuffix = QString())
+        : KisStrokeJobData(sequentiality, exclusivity),
+          m_addMutatedJobs(addMutatedJobs),
+          m_customSuffix(customSuffix)
     {
     }
 
     KisTestingStrokeJobData(const KisTestingStrokeJobData &rhs)
-        : KisStrokeJobData(rhs)
+        : KisStrokeJobData(rhs),
+          m_addMutatedJobs(rhs.m_addMutatedJobs)
     {
     }
 
-    KisStrokeJobData* createLodClone(int levelOfDetail) {
+    KisStrokeJobData* createLodClone(int levelOfDetail) override {
         Q_UNUSED(levelOfDetail);
         return new KisTestingStrokeJobData(*this);
     }
+
+    bool m_addMutatedJobs = false;
+    bool m_isMutated = false;
+    QString m_customSuffix;
 };
 
+class KisMutatableDabStrategy : public KisNoopDabStrategy
+{
+public:
+    KisMutatableDabStrategy(const QString &name, KisStrokeStrategy *parentStrokeStrategy)
+        : KisNoopDabStrategy(name),
+          m_parentStrokeStrategy(parentStrokeStrategy)
+    {
+    }
+
+    void run(KisStrokeJobData *data) override {
+        KisTestingStrokeJobData *td = dynamic_cast<KisTestingStrokeJobData*>(data);
+
+        if (td && td->m_isMutated) {
+            globalExecutedDabs << QString("%1_mutated").arg(name(data));
+        } else if (td && td->m_addMutatedJobs) {
+            globalExecutedDabs << name(data);
+
+            for (int i = 0; i < 3; i++) {
+                KisTestingStrokeJobData *newData =
+                    new KisTestingStrokeJobData(td->sequentiality(), td->exclusivity(), false);
+                newData->m_isMutated = true;
+                m_parentStrokeStrategy->addMutatedJob(newData);
+            }
+        } else {
+            globalExecutedDabs << name(data);
+        }
+    }
+
+    virtual QString name(KisStrokeJobData *data) const {
+        const QString baseName = KisNoopDabStrategy::name(data);
+
+        KisTestingStrokeJobData *td = dynamic_cast<KisTestingStrokeJobData*>(data);
+        return !td || td->m_customSuffix.isEmpty() ? baseName : QString("%1_%2").arg(baseName).arg(td->m_customSuffix);
+    }
+
+private:
+    KisStrokeStrategy *m_parentStrokeStrategy = 0;
+};
+
+
 class KisTestingStrokeStrategy : public KisStrokeStrategy
 {
 public:
@@ -166,26 +216,26 @@ public:
         m_prefix = QString("clone%1_%2").arg(levelOfDetail).arg(m_prefix);
     }
 
-    KisStrokeJobStrategy* createInitStrategy() {
+    KisStrokeJobStrategy* createInitStrategy() override {
         return m_forceAllowInitJob || !m_inhibitServiceJobs ?
             new KisNoopDabStrategy(m_prefix + "init") : 0;
     }
 
-    KisStrokeJobStrategy* createFinishStrategy() {
+    KisStrokeJobStrategy* createFinishStrategy() override {
         return !m_inhibitServiceJobs ?
             new KisNoopDabStrategy(m_prefix + "finish") : 0;
     }
 
-    KisStrokeJobStrategy* createCancelStrategy() {
+    KisStrokeJobStrategy* createCancelStrategy() override {
         return m_forceAllowCancelJob || !m_inhibitServiceJobs ?
             new KisNoopDabStrategy(m_prefix + "cancel") : 0;
     }
 
-    KisStrokeJobStrategy* createDabStrategy() {
-        return new KisNoopDabStrategy(m_prefix + "dab");
+    KisStrokeJobStrategy* createDabStrategy() override {
+        return new KisMutatableDabStrategy(m_prefix + "dab", this);
     }
 
-    KisStrokeStrategy* createLodClone(int levelOfDetail) {
+    KisStrokeStrategy* createLodClone(int levelOfDetail) override {
         return new KisTestingStrokeStrategy(*this, levelOfDetail);
     }
 
@@ -199,7 +249,7 @@ public:
         int m_seqNo;
     };
 
-    KisStrokeJobData* createCancelData() {
+    KisStrokeJobData* createCancelData() override {
         return new CancelData(m_cancelSeqNo++);
     }
 
@@ -214,9 +264,9 @@ private:
 inline QString getJobName(KisStrokeJob *job) {
     KisNoopDabStrategy *pointer =
         dynamic_cast<KisNoopDabStrategy*>(job->testingGetDabStrategy());
-    Q_ASSERT(pointer);
+    KIS_ASSERT(pointer);
 
-    return pointer->name();
+    return pointer->name(job->testingGetDabData());
 }
 
 inline int cancelSeqNo(KisStrokeJob *job) {
