@@ -63,6 +63,7 @@
 #include <InfoObject.h>
 #include <Node.h>
 #include <Selection.h>
+#include <LibKisUtils.h>
 
 struct Document::Private {
     Private() {}
@@ -112,28 +113,10 @@ Node *Document::activeNode() const
         }
     }
     if (activeNodes.size() > 0) {
-        KisNodeSP activeNode = activeNodes.first();
-        if (qobject_cast<const KisGroupLayer*>(activeNode.data())) {
-            return new GroupLayer(KisGroupLayerSP(dynamic_cast<KisGroupLayer*>(activeNode.data())));
-        } else if (qobject_cast<const KisFileLayer*>(activeNode.data())) {
-            return new FileLayer(KisFileLayerSP(dynamic_cast<KisFileLayer*>(activeNode.data())));
-        } else if (qobject_cast<const KisAdjustmentLayer*>(activeNode.data())) {
-            return new FilterLayer(KisAdjustmentLayerSP(dynamic_cast<KisAdjustmentLayer*>(activeNode.data())));
-        } else  if (qobject_cast<const KisGeneratorLayer*>(activeNode.data())) {
-            return new FillLayer(KisGeneratorLayerSP(dynamic_cast<KisGeneratorLayer*>(activeNode.data())));
-        } else if (qobject_cast<const KisCloneLayer*>(activeNode.data())) {
-            return new CloneLayer(KisCloneLayerSP(dynamic_cast<KisCloneLayer*>(activeNode.data())));
-        } else  if (qobject_cast<const KisShapeLayer*>(activeNode.data())) {
-            return new VectorLayer(KisShapeLayerSP(dynamic_cast<KisShapeLayer*>(activeNode.data())));
-        } else  if (qobject_cast<const KisFilterMask*>(activeNode.data())) {
-            return new FilterMask(d->document->image(), KisFilterMaskSP(dynamic_cast<KisFilterMask*>(activeNode.data())));
-        } else  if (qobject_cast<const KisSelectionMask*>(activeNode.data())) {
-            return new SelectionMask(d->document->image(), KisSelectionMaskSP(dynamic_cast<KisSelectionMask*>(activeNode.data())));
-        } else{
-            return new Node(d->document->image(), activeNode);
-        }
+        QList<Node*> nodes = LibKisUtils::createNodeList(activeNodes, d->document->image());
+        return nodes.first();
     }
-    return new Node(d->document->image(), d->document->image()->root()->firstChild());
+    return 0;
 }
 
 void Document::setActiveNode(Node* value)
@@ -389,28 +372,28 @@ double Document::xRes() const
 {
     if (!d->document) return 0.0;
     if (!d->document->image()) return 0.0;
-    return d->document->image()->xRes();
+    return d->document->image()->xRes()*72.0;
 }
 
 void Document::setXRes(double xRes) const
 {
     if (!d->document) return;
     if (!d->document->image()) return;
-    d->document->image()->setResolution(xRes, d->document->image()->yRes());
+    d->document->image()->setResolution(xRes/72.0, d->document->image()->yRes());
 }
 
 double Document::yRes() const
 {
     if (!d->document) return 0.0;
     if (!d->document->image()) return 0.0;
-    return d->document->image()->yRes();
+    return d->document->image()->yRes()*72.0;
 }
 
 void Document::setYRes(double yRes) const
 {
     if (!d->document) return;
     if (!d->document->image()) return;
-    d->document->image()->setResolution(d->document->image()->xRes(), yRes);
+    d->document->image()->setResolution(d->document->image()->xRes(), yRes/72.0);
 }
 
 
@@ -495,7 +478,7 @@ void Document::scaleImage(int w, int h, int xres, int yres, QString strategy)
     KisFilterStrategy *actualStrategy = KisFilterStrategyRegistry::instance()->get(strategy);
     if (!actualStrategy) actualStrategy = KisFilterStrategyRegistry::instance()->get("Bicubic");
 
-    image->scaleImage(rc.size(), xres, yres, actualStrategy);
+    image->scaleImage(rc.size(), xres/72, yres/72, actualStrategy);
 }
 
 void Document::rotateImage(double radians)
@@ -531,9 +514,11 @@ bool Document::saveAs(const QString &filename)
 
     const QString outputFormatString = KisMimeDatabase::mimeTypeForFile(filename, false);
     const QByteArray outputFormat = outputFormatString.toLatin1();
-
+    QUrl oldUrl = d->document->url();
+    d->document->setUrl(QUrl::fromLocalFile(filename));
     bool retval = d->document->saveAs(QUrl::fromLocalFile(filename), outputFormat, true);
     d->document->waitForSavingToComplete();
+    d->document->setUrl(oldUrl);
 
     return retval;
 }
@@ -546,37 +531,37 @@ Node* Document::createNode(const QString &name, const QString &nodeType)
 
     Node *node = 0;
 
-    if (nodeType == "paintlayer") {
+    if (nodeType.toLower()== "paintlayer") {
         node = new Node(image, new KisPaintLayer(image, name, OPACITY_OPAQUE_U8));
     }
-    else if (nodeType == "grouplayer") {
+    else if (nodeType.toLower()  == "grouplayer") {
         node = new Node(image, new KisGroupLayer(image, name, OPACITY_OPAQUE_U8));
     }
-    else if (nodeType == "filelayer") {
+    else if (nodeType.toLower()  == "filelayer") {
         node = new Node(image, new KisFileLayer(image, name, OPACITY_OPAQUE_U8));
     }
-    else if (nodeType == "filterlayer") {
+    else if (nodeType.toLower()  == "filterlayer") {
         node = new Node(image, new KisAdjustmentLayer(image, name, 0, 0));
     }
-    else if (nodeType == "filllayer") {
+    else if (nodeType.toLower()  == "filllayer") {
         node = new Node(image, new KisGeneratorLayer(image, name, 0, 0));
     }
-    else if (nodeType == "clonelayer") {
+    else if (nodeType.toLower()  == "clonelayer") {
         node = new Node(image, new KisCloneLayer(0, image, name, OPACITY_OPAQUE_U8));
     }
-    else if (nodeType == "vectorlayer") {
+    else if (nodeType.toLower()  == "vectorlayer") {
         node = new Node(image, new KisShapeLayer(d->document->shapeController(), image, name, OPACITY_OPAQUE_U8));
     }
-    else if (nodeType == "transparencymask") {
+    else if (nodeType.toLower()  == "transparencymask") {
         node = new Node(image, new KisTransparencyMask());
     }
-    else if (nodeType == "filtermask") {
+    else if (nodeType.toLower()  == "filtermask") {
         node = new Node(image, new KisFilterMask());
     }
-    else if (nodeType == "transformmask") {
+    else if (nodeType.toLower()  == "transformmask") {
         node = new Node(image, new KisTransformMask());
     }
-    else if (nodeType == "selectionmask") {
+    else if (nodeType.toLower()  == "selectionmask") {
         node = new Node(image, new KisSelectionMask(image));
     }
     return node;
@@ -591,13 +576,13 @@ GroupLayer *Document::createGroupLayer(const QString &name)
     return new GroupLayer(image, name);
 }
 
-FileLayer *Document::createFileLayer(const QString &name, const QString FileName, const QString ScalingMethod)
+FileLayer *Document::createFileLayer(const QString &name, const QString fileName, const QString scalingMethod)
 {
     if (!d->document) return 0;
     if (!d->document->image()) return 0;
     KisImageSP image = d->document->image();
 
-    return new FileLayer(image, name, fileName(), FileName, ScalingMethod);
+    return new FileLayer(image, name, this->fileName(), fileName, scalingMethod);
 }
 
 FilterLayer *Document::createFilterLayer(const QString &name, Filter &filter, Selection &selection)
@@ -609,18 +594,23 @@ FilterLayer *Document::createFilterLayer(const QString &name, Filter &filter, Se
     return new FilterLayer(image, name, filter, selection);
 }
 
-FillLayer *Document::createFillLayer(const QString &name, const QString filterName, InfoObject &configuration, Selection &selection)
+FillLayer *Document::createFillLayer(const QString &name, const QString generatorName, InfoObject &configuration, Selection &selection)
 {
     if (!d->document) return 0;
     if (!d->document->image()) return 0;
     KisImageSP image = d->document->image();
 
-    KisFilterConfigurationSP config = KisGeneratorRegistry::instance()->value(filterName)->defaultConfiguration();
-    Q_FOREACH(const QString property, configuration.properties().keys()) {
-        config->setProperty(property, configuration.property(property));
-    }
+    KisGeneratorSP generator = KisGeneratorRegistry::instance()->value(generatorName);
+    if (generator) {
 
-    return new FillLayer(image, name, config, selection);
+        KisFilterConfigurationSP config = generator->defaultConfiguration();
+        Q_FOREACH(const QString property, configuration.properties().keys()) {
+            config->setProperty(property, configuration.property(property));
+        }
+
+        return new FillLayer(image, name, config, selection);
+    }
+    return 0;
 }
 
 CloneLayer *Document::createCloneLayer(const QString &name, const Node *source)
