@@ -3,6 +3,7 @@
                  2004 Boudewijn Rempt <boud@valdyas.org>
                  2004 Adrian Page <adrian@pagenet.plus.com>
                  2004, 2007 Sven Langkamp <sven.langkamp@gmail.com>
+                 2017 Wolthera van Hövell tot Westerflier <griffinvalley@gmail.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -101,8 +102,8 @@ protected:
     public:
         static RGBColorInterpolationStrategy *instance();
 
-        virtual void colorAt(KoColor& dst, qreal t, const KoColor& start, const KoColor& end) const;
-        virtual int type() const {
+        void colorAt(KoColor& dst, qreal t, const KoColor& start, const KoColor& end) const override;
+        int type() const override {
             return COLOR_INTERP_RGB;
         }
 
@@ -118,8 +119,8 @@ protected:
     public:
         static HSVCWColorInterpolationStrategy *instance();
 
-        virtual void colorAt(KoColor& dst, qreal t, const KoColor& start, const KoColor& end) const;
-        virtual int type() const {
+        void colorAt(KoColor& dst, qreal t, const KoColor& start, const KoColor& end) const override;
+        int type() const override {
             return COLOR_INTERP_HSV_CW;
         }
     private:
@@ -134,8 +135,8 @@ protected:
     public:
         static HSVCCWColorInterpolationStrategy *instance();
 
-        virtual void colorAt(KoColor& dst, qreal t, const KoColor& start, const KoColor& end) const;
-        virtual int type() const {
+        void colorAt(KoColor& dst, qreal t, const KoColor& start, const KoColor& end) const override;
+        int type() const override {
             return COLOR_INTERP_HSV_CCW;
         }
     private:
@@ -160,8 +161,8 @@ protected:
     public:
         static LinearInterpolationStrategy *instance();
 
-        virtual qreal valueAt(qreal t, qreal middle) const;
-        virtual int type() const {
+        qreal valueAt(qreal t, qreal middle) const override;
+        int type() const override {
             return INTERP_LINEAR;
         }
 
@@ -181,8 +182,8 @@ protected:
     public:
         static CurvedInterpolationStrategy *instance();
 
-        virtual qreal valueAt(qreal t, qreal middle) const;
-        virtual int type() const {
+        qreal valueAt(qreal t, qreal middle) const override;
+        int type() const override {
             return INTERP_CURVED;
         }
     private:
@@ -197,8 +198,8 @@ protected:
     public:
         static SphereIncreasingInterpolationStrategy *instance();
 
-        virtual qreal valueAt(qreal t, qreal middle) const;
-        virtual int type() const {
+        qreal valueAt(qreal t, qreal middle) const override;
+        int type() const override {
             return INTERP_SPHERE_INCREASING;
         }
     private:
@@ -212,8 +213,8 @@ protected:
     public:
         static SphereDecreasingInterpolationStrategy *instance();
 
-        virtual qreal valueAt(qreal t, qreal middle) const;
-        virtual int type() const {
+        qreal valueAt(qreal t, qreal middle) const override;
+        int type() const override {
             return INTERP_SPHERE_DECREASING;
         }
     private:
@@ -227,8 +228,8 @@ protected:
     public:
         static SineInterpolationStrategy *instance();
 
-        virtual qreal valueAt(qreal t, qreal middle) const;
-        virtual int type() const {
+        qreal valueAt(qreal t, qreal middle) const override;
+        int type() const override {
             return INTERP_SINE;
         }
     private:
@@ -257,21 +258,21 @@ class KRITAPIGMENT_EXPORT KoSegmentGradient : public KoAbstractGradient
 {
 
 public:
-    explicit KoSegmentGradient(const QString &file);
-    virtual ~KoSegmentGradient();
+    explicit KoSegmentGradient(const QString &file = QString());
+    ~KoSegmentGradient() override;
 
-    KoAbstractGradient* clone() const;
+    KoAbstractGradient* clone() const override;
 
     /// reimplemented
-    virtual bool load();
-    virtual bool loadFromDevice(QIODevice *dev);
+    bool load() override;
+    bool loadFromDevice(QIODevice *dev) override;
 
     /// not implemented
-    virtual bool save();
-    virtual bool saveToDevice(QIODevice* dev) const;
+    bool save() override;
+    bool saveToDevice(QIODevice* dev) const override;
 
     /// reimplemented
-    void colorAt(KoColor& dst, qreal t) const;
+    void colorAt(KoColor& dst, qreal t) const override;
 
     /**
      * Returns the segment at a given position
@@ -281,10 +282,22 @@ public:
     KoGradientSegment *segmentAt(qreal t) const;
 
     /// reimplemented
-    virtual QGradient* toQGradient() const;
+    QGradient* toQGradient() const override;
 
     /// reimplemented
-    QString defaultFileExtension() const;
+    QString defaultFileExtension() const override;
+
+    /**
+     * @brief toXML
+     * convert the gradient to xml.
+     */
+    void toXML(QDomDocument& doc, QDomElement& gradientElt) const;
+    /**
+     * @brief fromXML
+     * get a segment gradient from xml.
+     * @return gradient
+     */
+    static KoSegmentGradient fromXML(const QDomElement& elt);
 
         /**
      * a gradient colour picker can consist of one or more segments.
