@@ -84,7 +84,7 @@
 #include <kis_debug.h>
 #include "kis_action_registry.h"
 #include <kis_brush_server.h>
-#include <kis_resource_server_provider.h>
+#include <KisResourceServerProvider.h>
 #include <KoResourceServerProvider.h>
 #include "kis_image_barrier_locker.h"
 #include "opengl/kis_opengl.h"
@@ -230,6 +230,7 @@ void KisApplication::initializeGlobals(const KisApplicationArguments &args)
 
 void KisApplication::addResourceTypes()
 {
+//    qDebug() << "addResourceTypes();";
     // All Krita's resource types
     KoResourcePaths::addResourceType("kis_pics", "data", "/pics/");
     KoResourcePaths::addResourceType("kis_images", "data", "/images/");
@@ -273,6 +274,7 @@ void KisApplication::addResourceTypes()
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/tags/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/asl/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/bundles/");
+    d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/brushes/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/gradients/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/paintoppresets/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/palettes/");
@@ -282,6 +284,7 @@ void KisApplication::addResourceTypes()
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/input/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/pykrita/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/symbols/");
+    d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/color-schemes/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/preset_icons/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/preset_icons/tool_icons/");
     d.mkpath(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/preset_icons/emblem_icons/");
@@ -292,41 +295,46 @@ void KisApplication::addResourceTypes()
 
 void KisApplication::loadResources()
 {
-    setSplashScreenLoadingText(i18n("Loading Gradients..."));
-    processEvents();
-    KoResourceServerProvider::instance()->gradientServer(true);
+//    qDebug() << "loadResources();";
 
-
-    // Load base resources
-    setSplashScreenLoadingText(i18n("Loading Patterns..."));
+    setSplashScreenLoadingText(i18n("Loading Resources..."));
     processEvents();
-    KoResourceServerProvider::instance()->patternServer(true);
+    KoResourceServerProvider::instance();
 
-    setSplashScreenLoadingText(i18n("Loading Palettes..."));
+    setSplashScreenLoadingText(i18n("Loading Brush Presets..."));
     processEvents();
-    KoResourceServerProvider::instance()->paletteServer(false);
+    KisResourceServerProvider::instance();
 
     setSplashScreenLoadingText(i18n("Loading Brushes..."));
     processEvents();
-    KisBrushServer::instance()->brushServer(true);
+    KisBrushServer::instance()->brushServer();
 
-    // load paintop presets
-    setSplashScreenLoadingText(i18n("Loading Paint Operations..."));
+    setSplashScreenLoadingText(i18n("Loading Bundles..."));
     processEvents();
-    KisResourceServerProvider::instance()->paintOpPresetServer(true);
+    KisResourceBundleServerProvider::instance();
+}
 
-    // load symbols
-    setSplashScreenLoadingText(i18n("Loading SVG Symbol Collections..."));
-    processEvents();
-    KoResourceServerProvider::instance()->svgSymbolCollectionServer(true);
+void KisApplication::loadResourceTags()
+{
+//    qDebug() << "loadResourceTags()";
 
-    setSplashScreenLoadingText(i18n("Loading Resource Bundles..."));
-    processEvents();
-    KisResourceServerProvider::instance()->resourceBundleServer();
+    KoResourceServerProvider::instance()->patternServer()->loadTags();
+    KoResourceServerProvider::instance()->gradientServer()->loadTags();
+    KoResourceServerProvider::instance()->paletteServer()->loadTags();
+    KoResourceServerProvider::instance()->svgSymbolCollectionServer()->loadTags();
+    KisBrushServer::instance()->brushServer()->loadTags();
+    KisResourceServerProvider::instance()->workspaceServer()->loadTags();
+    KisResourceServerProvider::instance()->layerStyleCollectionServer()->loadTags();
+    KisResourceBundleServerProvider::instance()->resourceBundleServer()->loadTags();
+    KisResourceServerProvider::instance()->paintOpPresetServer()->loadTags();
+
+    KisResourceServerProvider::instance()->paintOpPresetServer()->clearOldSystemTags();
 }
 
 void KisApplication::loadPlugins()
 {
+//    qDebug() << "loadPlugins();";
+
     KoShapeRegistry* r = KoShapeRegistry::instance();
     r->add(new KisShapeSelectionFactory());
 
@@ -335,10 +343,15 @@ void KisApplication::loadPlugins()
     KisGeneratorRegistry::instance();
     KisPaintOpRegistry::instance();
     KoColorSpaceRegistry::instance();
+}
 
+void KisApplication::loadGuiPlugins()
+{
+//    qDebug() << "loadGuiPlugins();";
     // Load the krita-specific tools
     setSplashScreenLoadingText(i18n("Loading Plugins for Krita/Tool..."));
     processEvents();
+//    qDebug() << "loading tools";
     KoPluginLoader::instance()->load(QString::fromLatin1("Krita/Tool"),
                                      QString::fromLatin1("[X-Krita-Version] == 28"));
 
@@ -346,16 +359,17 @@ void KisApplication::loadPlugins()
     // Load dockers
     setSplashScreenLoadingText(i18n("Loading Plugins for Krita/Dock..."));
     processEvents();
+//    qDebug() << "loading dockers";
     KoPluginLoader::instance()->load(QString::fromLatin1("Krita/Dock"),
                                      QString::fromLatin1("[X-Krita-Version] == 28"));
 
     // XXX_EXIV: make the exiv io backends real plugins
     setSplashScreenLoadingText(i18n("Loading Plugins Exiv/IO..."));
     processEvents();
+//    qDebug() << "loading exiv2";
     KisExiv2::initialize();
 }
 
-
 bool KisApplication::start(const KisApplicationArguments &args)
 {
     KisConfig cfg;
@@ -425,12 +439,18 @@ bool KisApplication::start(const KisApplicationArguments &args)
     processEvents();
     addResourceTypes();
 
-    // Load all resources and tags before the plugins do that
-    loadResources();
-
     // Load the plugins
     loadPlugins();
 
+    // Load all resources
+    loadResources();
+
+    // Load all the tags
+    loadResourceTags();
+
+    // Load the gui plugins
+    loadGuiPlugins();
+
     if (needsMainWindow) {
         // show a mainWindow asap, if we want that
         setSplashScreenLoadingText(i18n("Loading Main Window..."));
@@ -444,7 +464,7 @@ bool KisApplication::start(const KisApplicationArguments &args)
                 KoResourceServer<KisWorkspaceResource> * rserver = KisResourceServerProvider::instance()->workspaceServer();
                 KisWorkspaceResource* workspace = rserver->resourceByName(args.workspace());
                 if (workspace) {
-                    m_mainWindow->restoreWorkspace(workspace->dockerState());
+                    m_mainWindow->restoreWorkspace(workspace);
                 }
             }
 
