@@ -24,6 +24,7 @@
 class QApplication;
 class QByteArray;
 class QStringList;
+class KisDocument;
 
 #include "kritaui_export.h"
 
@@ -52,6 +53,9 @@ public:
     bool canvasOnly() const;
     bool noSplash() const;
     bool fullScreen() const;
+    bool doNewImage() const;
+    KisDocument *image() const;
+
 
 private:
 
