@@ -34,13 +34,14 @@
 #include <resources/KoColorSet.h>
 
 #include <resources/KoPattern.h>
-#include "kis_resource_server_provider.h"
+#include "KisResourceServerProvider.h"
 #include "KisViewManager.h"
 #include <QGridLayout>
 #include <QLabel>
 #include <QSpinBox>
 #include <QLineEdit>
 #include <kis_canvas_resource_provider.h>
+#include <kis_config.h>
 
 #include "kis_int_parse_spin_box.h"
 
@@ -48,11 +49,11 @@ class ColorSetDelegate : public QAbstractItemDelegate
 {
 public:
     ColorSetDelegate(QObject * parent = 0) : QAbstractItemDelegate(parent) {}
-    virtual ~ColorSetDelegate() {}
+    ~ColorSetDelegate() override {}
     /// reimplemented
-    virtual void paint(QPainter *, const QStyleOptionViewItem &, const QModelIndex &) const;
+    void paint(QPainter *, const QStyleOptionViewItem &, const QModelIndex &) const override;
     /// reimplemented
-    QSize sizeHint(const QStyleOptionViewItem & option, const QModelIndex &) const {
+    QSize sizeHint(const QStyleOptionViewItem & option, const QModelIndex &) const override {
         return option.decorationSize;
     }
 };
@@ -76,17 +77,17 @@ void ColorSetDelegate::paint(QPainter * painter, const QStyleOptionViewItem & op
     painter->drawText(option.rect.x() + 5, option.rect.y() + painter->fontMetrics().ascent() + 5, colorSet->name());
 
     int size = 7;
-    for (int i = 0; i < colorSet->nColors() && i*size < option.rect.width(); i++) {
+    for (quint32 i = 0; i < colorSet->nColors() && i*size < (quint32)option.rect.width(); i++) {
         QRect rect(option.rect.x() + i*size, option.rect.y() + option.rect.height() - size, size, size);
-        painter->fillRect(rect, colorSet->getColor(i).color.toQColor());
+        painter->fillRect(rect, colorSet->getColorGlobal(i).color.toQColor());
     }
-    
+
     painter->restore();
 }
 
 KisColorsetChooser::KisColorsetChooser(QWidget* parent): QWidget(parent)
 {
-    KoResourceServer<KoColorSet> * rserver = KoResourceServerProvider::instance()->paletteServer(false);
+    KoResourceServer<KoColorSet> * rserver = KoResourceServerProvider::instance()->paletteServer();
     QSharedPointer<KoAbstractResourceServerAdapter> adapter(new KoResourceServerAdapter<KoColorSet>(rserver));
     m_itemChooser = new KoResourceItemChooser(adapter, this);
     m_itemChooser->setItemDelegate(new ColorSetDelegate(this));
@@ -96,7 +97,12 @@ KisColorsetChooser::KisColorsetChooser(QWidget* parent): QWidget(parent)
     m_itemChooser->setColumnCount(1);
     connect(m_itemChooser, SIGNAL(resourceSelected(KoResource*)),
             this, SLOT(resourceSelected(KoResource*)));
-    
+
+    KisConfig cfg;
+    m_itemChooser->configureKineticScrolling(cfg.kineticScrollingGesture(),
+                                         cfg.kineticScrollingSensitivity(),
+                                         cfg.kineticScrollingScrollbar());
+
     QPushButton* saveButton = new QPushButton(i18n("Save"));
     connect(saveButton, SIGNAL(clicked(bool)), this, SLOT(slotSave()));
 
