@@ -33,7 +33,6 @@
 #include <KoDocumentInfo.h>
 #include <KoDpi.h>
 #include <KoUnit.h>
-#include <KoFileDialog.h>
 #include <KoID.h>
 #include <KoOdfReadStore.h>
 #include <KoProgressProxy.h>
@@ -104,7 +103,7 @@
 #include "kis_statusbar.h"
 #include "widgets/kis_progress_widget.h"
 #include "kis_canvas_resource_provider.h"
-#include "kis_resource_server_provider.h"
+#include "KisResourceServerProvider.h"
 #include "kis_node_manager.h"
 #include "KisPart.h"
 #include "KisApplication.h"
@@ -483,6 +482,7 @@ KisDocument::~KisDocument()
 
         KisImageWSP sanityCheckPointer = d->image;
         Q_UNUSED(sanityCheckPointer);
+
         // The following line trigger the deletion of the image
         d->image.clear();
 
@@ -490,7 +490,6 @@ KisDocument::~KisDocument()
         KIS_SAFE_ASSERT_RECOVER_NOOP(!sanityCheckPointer.isValid());
     }
 
-
     delete d;
 }
 
@@ -658,7 +657,17 @@ KisDocument* KisDocument::lockAndCloneForSaving()
     if (!locker.successfullyLocked()) {
         return 0;
     }
-    return new KisDocument(*this);
+
+    KisDocument *clonedDoc = new KisDocument(*this);
+
+    // force update of all the asynchronous nodes
+    clonedDoc->image()->waitForDone();
+    QApplication::processEvents();
+
+    KisLayerUtils::forceAllDelayedNodesUpdate(clonedDoc->image()->root());
+    clonedDoc->image()->waitForDone();
+
+    return clonedDoc;
 }
 
 bool KisDocument::exportDocumentSync(const QUrl &url, const QByteArray &mimeType, KisPropertiesConfigurationSP exportConfiguration)
@@ -723,9 +732,13 @@ bool KisDocument::initiateSavingInBackground(const QString actionName,
                                                            exportConfiguration);
 
     if (!started) {
-        d->backgroundSaveDocument.take()->deleteLater();
-        d->savingMutex.unlock();
-        d->backgroundSaveJob = KritaUtils::ExportFileJob();
+        // the state should have been deinitialized in slotChildCompletedSavingInBackground()
+
+        KIS_SAFE_ASSERT_RECOVER (!d->backgroundSaveDocument && !d->backgroundSaveJob.isValid()) {
+            d->backgroundSaveDocument.take()->deleteLater();
+            d->savingMutex.unlock();
+            d->backgroundSaveJob = KritaUtils::ExportFileJob();
+        }
     }
 
     return started;
@@ -1118,6 +1131,7 @@ bool KisDocument::openFile()
     KisImportExportFilter::ConversionStatus status;
 
     status = d->importExportManager->importDocument(localFilePath(), typeName);
+
     if (status != KisImportExportFilter::OK) {
         QString msg = KisImportExportFilter::conversionStatusString(status);
         if (!msg.isEmpty()) {
@@ -1537,9 +1551,6 @@ bool KisDocument::newImage(const QString& name,
 
     image->assignImageProfile(cs->profile());
     documentInfo()->setAboutInfo("title", name);
-    if (name != i18n("Unnamed") && !name.isEmpty()) {
-        setUrl(QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + '/' + name + ".kra"));
-    }
     documentInfo()->setAboutInfo("abstract", description);
 
     layer = new KisPaintLayer(image.data(), image->nextLayerName(), OPACITY_OPAQUE_U8, cs);
@@ -1593,8 +1604,10 @@ bool KisDocument::isSaving() const
 
 void KisDocument::waitForSavingToComplete()
 {
-    KisAsyncActionFeedback f(i18nc("progress dialog message when the user closes the document that is being saved", "Waiting for saving to complete..."), 0);
-    f.waitForMutex(&d->savingMutex);
+    if (isSaving()) {
+        KisAsyncActionFeedback f(i18nc("progress dialog message when the user closes the document that is being saved", "Waiting for saving to complete..."), 0);
+        f.waitForMutex(&d->savingMutex);
+    }
 }
 
 KoShapeBasedDocumentBase *KisDocument::shapeController() const
@@ -1656,6 +1669,14 @@ void KisDocument::setCurrentImage(KisImageSP image)
     d->image->initialRefreshGraph();
 }
 
+void KisDocument::hackPreliminarySetImage(KisImageSP image)
+{
+    KIS_SAFE_ASSERT_RECOVER_RETURN(!d->image);
+
+    d->setImageAndInitIdleWatcher(image);
+    d->shapeController->setImage(image);
+}
+
 void KisDocument::setImageModified()
 {
     setModified(true);
