@@ -22,12 +22,17 @@ Boston, MA 02110-1301, USA.
 #define KIS_IMPORT_EXPORT_FILTER_H
 
 #include <QObject>
+#include <QIODevice>
 #include <QMap>
 #include <QPointer>
 #include <QString>
+#include <QPair>
+#include <QList>
+#include <KoID.h>
 #include <QSharedPointer>
 #include <kis_properties_configuration.h>
 #include <kis_types.h>
+#include <KisExportCheckBase.h>
 
 class KoUpdater;
 class KisDocument;
@@ -43,8 +48,6 @@ class KisConfigWidget;
  * the @ref convert() method. Don't forget to specify the Q_OBJECT
  * macro in your class even if you don't use signals or slots.
  * This is needed as filters are created on the fly.
- * The m_chain member allows access to the @ref KisFilterChain
- * which invokes the filter to query for input/output.
  *
  * @note Take care: The m_chain pointer is invalid while the constructor
  * runs due to the implementation -- @em don't use it in the constructor.
@@ -61,7 +64,11 @@ class KisConfigWidget;
 class KRITAUI_EXPORT KisImportExportFilter : public QObject
 {
     Q_OBJECT
-
+public:
+    static const QString ImageContainsTransparencyTag;
+    static const QString ColorModelIDTag;
+    static const QString ColorDepthIDTag;
+    static const QString sRGBTag;
 public:
     /**
      * This enum is used to signal the return state of your filter.
@@ -70,41 +77,31 @@ public:
      * if it's needed.
      */
     enum ConversionStatus { OK,
-                            StupidError,
                             UsageError,
                             CreationError,
                             FileNotFound,
                             StorageCreationError,
                             BadMimeType,
                             BadConversionGraph,
-                            EmbeddedDocError,
                             WrongFormat,
                             NotImplemented,
                             ParsingError,
                             InternalError,
-                            UnexpectedEOF,
-                            UnexpectedOpcode,
                             UserCancelled,
-                            OutOfMemory,
-                            PasswordProtected,
                             InvalidFormat,
-                            FilterEntryNull,
-                            NoDocumentCreated,
-                            DownloadFailed,
                             FilterCreationError,
                             ProgressCancelled,
                             UnsupportedVersion,
                             JustInCaseSomeBrokenCompilerUsesLessThanAByte = 255
                           };
 
-    virtual ~KisImportExportFilter();
+    ~KisImportExportFilter() override;
 
-    /**
-     * @brief setChain set the chain information on the filter. The chain information
-     * lets the filter know what document it's working on. The filter will not delete
-     * @param chain the actual filter chain
-     */
-    void setChain(KisFilterChainSP chain);
+    void setBatchMode(bool batchmode);
+    void setFilename(const QString &filename);
+    void setRealFilename(const QString &filename);
+    void setMimeType(const QString &mime);
+    void setUpdater(QPointer<KoUpdater> updater);
 
     /**
      * The filter chain calls this method to perform the actual conversion.
@@ -112,18 +109,10 @@ public:
      * .desktop file.
      * You @em have to implement this method to make the filter work.
      *
-     * @param from The mimetype of the source file/document
-     * @param to The mimetype of the destination file/document
      * @return The error status, see the @ref #ConversionStatus enum.
      *         KisImportExportFilter::OK means that everything is alright.
      */
-    virtual ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0) = 0;
-
-    /**
-     * Set the updater to which the filter will report progress.
-     * Every emit of the sigProgress signal is reported to the updater.
-     */
-    void setUpdater(const QPointer<KoUpdater>& updater);
+    virtual ConversionStatus convert(KisDocument *document, QIODevice *io, KisPropertiesConfigurationSP configuration = 0) = 0;
 
     /**
      * Get the text version of the status value
@@ -144,7 +133,7 @@ public:
      * @param to The mimetype of the destination file/document
      * @return a serializable KisPropertiesConfiguration object
      */
-    virtual KisPropertiesConfigurationSP lastSavedConfiguration(const QByteArray &from = "", const QByteArray &to = "") const;
+    KisPropertiesConfigurationSP lastSavedConfiguration(const QByteArray &from = "", const QByteArray &to = "") const;
 
     /**
      * @brief createConfigurationWidget creates a widget that can be used to define the settings for a given import/export filter
@@ -156,16 +145,14 @@ public:
      */
     virtual KisConfigWidget *createConfigurationWidget(QWidget *parent, const QByteArray& from = "", const QByteArray& to = "") const;
 
-
-Q_SIGNALS:
     /**
-     * Emit this signal with a value in the range of 1...100 to have some
-     * progress feedback for the user in the statusbar of the application.
-     *
-     * @param value The actual progress state. Should always remain in
-     * the range 1..100.
+     * @brief generate and return the list of capabilities of this export filter. The list
+     * @return returns the list of capabilities of this export filter
      */
-    void sigProgress(int value);
+    virtual QMap<QString, KisExportCheckBase*> exportChecks();
+
+    /// Override and return false for the filters that use a library that cannot handle file handles, only file names.
+    virtual bool supportsIO() const { return true; }
 
 protected:
     /**
@@ -173,11 +160,15 @@ protected:
      */
     KisImportExportFilter(QObject *parent = 0);
 
-    KisDocument *inputDocument() const;
-    KisDocument *outputDocument() const;
-    QString inputFile() const;
-    QString outputFile() const;
-    bool getBatchMode() const;
+    QString filename() const;
+    QString realFilename() const;
+    bool batchMode() const;
+    QByteArray mimeType() const;
+
+    void setProgress(int value);
+    virtual void initializeCapabilities();
+    void addCapability(KisExportCheckBase *capability);
+    void addSupportedColorModels(QList<QPair<KoID, KoID> > supportedColorModels, const QString &name, KisExportCheckBase::Level level = KisExportCheckBase::PARTIALLY);
 
 private:
 
@@ -187,8 +178,6 @@ private:
     class Private;
     Private *const d;
 
-private Q_SLOTS:
-    void slotProgress(int value);
 };
 
 #endif
