@@ -45,7 +45,7 @@ class QDockWidget;
 class KisView;
 class KisViewManager;
 class KoCanvasController;
-
+class KisWorkspaceResource;
 
 /**
  * @brief Main window for Krita
@@ -129,10 +129,8 @@ public:
      */
     bool saveDocument(KisDocument *document, bool saveas, bool isExporting);
 
-
     void setReadWrite(bool readwrite);
 
-
     /// Return the list of dock widgets belonging to this main window.
     QList<QDockWidget*> dockWidgets() const;
 
@@ -149,7 +147,7 @@ public:
      * @param state the saved state
      * @return TRUE on success
      */
-    bool restoreWorkspace(const QByteArray &state);
+    bool restoreWorkspace(KisWorkspaceResource *workspace);
 
     KisViewManager *viewManager() const;
 
@@ -229,8 +227,6 @@ public Q_SLOTS:
      */
     void updateCaption();
 
-
-
     /**
      *  Saves the current document with the current name.
      */
@@ -320,11 +316,6 @@ private Q_SLOTS:
      */
     void viewFullscreen(bool fullScreen);
 
-    /**
-     * Toggle docker titlebars on/off.
-     */
-    void showDockerTitleBars(bool show);
-
     /**
      * Reload file
      */
@@ -377,6 +368,8 @@ protected:
     void dragMoveEvent(QDragMoveEvent * event) override;
     void dragLeaveEvent(QDragLeaveEvent * event) override;
 
+    void mouseReleaseEvent(QMouseEvent *event) override;
+
 
 private:
 
@@ -423,7 +416,7 @@ private:
 
     void saveWindowSettings();
 
-    QPointer<KisView>activeKisView();
+    QPointer<KisView> activeKisView();
 
     void applyDefaultSettings(QPrinter &printer);
 
