@@ -170,6 +170,9 @@ int KisPaletteModel::rowCount(const QModelIndex& /*parent*/) const
     if (!m_colorSet) {
         return 0;
     }
+    if (m_colorSet->nColors()==0) {
+        return 0;
+    }
     if (columnCount() > 0) {
         int countedrows = m_colorSet->nColorsGroup("")/columnCount();
         if (m_colorSet->nColorsGroup()%columnCount() > 0) {
@@ -269,39 +272,41 @@ KoColorSet* KisPaletteModel::colorSet() const
 QModelIndex KisPaletteModel::indexFromId(int i) const
 {
     QModelIndex index = QModelIndex();
-    if (colorSet()->nColors()==0) {
+    if (!colorSet() || colorSet()->nColors() == 0) {
         return index;
     }
-    if (i > colorSet()->nColors()) {
+
+    if (i > (int)colorSet()->nColors()) {
         qWarning()<<"index is too big"<<i<<"/"<<colorSet()->nColors();
         index = this->index(0,0);
     }
+
     if (i < (int)colorSet()->nColorsGroup(0)) {
-        index = QAbstractTableModel::index(i/columnCount(), i%columnCount());
+        index = QAbstractTableModel::index(i/columnCount(), i % columnCount());
         if (!index.isValid()) {
-            index = QAbstractTableModel::index(0,0,QModelIndex());
+            index = QAbstractTableModel::index(0, 0, QModelIndex());
         }
         return index;
     } else {
-        int rowstotal = 1+m_colorSet->nColorsGroup()/columnCount();
-        if (m_colorSet->nColorsGroup()==0) {
-            rowstotal +=1;
+        int rowstotal = 1 + m_colorSet->nColorsGroup() / columnCount();
+        if (m_colorSet->nColorsGroup() == 0) {
+            rowstotal += 1;
         }
         int totalIndexes = colorSet()->nColorsGroup();
         Q_FOREACH (QString groupName, m_colorSet->getGroupNames()){
-            if (i+1<=totalIndexes+colorSet()->nColorsGroup(groupName) && i+1>totalIndexes) {
-                int col = (i-totalIndexes)%columnCount();
-                int row = rowstotal+1+((i-totalIndexes)/columnCount());
+            if (i + 1 <= (int)(totalIndexes + colorSet()->nColorsGroup(groupName)) && i + 1 > (int)totalIndexes) {
+                int col = (i - totalIndexes) % columnCount();
+                int row = rowstotal + 1 + ((i - totalIndexes) / columnCount());
                 index = this->index(row, col);
                 return index;
             } else {
-                rowstotal += 1+m_colorSet->nColorsGroup(groupName)/columnCount();
+                rowstotal += 1 + m_colorSet->nColorsGroup(groupName) / columnCount();
                 totalIndexes += colorSet()->nColorsGroup(groupName);
                 if (m_colorSet->nColorsGroup(groupName)%columnCount() > 0) {
-                    rowstotal+=1;
+                    rowstotal += 1;
                 }
                 if (m_colorSet->nColorsGroup(groupName)==0) {
-                    rowstotal+=1; //always add one for the group when considering groups.
+                    rowstotal += 1; //always add one for the group when considering groups.
                 }
             }
         }
@@ -356,17 +361,17 @@ bool KisPaletteModel::addColorSetEntry(KoColorSetEntry entry, QString groupName)
 {
     int col = m_colorSet->nColorsGroup(groupName)%columnCount();
     QModelIndex i = getLastEntryIndex();
-    if (col+1>columnCount()) {
+    if (col+1 > columnCount()) {
         beginInsertRows(QModelIndex(), i.row(), i.row()+1);
     }
-    if (m_colorSet->nColors()<columnCount()) {
+    if ((int)m_colorSet->nColors() < columnCount()) {
         beginInsertColumns(QModelIndex(), m_colorSet->nColors(), m_colorSet->nColors()+1);
     }
     m_colorSet->add(entry, groupName);
-    if (col+1>columnCount()) {
+    if (col + 1 > columnCount()) {
         endInsertRows();
     }
-    if (m_colorSet->nColors()<columnCount()) {
+    if (m_colorSet->nColors() < (quint32)columnCount()) {
         endInsertColumns();
     }
     return true;
