@@ -2,7 +2,7 @@
  * Copyright (C) 1998-1999 Torben Weis       <weis@kde.org>
  * Copyright (C) 2000-2005 David Faure       <faure@kde.org>
  * Copyright (C) 2007-2008 Thorsten Zachmann <zachmann@kde.org>
- * Copyright (C) 2010-2012 Boudewijn Rempt   <boud@kogmbh.com>
+ * Copyright (C) 2010-2012 Boudewijn Rempt   <boud@valdyas.org>
  * Copyright (C) 2011 Inge Wallin            <ingwa@kogmbh.com>
  * Copyright (C) 2015 Michael Abrahams       <miabraha@gmail.com>
  *
@@ -62,13 +62,14 @@
 #include "KisDocument.h"
 #include "kis_config.h"
 #include "kis_shape_controller.h"
-#include "kis_resource_server_provider.h"
+#include "KisResourceServerProvider.h"
 #include "kis_animation_cache_populator.h"
 #include "kis_idle_watcher.h"
 #include "kis_image.h"
 #include "KisImportExportManager.h"
 #include "KisDocument.h"
 #include "KoToolManager.h"
+#include "KisViewManager.h"
 #include "KisOpenPane.h"
 
 #include "kis_color_manager.h"
@@ -99,14 +100,12 @@ public:
     QList<QPointer<KisView> > views;
     QList<QPointer<KisMainWindow> > mainWindows;
     QList<QPointer<KisDocument> > documents;
-
     KActionCollection *actionCollection{0};
-
     KisIdleWatcher idleWatcher;
     KisAnimationCachePopulator animationCachePopulator;
-    void loadActions();
 };
 
+
 KisPart* KisPart::instance()
 {
     return s_instance;
@@ -157,7 +156,9 @@ void KisPart::updateIdleWatcherConnections()
     QVector<KisImageSP> images;
 
     Q_FOREACH (QPointer<KisDocument> document, documents()) {
-        images << document->image();
+        if (document->image()) {
+            images << document->image();
+        }
     }
 
     d->idleWatcher.setTrackedImages(images);
@@ -170,6 +171,8 @@ void KisPart::addDocument(KisDocument *document)
     if (!d->documents.contains(document)) {
         d->documents.append(document);
         emit documentOpened('/'+objectName());
+        emit sigDocumentAdded(document);
+        connect(document, SIGNAL(sigSavingFinished()), SLOT(slotDocumentSaved()));
     }
 }
 
@@ -194,16 +197,16 @@ void KisPart::removeDocument(KisDocument *document)
 {
     d->documents.removeAll(document);
     emit documentClosed('/'+objectName());
+    emit sigDocumentRemoved(document->url().toLocalFile());
     document->deleteLater();
 }
 
 KisMainWindow *KisPart::createMainWindow()
 {
     KisMainWindow *mw = new KisMainWindow();
-
     dbgUI <<"mainWindow" << (void*)mw << "added to view" << this;
     d->mainWindows.append(mw);
-
+    emit sigWindowAdded(mw);
     return mw;
 }
 
@@ -246,8 +249,6 @@ void KisPart::addView(KisView *view)
         d->views.append(view);
     }
 
-    connect(view, SIGNAL(destroyed()), this, SLOT(viewDestroyed()));
-
     emit sigViewAdded(view);
 }
 
@@ -261,9 +262,7 @@ void KisPart::removeView(KisView *view)
      *             document *before* the saving is completed, a crash
      *             will happen.
      */
-    if (view->mainWindow()->hackIsSaving()) {
-        return;
-    }
+    KIS_ASSERT_RECOVER_RETURN(!view->mainWindow()->hackIsSaving());
 
     emit sigViewRemoved(view);
 
@@ -305,6 +304,11 @@ int KisPart::viewCount(KisDocument *doc) const
     }
 }
 
+void KisPart::slotDocumentSaved()
+{
+    KisDocument *doc = qobject_cast<KisDocument*>(sender());
+    emit sigDocumentSaved(doc->url().toLocalFile());
+}
 
 void KisPart::removeMainWindow(KisMainWindow *mainWindow)
 {
@@ -341,6 +345,7 @@ KisMainWindow *KisPart::currentMainwindow() const
 
 }
 
+
 KisIdleWatcher* KisPart::idleWatcher() const
 {
     return &d->idleWatcher;
@@ -353,24 +358,12 @@ KisAnimationCachePopulator* KisPart::cachePopulator() const
 
 void KisPart::openExistingFile(const QUrl &url)
 {
-    Q_ASSERT(url.isLocalFile());
-    qApp->setOverrideCursor(Qt::BusyCursor);
-    KisDocument *document = createDocument();
-    if (!document->openUrl(url)) {
-        delete document;
-        return;
-    }
-    if (!document->image()) {
-        delete document;
-        return;
-    }
-    document->setModified(false);
-    addDocument(document);
+    // TODO: refactor out this method!
 
     KisMainWindow *mw = currentMainwindow();
-    mw->addViewAndNotifyLoadingCompleted(document);
+    KIS_SAFE_ASSERT_RECOVER_RETURN(mw);
 
-    qApp->restoreOverrideCursor();
+    mw->openDocument(url, KisMainWindow::None);
 }
 
 void KisPart::updateShortcuts()
@@ -418,11 +411,16 @@ void KisPart::openTemplate(const QUrl &url)
         mimeType.remove( QRegExp( "-template$" ) );
         document->setMimeTypeAfterLoading(mimeType);
         document->resetURL();
-        document->setEmpty();
     }
     else {
-        document->showLoadingErrorDialog();
-        document->initEmpty();
+        if (document->errorMessage().isEmpty()) {
+            QMessageBox::critical(0, i18nc("@title:window", "Krita"), i18n("Could not create document from template\n%1", document->localFilePath()));
+        }
+        else {
+            QMessageBox::critical(0, i18nc("@title:window", "Krita"), i18n("Could not create document from template\n%1\nReason: %2", document->localFilePath(), document->errorMessage()));
+        }
+        delete document;
+        return;
     }
     addDocument(document);
 
@@ -439,14 +437,6 @@ void KisPart::openTemplate(const QUrl &url)
     qApp->restoreOverrideCursor();
 }
 
-void KisPart::viewDestroyed()
-{
-    KisView *view = qobject_cast<KisView*>(sender());
-    if (view) {
-        removeView(view);
-    }
-}
-
 void KisPart::addRecentURLToAllMainWindows(QUrl url)
 {
     // Add to recent actions list in our mainWindows
@@ -471,6 +461,8 @@ void KisPart::startCustomDocument(KisDocument* doc)
 
 KisInputManager* KisPart::currentInputManager()
 {
-    return instance()->currentMainwindow()->viewManager()->inputManager();
+    KisMainWindow *mw = currentMainwindow();
+    KisViewManager *manager = mw ? mw->viewManager() : 0;
+    return manager ? manager->inputManager() : 0;
 }
 
