@@ -2,7 +2,7 @@
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
    Copyright (C) 2000-2005 David Faure  <faure@kde.org>
    Copyright (C) 2007 Thorsten Zachmann <zachmann@kde.org>
-   Copyright (C) 2010 Boudewijn Rempt   <boud@kogmbh.com>
+   Copyright (C) 2010 Boudewijn Rempt   <boud@valdyas.org>
    Copyright (C) 2015 Michael Abrahams  <miabraha@gmail.com>
 
    This library is free software; you can redistribute it and/or
@@ -35,6 +35,7 @@
 namespace KIO {
 }
 
+class KisAction;
 class KisDocument;
 class KisView;
 class KisDocument;
@@ -76,7 +77,7 @@ public:
      * The destructor does not delete any attached KisView objects and it does not
      * delete the attached widget as returned by widget().
      */
-    ~KisPart();
+    ~KisPart() override;
 
     // ----------------- Document management -----------------
 
@@ -167,29 +168,32 @@ public Q_SLOTS:
 
 private Q_SLOTS:
 
-    void viewDestroyed();
-
     void updateIdleWatcherConnections();
 
     void updateShortcuts();
 
 Q_SIGNALS:
     /**
-     * emitted when a new document is opened.
+     * emitted when a new document is opened. (for the idle watcher)
      */
     void documentOpened(const QString &ref);
 
     /**
-     * emitted when an old document is closed.
+     * emitted when an old document is closed. (for the idle watcher)
      */
     void documentClosed(const QString &ref);
 
+    // These signals are for libkis or sketch
     void sigViewAdded(KisView *view);
     void sigViewRemoved(KisView *view);
+    void sigDocumentAdded(KisDocument *document);
+    void sigDocumentSaved(const QString &url);
+    void sigDocumentRemoved(const QString &filename);
+    void sigWindowAdded(KisMainWindow *window);
 
 public:
 
-    static KisInputManager *currentInputManager();
+    KisInputManager *currentInputManager();
 
     //------------------ View management ------------------
 
@@ -226,6 +230,11 @@ public:
      */
     int viewCount(KisDocument *doc) const;
 
+
+private Q_SLOTS:
+
+    void slotDocumentSaved();
+
 private:
 
     Q_DISABLE_COPY(KisPart)
