@@ -78,7 +78,6 @@
 #include "KisPrintJob.h"
 #include "kis_shape_controller.h"
 #include "kis_tool_freehand.h"
-#include "KisUndoStackAction.h"
 #include "KisViewManager.h"
 #include "kis_zoom_manager.h"
 #include "kis_statusbar.h"
@@ -117,9 +116,6 @@ public:
     {
     }
 
-    KisUndoStackAction *undo = 0;
-    KisUndoStackAction *redo = 0;
-
     bool inOperation; //in the middle of an operation (no screen refreshing)?
 
     QPointer<KisDocument> document; // our KisDocument
@@ -219,9 +215,6 @@ KisView::KisView(KisDocument *document, KoCanvasResourceManager *resourceManager
 
     setFocusPolicy(Qt::StrongFocus);
 
-    d->undo = new KisUndoStackAction(d->document->undoStack(), KisUndoStackAction::UNDO);
-    d->redo = new KisUndoStackAction(d->document->undoStack(), KisUndoStackAction::RED0);
-
     QStatusBar * sb = statusBar();
     if (sb) { // No statusbar in e.g. konqueror
         connect(d->document, SIGNAL(statusBarMessage(const QString&, int)),
@@ -401,16 +394,6 @@ void KisView::slotContinueRemoveNode(KisNodeSP newActiveNode)
     }
 }
 
-QAction *KisView::undoAction() const
-{
-    return d->undo;
-}
-
-QAction *KisView::redoAction() const
-{
-    return d->redo;
-}
-
 KoZoomController *KisView::zoomController() const
 {
     return d->zoomManager.zoomController();
@@ -693,9 +676,7 @@ bool KisView::queryClose()
     if (!document())
         return true;
 
-    if (document()->isSaving()) {
-        document()->waitForSavingToComplete();
-    }
+    document()->waitForSavingToComplete();
 
     if (document()->isModified()) {
         QString name;
