@@ -73,7 +73,7 @@ KisBrushHud::KisBrushHud(KisCanvasResourceProvider *provider, QWidget *parent)
 
     QHBoxLayout *labelLayout = new QHBoxLayout();
     m_d->lblPresetIcon = new QLabel(this);
-    const QSize iconSize = QSize(22,22) * qApp->devicePixelRatio();
+    const QSize iconSize = QSize(22,22);
     m_d->lblPresetIcon->setMinimumSize(iconSize);
     m_d->lblPresetIcon->setMaximumSize(iconSize);
     m_d->lblPresetIcon->setScaledContents(true);
@@ -82,7 +82,9 @@ KisBrushHud::KisBrushHud(KisCanvasResourceProvider *provider, QWidget *parent)
 
     m_d->btnConfigure = new QToolButton(this);
     m_d->btnConfigure->setAutoRaise(true);
-    m_d->btnConfigure->setIcon(KisIconUtils::loadIcon("applications-system"));
+
+
+
     connect(m_d->btnConfigure, SIGNAL(clicked()), SLOT(slotConfigBrushHud()));
 
     labelLayout->addWidget(m_d->lblPresetIcon);
@@ -109,6 +111,8 @@ KisBrushHud::KisBrushHud(KisCanvasResourceProvider *provider, QWidget *parent)
     m_d->wdgPropertiesArea->setWidget(m_d->wdgProperties);
     layout->addWidget(m_d->wdgPropertiesArea);
 
+    updateIcons();
+
     setLayout(layout);
     setCursor(Qt::ArrowCursor);
 
@@ -116,6 +120,8 @@ KisBrushHud::KisBrushHud(KisCanvasResourceProvider *provider, QWidget *parent)
     setAttribute(Qt::WA_NoMousePropagation, true);
 }
 
+
+
 KisBrushHud::~KisBrushHud()
 {
 }
@@ -126,6 +132,11 @@ QSize KisBrushHud::sizeHint() const
     return QSize(size.width(), parentWidget()->height());
 }
 
+void KisBrushHud::updateIcons()
+{
+    m_d->btnConfigure->setIcon(KisIconUtils::loadIcon("applications-system"));
+}
+
 void KisBrushHud::slotReloadProperties()
 {
     m_d->presetConnections.clear();
