@@ -135,10 +135,13 @@ public:
     bool lodAllowedInCanvas;
     bool bootstrapLodBlocked;
     QPointer<KoShapeManager> currentlyActiveShapeManager;
+    KisInputActionGroupsMask inputActionGroupsMask = AllActionGroup;
 
     bool effectiveLodAllowedInCanvas() {
         return lodAllowedInCanvas && !bootstrapLodBlocked;
     }
+
+    void setActiveShapeManager(KoShapeManager *shapeManager);
 };
 
 namespace {
@@ -361,11 +364,23 @@ void KisCanvas2::addCommand(KUndo2Command *command)
     m_d->view->document()->addCommand(command);
 }
 
+void KisCanvas2::KisCanvas2Private::setActiveShapeManager(KoShapeManager *shapeManager)
+{
+    if (shapeManager != currentlyActiveShapeManager) {
+        currentlyActiveShapeManager = shapeManager;
+        selectedShapesProxy.setShapeManager(shapeManager);
+    }
+}
+
 KoShapeManager* KisCanvas2::shapeManager() const
 {
     KisNodeSP node = m_d->view->currentNode();
     KoShapeManager *localShapeManager = fetchShapeManagerFromNode(node);
 
+    if (localShapeManager != m_d->currentlyActiveShapeManager) {
+        m_d->setActiveShapeManager(localShapeManager);
+    }
+
     // sanity check for consistency of the local shape manager
     KIS_SAFE_ASSERT_RECOVER (localShapeManager == m_d->currentlyActiveShapeManager) {
         localShapeManager = globalShapeManager();
@@ -404,6 +419,16 @@ KisInputManager* KisCanvas2::globalInputManager() const
     return m_d->view->globalInputManager();
 }
 
+KisInputActionGroupsMask KisCanvas2::inputActionGroupsMask() const
+{
+    return m_d->inputActionGroupsMask;
+}
+
+void KisCanvas2::setInputActionGroupsMask(KisInputActionGroupsMask mask)
+{
+    m_d->inputActionGroupsMask = mask;
+}
+
 QWidget* KisCanvas2::canvasWidget()
 {
     return m_d->canvasWidget->widget();
@@ -783,17 +808,12 @@ void KisCanvas2::notifyZoomChanged()
 
 void KisCanvas2::slotTrySwitchShapeManager()
 {
-    QPointer<KoShapeManager> oldManager = m_d->currentlyActiveShapeManager;
-
     KisNodeSP node = m_d->view->currentNode();
 
     QPointer<KoShapeManager> newManager;
     newManager = fetchShapeManagerFromNode(node);
 
-    if (newManager != oldManager) {
-        m_d->currentlyActiveShapeManager = newManager;
-        m_d->selectedShapesProxy.setShapeManager(newManager);
-    }
+    m_d->setActiveShapeManager(newManager);
 }
 
 void KisCanvas2::notifyLevelOfDetailChange()
@@ -922,6 +942,7 @@ void KisCanvas2::setFavoriteResourceManager(KisFavoriteResourceManager* favorite
                                             m_d->view->resourceProvider(), m_d->canvasWidget->widget());
     connect(m_d->popupPalette, SIGNAL(zoomLevelChanged(int)), this, SLOT(slotZoomChanged(int)));
     connect(m_d->popupPalette, SIGNAL(sigUpdateCanvas()), this, SLOT(updateCanvas()));
+    connect(m_d->view->mainWindow(), SIGNAL(themeChanged()), m_d->popupPalette, SLOT(slotUpdateIcons()));
 
     m_d->popupPalette->showPopupPalette(false);
 }
