@@ -69,7 +69,7 @@ struct KisGuidesManager::Private
     void deleteGuide(const GuideHandle &h);
     const GuideHandle invalidGuide;
 
-    bool updateCursor(const QPointF &docPos);
+    bool updateCursor(const QPointF &docPos, bool forceDisableCursor = false);
 
     void initDragStart(const GuideHandle &guide,
                        const QPointF &dragStart,
@@ -166,6 +166,11 @@ void KisGuidesManager::setGuidesConfigImpl(const KisGuidesConfig &value, bool em
         m_d->updateSnappingStatus(value);
     }
 
+    if (m_d->view) {
+        m_d->view->document()->setUnit(KoUnit(m_d->guidesConfig.unitType()));
+        m_d->view->viewManager()->actionManager()->actionByName("ruler_pixel_multiple2")->setChecked(value.rulersMultiple2());
+    }
+
     emit sigRequestUpdateGuidesConfig(m_d->guidesConfig);
 }
 
@@ -269,6 +274,28 @@ void KisGuidesManager::setSnapToGuides(bool value)
     setGuidesConfigImpl(m_d->guidesConfig);
 }
 
+bool KisGuidesManager::rulersMultiple2() const
+{
+    return m_d->guidesConfig.rulersMultiple2();
+}
+
+void KisGuidesManager::setRulersMultiple2(bool value)
+{
+    m_d->guidesConfig.setRulersMultiple2(value);
+    setGuidesConfigImpl(m_d->guidesConfig);
+}
+
+KoUnit::Type KisGuidesManager::unitType() const
+{
+    return m_d->guidesConfig.unitType();
+}
+
+void KisGuidesManager::setUnitType(const KoUnit::Type type)
+{
+    m_d->guidesConfig.setUnitType(type);
+    setGuidesConfigImpl(m_d->guidesConfig, false);
+}
+
 void KisGuidesManager::setup(KisActionManager *actionManager)
 {
     KisAction *action = 0;
@@ -429,12 +456,12 @@ void KisGuidesManager::Private::deleteGuide(const GuideHandle &h)
     }
 }
 
-bool KisGuidesManager::Private::updateCursor(const QPointF &docPos)
+bool KisGuidesManager::Private::updateCursor(const QPointF &docPos, bool forceDisableCursor)
 {
     KisCanvas2 *canvas = view->canvasBase();
 
     const GuideHandle guide = findGuide(docPos);
-    const bool guideValid = isGuideValid(guide);
+    const bool guideValid = isGuideValid(guide) && !forceDisableCursor;
 
     if (guideValid && !cursorSwitched) {
         oldCursor = canvas->canvasWidget()->cursor();
@@ -549,7 +576,10 @@ QPointF KisGuidesManager::Private::getDocPointFromEvent(QEvent *event)
     KisCanvas2 *canvas = view->canvasBase();
     const KisCoordinatesConverter *converter = canvas->coordinatesConverter();
 
-    if (event->type() == QEvent::MouseMove ||
+    if (event->type() == QEvent::Enter) {
+        QEnterEvent *enterEvent = static_cast<QEnterEvent*>(event);
+        result = alignToPixels(converter->widgetToDocument(enterEvent->pos()));
+    } else if (event->type() == QEvent::MouseMove ||
         event->type() == QEvent::MouseButtonPress ||
         event->type() == QEvent::MouseButtonRelease) {
 
@@ -562,6 +592,10 @@ QPointF KisGuidesManager::Private::getDocPointFromEvent(QEvent *event)
 
         QTabletEvent *tabletEvent = static_cast<QTabletEvent*>(event);
         result = alignToPixels(converter->widgetToDocument(tabletEvent->pos()));
+    } else {
+        // we shouldn't silently return QPointF(0,0), higher level code may
+        // snap to some unexpected guide
+        KIS_SAFE_ASSERT_RECOVER_NOOP(0 && "event type is not supported!");
     }
 
     return result;
@@ -596,13 +630,17 @@ bool KisGuidesManager::eventFilter(QObject *obj, QEvent *event)
     bool retval = false;
 
     switch (event->type()) {
-    case QEvent::Enter:
     case QEvent::Leave:
+        m_d->updateCursor(QPointF(), true);
+        break;
+    case QEvent::Enter:
     case QEvent::TabletMove:
     case QEvent::MouseMove: {
         const QPointF docPos = m_d->getDocPointFromEvent(event);
         const Qt::KeyboardModifiers modifiers = qApp->keyboardModifiers();
-        retval = m_d->mouseMoveHandler(docPos, modifiers);
+
+        // we should never eat Enter events, input manager may get crazy about it
+        retval = m_d->mouseMoveHandler(docPos, modifiers) && event->type() != QEvent::Enter;
 
         break;
     }
