@@ -18,7 +18,7 @@
  */
 
 #include "kis_dlg_blacklist_cleanup.h"
-#include <kis_resource_server_provider.h>
+#include <KisResourceServerProvider.h>
 
 #include <kis_icon.h>
 #include <KoResourceServerProvider.h>
