@@ -61,7 +61,7 @@
 #include <KoResourcePaths.h>
 #include "kis_action_registry.h"
 
-#include "widgets/squeezedcombobox.h"
+#include <squeezedcombobox.h>
 #include "kis_clipboard.h"
 #include "widgets/kis_cmb_idlist.h"
 #include "KoColorSpace.h"
@@ -127,7 +127,16 @@ GeneralTab::GeneralTab(QWidget *_parent, const char *_name)
     m_hideSplashScreen->setChecked(cfg.hideSplashScreen());
 
     KConfigGroup group = KSharedConfig::openConfig()->group("File Dialogs");
-    m_chkNativeFileDialog->setChecked(!group.readEntry("DontUseNativeFileDialog", true));
+    bool dontUseNative = true;
+#ifdef Q_OS_UNIX
+    if (qgetenv("XDG_CURRENT_DESKTOP") == "KDE") {
+        dontUseNative = false;
+    }
+#endif
+#ifdef Q_OS_WIN
+    dontUseNative = false;
+#endif
+    m_chkNativeFileDialog->setChecked(!group.readEntry("DontUseNativeFileDialog", dontUseNative));
 
     intMaxBrushSize->setValue(cfg.readEntry("maximumBrushSize", 1000));
 
