@@ -23,6 +23,7 @@
 #include <KoCanvasBase.h>
 
 #include <kis_types.h>
+#include "kis_thread_safe_signal_compressor.h"
 
 class KoShapeManager;
 class KoToolProxy;
@@ -30,6 +31,7 @@ class KoViewConverter;
 class KUndo2Command;
 class QWidget;
 class KoUnit;
+class KisImageViewConverter;
 
 /**
  * KisShapeLayerCanvas is a special canvas implementation that Krita
@@ -38,47 +40,71 @@ class KoUnit;
  * Do NOT give this canvas to tools or to the KoCanvasController, it's
  * not made for that.
  */
-class KisShapeLayerCanvas : public QObject, public KoCanvasBase
+class KisShapeLayerCanvas : public KoCanvasBase
 {
     Q_OBJECT
 public:
 
-    KisShapeLayerCanvas(KisShapeLayer *parent, KoViewConverter * viewConverter);
-    virtual ~KisShapeLayerCanvas();
+    KisShapeLayerCanvas(KisShapeLayer *parent, KisImageWSP image);
+    ~KisShapeLayerCanvas() override;
 
     /// This canvas won't render onto a widget, but a projection
     void setProjection(KisPaintDeviceSP projection) {
         m_projection = projection;
     }
 
+    void setImage(KisImageWSP image);
+
     void prepareForDestroying();
-    void gridSize(QPointF *offset, QSizeF *spacing) const;
-    bool snapToGrid() const;
-    void addCommand(KUndo2Command *command);
-    KoShapeManager *shapeManager() const;
-    void updateCanvas(const QRectF& rc);
-    KoToolProxy * toolProxy() const;
-    KoViewConverter *viewConverter() const;
-    QWidget* canvasWidget();
-    const QWidget* canvasWidget() const;
-    KoUnit unit() const;
-    virtual void updateInputMethodInfo() {}
-    virtual void setCursor(const QCursor &) {}
+    void gridSize(QPointF *offset, QSizeF *spacing) const override;
+    bool snapToGrid() const override;
+    void addCommand(KUndo2Command *command) override;
+    KoShapeManager *shapeManager() const override;
+    KoSelectedShapesProxy *selectedShapesProxy() const override;
+    void updateCanvas(const QRectF& rc) override;
+    KoToolProxy * toolProxy() const override;
+    KoViewConverter* viewConverter() const override;
+    QWidget* canvasWidget() override;
+    const QWidget* canvasWidget() const override;
+    KoUnit unit() const override;
+    void updateInputMethodInfo() override {}
+    void setCursor(const QCursor &) override {}
+
+    void updateCanvas(const QVector<QRectF> &region);
+
+    void forceRepaint();
+
+    void resetCache();
+    bool hasChangedWhileBeingInvisible();
+    void rerenderAfterBeingInvisible();
 
 private Q_SLOTS:
+    friend class KisRepaintShapeLayerLayerJob;
     void repaint();
+    void slotStartAsyncRepaint();
+    void slotImageSizeChanged();
 Q_SIGNALS:
     void forwardRepaint();
 private:
 
     bool m_isDestroying;
-    KoViewConverter * m_viewConverter;
-    KoShapeManager * m_shapeManager;
+    QScopedPointer<KisImageViewConverter> m_viewConverter;
+    QScopedPointer<KoShapeManager> m_shapeManager;
+    QScopedPointer<KoSelectedShapesProxy> m_selectedShapesProxy;
     KisPaintDeviceSP m_projection;
     KisShapeLayer *m_parentLayer;
 
+    KisThreadSafeSignalCompressor m_asyncUpdateSignalCompressor;
+    volatile bool m_hasUpdateInCompressor = false;
+
+    bool m_hasChangedWhileBeingInvisible = false;
+
     QRegion m_dirtyRegion;
     QMutex m_dirtyRegionMutex;
+
+    QRect m_cachedImageRect;
+
+    KisImageWSP m_image;
 };
 
 #endif
