@@ -23,6 +23,9 @@
 #include <QEvent>
 #include <QTouchEvent>
 #include <QScopedPointer>
+#include <QPointer>
+#include <QQueue>
+#include <QElapsedTimer>
 
 #include "kis_input_manager.h"
 #include "kis_shortcut_matcher.h"
@@ -33,7 +36,7 @@
 #include "input/kis_tablet_debugger.h"
 #include "kis_timed_signal_threshold.h"
 #include "kis_signal_auto_connection.h"
-
+#include "kis_latency_tracker.h"
 
 class KisToolInvocationAction;
 
@@ -46,6 +49,7 @@ public:
     void addStrokeShortcut(KisAbstractInputAction* action, int index, const QList< Qt::Key >& modifiers, Qt::MouseButtons buttons);
     void addKeyShortcut(KisAbstractInputAction* action, int index,const QList<Qt::Key> &keys);
     void addTouchShortcut( KisAbstractInputAction* action, int index, KisShortcutConfiguration::GestureAction gesture );
+    bool addNativeGestureShortcut( KisAbstractInputAction* action, int index, KisShortcutConfiguration::GestureAction gesture );
     void addWheelShortcut(KisAbstractInputAction* action, int index, const QList< Qt::Key >& modifiers, KisShortcutConfiguration::MouseWheelMovement wheelAction);
     bool processUnhandledEvent(QEvent *event);
     void setupActions();
@@ -53,8 +57,8 @@ public:
 
     KisInputManager *q;
 
-    KisCanvas2 *canvas = 0;
-    KisToolProxy *toolProxy = 0;
+    QPointer<KisCanvas2> canvas;
+    QPointer<KisToolProxy> toolProxy;
 
     bool forwardAllEventsToTool = false;
     bool ignoringQtCursorEvents();
@@ -116,7 +120,7 @@ public:
 
     private:
         KisInputManager::Private *d;
-        QMap<QObject*, KisCanvas2*> canvasResolver;
+        QMap<QObject*, QPointer<KisCanvas2>> canvasResolver;
         int eatOneMouseStroke;
         KisTimedSignalThreshold focusSwitchThreshold;
         KisSignalAutoConnectionsStore thresholdConnections;
@@ -141,5 +145,15 @@ public:
     };
     EventEater eventEater;
 
-    bool containsPointer = true;
+    bool containsPointer = false;
+
+    int accumulatedScrollDelta = 0;
+
+    class TabletLatencyTracker : public KisLatencyTracker {
+    protected:
+        virtual qint64 currentTimestamp() const;
+        virtual void print(const QString &message);
+    };
+
+    KisSharedPtr<TabletLatencyTracker> tabletLatencyTracker;
 };
