@@ -21,8 +21,10 @@
 
 #include <QScopedPointer>
 #include <functional>
+#include "KisImportExportFilter.h"
 
 class QWidget;
+class QMutex;
 
 class KisAsyncActionFeedback
 {
@@ -30,7 +32,9 @@ public:
     KisAsyncActionFeedback(const QString &message, QWidget *parent);
     ~KisAsyncActionFeedback();
 
-    bool runAction(std::function<bool()> func);
+    KisImportExportFilter::ConversionStatus runAction(std::function<KisImportExportFilter::ConversionStatus()> func);
+    void runVoidAction(std::function<void()> func);
+    void waitForMutex(QMutex *mutex);
 
 private:
     struct Private;
