@@ -310,9 +310,6 @@ public:
     bool hideDockersFullscreen(bool defaultValue = false) const;
     void setHideDockersFullscreen(const bool value) const;
 
-    bool showDockerTitleBars(bool defaultValue = false) const;
-    void setShowDockerTitleBars(const bool value) const;
-
     bool showDockers(bool defaultValue = false) const;
     void setShowDockers(const bool value) const;
 
