@@ -22,6 +22,7 @@
 
 #include <QMimeData>
 #include <QBuffer>
+#include <QPointer>
 
 #include <KoColorSpaceConstants.h>
 
@@ -39,7 +40,7 @@
 #include <kis_paint_layer.h>
 #include <kis_group_layer.h>
 #include <kis_projection_leaf.h>
-
+#include <kis_shape_controller.h>
 
 #include "kis_dummies_facade_base.h"
 #include "kis_node_dummies_graph.h"
@@ -63,14 +64,16 @@ struct KisNodeModel::Private
     QTimer updateTimer;
 
     KisModelIndexConverterBase *indexConverter = 0;
-    KisDummiesFacadeBase *dummiesFacade = 0;
+    QPointer<KisDummiesFacadeBase> dummiesFacade = 0;
     bool needFinishRemoveRows = false;
     bool needFinishInsertRows = false;
     bool showRootLayer = false;
     bool showGlobalSelection = false;
     QPersistentModelIndex activeNodeIndex;
 
-    KisNodeDummy* parentOfRemovedNode = 0;
+    QPointer<KisNodeDummy> parentOfRemovedNode = 0;
+
+    QSet<quintptr> dropEnabled;
 };
 
 KisNodeModel::KisNodeModel(QObject * parent)
@@ -95,7 +98,10 @@ KisNodeSP KisNodeModel::nodeFromIndex(const QModelIndex &index) const
     Q_ASSERT(index.isValid());
 
     KisNodeDummy *dummy = m_d->indexConverter->dummyFromIndex(index);
-    return dummy->node();
+    if (dummy) {
+        return dummy->node();
+    }
+    return 0;
 }
 
 QModelIndex KisNodeModel::indexFromNode(KisNodeSP node) const
@@ -189,7 +195,8 @@ void KisNodeModel::updateSettings()
     m_d->showGlobalSelection = cfg.showGlobalSelection();
     if (m_d->showRootLayer != oldShowRootLayer || m_d->showGlobalSelection != oldShowGlobalSelection) {
         resetIndexConverter();
-        reset();
+        beginResetModel();
+        endResetModel();
     }
 }
 
@@ -247,16 +254,14 @@ void KisNodeModel::connectDummies(KisNodeDummy *dummy, bool needConnect)
 
 void KisNodeModel::setDummiesFacade(KisDummiesFacadeBase *dummiesFacade, KisImageWSP image, KisShapeController *shapeController, KisNodeSelectionAdapter *nodeSelectionAdapter, KisNodeInsertionAdapter *nodeInsertionAdapter)
 {
-    KisDummiesFacadeBase *oldDummiesFacade;
-    KisShapeController *oldShapeController;
-    oldShapeController = m_d->shapeController;
-    oldDummiesFacade = m_d->dummiesFacade;
+    QPointer<KisDummiesFacadeBase> oldDummiesFacade(m_d->dummiesFacade);
+    KisShapeController  *oldShapeController = m_d->shapeController;
 
     m_d->shapeController = shapeController;
     m_d->nodeSelectionAdapter = nodeSelectionAdapter;
     m_d->nodeInsertionAdapter = nodeInsertionAdapter;
 
-    if(oldDummiesFacade && m_d->image) {
+    if (oldDummiesFacade && m_d->image) {
         m_d->image->disconnect(this);
         oldDummiesFacade->disconnect(this);
         connectDummies(m_d->dummiesFacade->rootDummy(), false);
@@ -267,9 +272,9 @@ void KisNodeModel::setDummiesFacade(KisDummiesFacadeBase *dummiesFacade, KisImag
     m_d->parentOfRemovedNode = 0;
     resetIndexConverter();
 
-    if(m_d->dummiesFacade) {
+    if (m_d->dummiesFacade) {
         KisNodeDummy *rootDummy = m_d->dummiesFacade->rootDummy();
-        if(rootDummy) {
+        if (rootDummy) {
             connectDummies(rootDummy, true);
         }
 
@@ -285,13 +290,14 @@ void KisNodeModel::setDummiesFacade(KisDummiesFacadeBase *dummiesFacade, KisImag
         connect(m_d->dummiesFacade, SIGNAL(sigDummyChanged(KisNodeDummy*)),
                 SLOT(slotDummyChanged(KisNodeDummy*)));
 
-        if(m_d->image.isValid()) {
+        if (m_d->image.isValid()) {
             connect(m_d->image, SIGNAL(sigIsolatedModeChanged()), SLOT(slotIsolatedModeChanged()));
         }
     }
 
-    if(m_d->dummiesFacade != oldDummiesFacade || m_d->shapeController != oldShapeController) {
-        reset();
+    if (m_d->dummiesFacade != oldDummiesFacade || m_d->shapeController != oldShapeController) {
+        beginResetModel();
+        endResetModel();
     }
 }
 
@@ -360,15 +366,15 @@ void KisNodeModel::slotDummyChanged(KisNodeDummy *dummy)
     m_d->updateTimer.start(1000);
 }
 
-void addChangedIndex(const QModelIndex &index, QSet<QModelIndex> *indexes)
+void addChangedIndex(const QModelIndex &idx, QSet<QModelIndex> *indexes)
 {
-    if (!index.isValid() || indexes->contains(index)) return;
+    if (!idx.isValid() || indexes->contains(idx)) return;
 
-    indexes->insert(index);
+    indexes->insert(idx);
 
-    const int rowCount = index.model()->rowCount(index);
+    const int rowCount = idx.model()->rowCount(idx);
     for (int i = 0; i < rowCount; i++) {
-        addChangedIndex(index.child(i, 0), indexes);
+        addChangedIndex(idx.model()->index(i, 0, idx), indexes);
     }
 }
 
@@ -494,12 +500,20 @@ Qt::ItemFlags KisNodeModel::flags(const QModelIndex &index) const
 {
     if(!m_d->dummiesFacade || !index.isValid()) return Qt::ItemIsDropEnabled;
 
-    Qt::ItemFlags flags = Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEditable | Qt::ItemIsDropEnabled;
+    Qt::ItemFlags flags = Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEditable;
+    if (m_d->dropEnabled.contains(index.internalId())) {
+        flags |= Qt::ItemIsDropEnabled;
+    }
     return flags;
 }
 
 bool KisNodeModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
+    if (role == KisNodeModel::DropEnabled) {
+        const QMimeData *mimeData = static_cast<const QMimeData*>(value.value<void*>());
+        setDropEnabled(mimeData);
+        return true;
+    }
 
     if (role == KisNodeModel::ActiveRole || role == KisNodeModel::AlternateActiveRole) {
         QModelIndex parentIndex;
@@ -642,3 +656,51 @@ bool KisNodeModel::dropMimeData(const QMimeData * data, Qt::DropAction action, i
                                          m_d->nodeInsertionAdapter);
 }
 
+bool KisNodeModel::canDropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) const {
+    if (parent.isValid()) {
+        // drop occurred on an item. always return true as returning false will mess up
+        // QT5's drag handling (see KisNodeModel::setDropEnabled).
+        return true;
+    } else {
+        return QAbstractItemModel::canDropMimeData(data, action, row, column, parent);
+    }
+}
+
+void KisNodeModel::setDropEnabled(const QMimeData *data) {
+    // what happens here should really happen in KisNodeModel::canDropMimeData(), but QT5
+    // will mess up if an item's Qt::ItemIsDropEnabled does not match what is returned by
+    // canDropMimeData; specifically, if we set the flag, but decide in canDropMimeData()
+    // later on that an "onto" drag is not allowed, QT will display an drop indicator for
+    // insertion, but not perform any drop when the mouse is released.
+
+    // the only robust implementation seems to set all flags correctly, which is done here.
+
+    bool copyNode = false;
+    KisNodeList nodes = KisMimeData::loadNodesFast(data, m_d->image, m_d->shapeController, copyNode);
+    m_d->dropEnabled.clear();
+    updateDropEnabled(nodes);
+}
+
+void KisNodeModel::updateDropEnabled(const QList<KisNodeSP> &nodes, QModelIndex parent) {
+    for (int r = 0; r < rowCount(parent); r++) {
+        QModelIndex idx = index(r, 0, parent);
+
+        KisNodeSP target = nodeFromIndex(idx);
+
+        bool dropEnabled = true;
+        Q_FOREACH (const KisNodeSP &node, nodes) {
+            if (!target->allowAsChild(node)) {
+                dropEnabled = false;
+                break;
+            }
+        }
+        if (dropEnabled) {
+            m_d->dropEnabled.insert(idx.internalId());
+        }
+        emit dataChanged(idx, idx); // indicate to QT that flags() have changed
+
+        if (hasChildren(idx)) {
+            updateDropEnabled(nodes, idx);
+        }
+    }
+}
