@@ -65,11 +65,12 @@
 #include "kis_node_manager.h"
 #include "KisViewManager.h"
 #include "kis_canvas_resource_provider.h"
-#include "kis_resource_server_provider.h"
+#include "KisResourceServerProvider.h"
 #include "kis_favorite_resource_manager.h"
 #include "kis_config.h"
 
 #include "widgets/kis_popup_button.h"
+#include "widgets/kis_iconwidget.h"
 #include "widgets/kis_tool_options_popup.h"
 #include "widgets/kis_paintop_presets_popup.h"
 #include "widgets/kis_tool_options_popup.h"
@@ -130,7 +131,7 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
         m_toolOptionsPopupButton->setFixedSize(iconsize, iconsize);
     }
 
-    m_brushEditorPopupButton = new KisPopupButton(this);
+    m_brushEditorPopupButton = new KisIconWidget(this);
     m_brushEditorPopupButton->setIcon(KisIconUtils::loadIcon("paintop_settings_02"));
     m_brushEditorPopupButton->setToolTip(i18n("Edit brush settings"));
     m_brushEditorPopupButton->setFixedSize(iconsize, iconsize);
@@ -160,15 +161,6 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     KisAction* alphaLockAction = m_viewManager->actionManager()->createAction("preserve_alpha");
     m_alphaLockButton->setDefaultAction(alphaLockAction);
 
-
-    // pen pressure
-    m_disablePressureButton = new KisHighlightedToolButton(this);
-    m_disablePressureButton->setFixedSize(iconsize, iconsize);
-    m_disablePressureButton->setCheckable(true);
-
-    m_disablePressureAction = m_viewManager->actionManager()->createAction("disable_pressure");
-    m_disablePressureButton->setDefaultAction(m_disablePressureAction);
-
     // horizontal and vertical mirror toolbar buttons
 
     // mirror tool options for the X Mirror
@@ -331,17 +323,6 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     action->setText(i18n("Brush composite"));
     action->setDefaultWidget(compositeActions);
 
-    QWidget* compositePressure = new QWidget(this);
-    QHBoxLayout* pressureLayout = new QHBoxLayout(compositePressure);
-    pressureLayout->addWidget(m_disablePressureButton);
-    pressureLayout->setSpacing(4);
-    pressureLayout->setContentsMargins(0, 0, 0, 0);
-
-    action = new QWidgetAction(this);
-    view->actionCollection()->addAction("pressure_action", action);
-    action->setText(i18n("Pressure usage (small button)"));
-    action->setDefaultWidget(compositePressure);
-
     action = new QWidgetAction(this);
     KisActionRegistry::instance()->propertizeAction("brushslider1", action);
     view->actionCollection()->addAction("brushslider1", action);
@@ -463,8 +444,9 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     connect(m_cmbCompositeOp     , SIGNAL(currentIndexChanged(int))           , SLOT(slotSetCompositeMode(int)));
     connect(m_eraseAction          , SIGNAL(toggled(bool))                    , SLOT(slotToggleEraseMode(bool)));
     connect(alphaLockAction      , SIGNAL(toggled(bool))                    , SLOT(slotToggleAlphaLockMode(bool)));
-    connect(m_disablePressureAction  , SIGNAL(toggled(bool))                    , SLOT(slotDisablePressureMode(bool)));
 
+    m_disablePressureAction = m_viewManager->actionManager()->createAction("disable_pressure");
+    connect(m_disablePressureAction  , SIGNAL(toggled(bool))                    , SLOT(slotDisablePressureMode(bool)));
     m_disablePressureAction->setChecked(true);
 
     connect(m_hMirrorAction        , SIGNAL(toggled(bool))                    , SLOT(slotHorizontalMirrorChanged(bool)));
@@ -500,6 +482,31 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     connect(view->mainWindow(), SIGNAL(themeChanged()), this, SLOT(slotUpdateSelectionIcon()));
 
     slotInputDeviceChanged(KoToolManager::instance()->currentInputDevice());
+
+    KisPaintOpPresetResourceServer *rserver = KisResourceServerProvider::instance()->paintOpPresetServer();
+    m_eraserName = "eraser_circle";
+    m_defaultPresetName = "basic_tip_default";
+    bool foundEraser = false;
+    bool foundTip = false;
+    for (int i=0; i<rserver->resourceCount(); i++) {
+        KisPaintOpPresetSP resource = rserver->resources().at(i);
+        if (resource->name().toLower().contains("eraser_circle")) {
+            m_eraserName = resource->name();
+            foundEraser = true;
+        } else if (foundEraser == false && (resource->name().toLower().contains("eraser") ||
+                                            resource->filename().toLower().contains("eraser"))) {
+            m_eraserName = resource->name();
+            foundEraser = true;
+        }
+        if (resource->name().toLower().contains("basic_tip_default")) {
+            m_defaultPresetName = resource->name();
+            foundTip = true;
+        } else if (foundTip == false && (resource->name().toLower().contains("default") ||
+                                         resource->filename().toLower().contains("default"))) {
+            m_defaultPresetName = resource->name();
+            foundTip = true;
+        }
+    }
 }
 
 KisPaintopBox::~KisPaintopBox()
@@ -628,10 +635,8 @@ void KisPaintopBox::setCurrentPaintop(KisPaintOpPresetSP preset)
 
 
     // load the current brush engine icon for the brush editor toolbar button
-    KisPaintOpFactory* paintOp = KisPaintOpRegistry::instance()->get(paintop.id());
-    QString pixFilename = KoResourcePaths::findResource("kis_images", paintOp->pixmap());
 
-    m_brushEditorPopupButton->setIcon(QIcon(pixFilename));
+    m_brushEditorPopupButton->slotSetItem(preset.data());
     m_presetsPopup->setCurrentPaintOpId(paintop.id());
 
 
@@ -769,20 +774,20 @@ void KisPaintopBox::slotInputDeviceChanged(const KoInputDevice& inputDevice)
 
     if (toolData == m_tabletToolMap.end()) {
         KisConfig cfg;
-        KisPaintOpPresetResourceServer *rserver = KisResourceServerProvider::instance()->paintOpPresetServer(false);
+        KisPaintOpPresetResourceServer *rserver = KisResourceServerProvider::instance()->paintOpPresetServer();
         KisPaintOpPresetSP preset;
         if (inputDevice.pointer() == QTabletEvent::Eraser) {
-            preset = rserver->resourceByName(cfg.readEntry<QString>(QString("LastEraser_%1").arg(inputDevice.uniqueTabletId()), "Eraser_circle"));
+            preset = rserver->resourceByName(cfg.readEntry<QString>(QString("LastEraser_%1").arg(inputDevice.uniqueTabletId()), m_eraserName));
         }
         else {
-            preset = rserver->resourceByName(cfg.readEntry<QString>(QString("LastPreset_%1").arg(inputDevice.uniqueTabletId()), "Basic_tip_default"));
+            preset = rserver->resourceByName(cfg.readEntry<QString>(QString("LastPreset_%1").arg(inputDevice.uniqueTabletId()), m_defaultPresetName));
             //if (preset)
                 //qDebug() << "found stored preset " << preset->name() << "for" << inputDevice.uniqueTabletId();
             //else
-                //qDebug() << "no preset fcound for" << inputDevice.uniqueTabletId();
+                //qDebug() << "no preset found for" << inputDevice.uniqueTabletId();
         }
         if (!preset) {
-            preset = rserver->resourceByName("Basic_tip_default");
+            preset = rserver->resourceByName(m_defaultPresetName);
         }
         if (preset) {
             //qDebug() << "inputdevicechanged 1" << preset;
@@ -803,10 +808,18 @@ void KisPaintopBox::slotInputDeviceChanged(const KoInputDevice& inputDevice)
 
 void KisPaintopBox::slotCreatePresetFromScratch(QString paintop)
 {
-    slotSetPaintop(paintop);  // change the paintop settings area and update the UI
-    m_presetsPopup->setCreatingBrushFromScratch(true); // disable UI elements while creating from scratch
-
-    KisPaintOpPresetSP preset = m_resourceProvider->currentPreset();
+    //First try to select an available default preset for that engine. If it doesn't exist, then
+    //manually set the engine to use a new preset.
+    KoID id(paintop, KisPaintOpRegistry::instance()->get(paintop)->name());
+    KisPaintOpPresetSP preset = defaultPreset(id);
+    if (!preset) {
+        slotSetPaintop(paintop);  // change the paintop settings area and update the UI
+        m_presetsPopup->setCreatingBrushFromScratch(true); // disable UI elements while creating from scratch
+        preset = m_resourceProvider->currentPreset();
+    } else {
+        m_resourceProvider->setPaintOpPreset(preset);
+        preset->setOptionsWidget(m_optionWidget);
+    }
     m_presetsPopup->resourceSelected(preset.data());  // this helps update the UI on the brush editor
 }
 
@@ -1157,9 +1170,9 @@ void KisPaintopBox::slotToggleAlphaLockMode(bool checked)
 void KisPaintopBox::slotDisablePressureMode(bool checked)
 {
     if (checked) {
-        m_disablePressureButton->actions()[0]->setIcon(KisIconUtils::loadIcon("transform_icons_penPressure"));
+        m_disablePressureAction->setIcon(KisIconUtils::loadIcon("transform_icons_penPressure"));
     } else {
-        m_disablePressureButton->actions()[0]->setIcon(KisIconUtils::loadIcon("transform_icons_penPressure_locked"));
+        m_disablePressureAction->setIcon(KisIconUtils::loadIcon("transform_icons_penPressure_locked"));
     }
 
     m_resourceProvider->setDisablePressure(checked);
@@ -1188,6 +1201,18 @@ void KisPaintopBox::slotGuiChangedCurrentPreset() // Called only when UI is chan
          */
 
         KisPaintOpPreset::UpdatedPostponer postponer(preset.data());
+
+
+        QStringList preserveProperties;
+        preserveProperties << "lodUserAllowed";
+        preserveProperties << "lodSizeThreshold";
+
+        // clear all the properties before dumping the stuff into the preset,
+        // some of the options add the values incrementally
+        // (e.g. KisPaintOpUtils::RequiredBrushFilesListTag), therefore they
+        // may add up if we pass the same preset multiple times
+        preset->settings()->resetSettings(preserveProperties);
+
         m_optionWidget->writeConfigurationSafe(const_cast<KisPaintOpSettings*>(preset->settings().data()));
     }
 
@@ -1278,9 +1303,9 @@ void KisPaintopBox::slotUpdateSelectionIcon()
     m_reloadAction->setIcon(KisIconUtils::loadIcon("view-refresh"));
 
     if (m_disablePressureAction->isChecked()) {
-        m_disablePressureButton->setIcon(KisIconUtils::loadIcon("transform_icons_penPressure"));
+        m_disablePressureAction->setIcon(KisIconUtils::loadIcon("transform_icons_penPressure"));
     } else {
-        m_disablePressureButton->setIcon(KisIconUtils::loadIcon("transform_icons_penPressure_locked"));
+        m_disablePressureAction->setIcon(KisIconUtils::loadIcon("transform_icons_penPressure_locked"));
     }
 }
 
