@@ -52,6 +52,7 @@ class KoCanvasController;
 class KisViewManager;
 class KisCanvasResourceProvider;
 class KisPopupButton;
+class KisIconWidget;
 class KisToolOptionsPopup;
 class KisPaintOpPresetsPopup;
 class KisPaintOpPresetsChooserPopup;
@@ -186,12 +187,11 @@ private:
     KisPopupButton*                     m_toolOptionsPopupButton;
 
     KisPresetSaveWidget*                m_savePresetWidget;
-    KisPopupButton*                     m_brushEditorPopupButton;
+    KisIconWidget*                     m_brushEditorPopupButton;
     KisPopupButton*                     m_presetSelectorPopupButton;
     KisCompositeOpComboBox*             m_cmbCompositeOp;
     QToolButton*                        m_eraseModeButton;
     QToolButton*                        m_alphaLockButton;
-    QToolButton*                        m_disablePressureButton;
     QToolButton*                        m_hMirrorButton;
     QToolButton*                        m_vMirrorButton;
     KisToolOptionsPopup*                m_toolOptionsPopup;
@@ -263,6 +263,9 @@ private:
     bool             m_eraserBrushOpacityEnabled;
 
     KisSignalAutoConnectionsStore m_presetConnections;
+
+    QString m_eraserName;
+    QString m_defaultPresetName;
 };
 
 #endif //KIS_PAINTOP_BOX_H_
