@@ -65,6 +65,7 @@
 #include <KoColorModelStandardIds.h>
 #include "dialogs/kis_dlg_png_import.h"
 #include "kis_clipboard.h"
+#include <kis_cursor_override_hijacker.h>
 
 namespace
 {
@@ -572,12 +573,12 @@ KisImageBuilder_Result KisPNGConverter::buildImage(QIODevice* iod)
             quint32 behaviour = cfg.pasteBehaviour();
             if (behaviour == PASTE_ASK) {
                 KisDlgPngImport dlg(m_path, csName.first, csName.second);
-                QApplication::restoreOverrideCursor();
+                KisCursorOverrideHijacker hijacker;
+                Q_UNUSED(hijacker);
                 dlg.exec();
                 if (!dlg.profile().isEmpty()) {
                     profile = KoColorSpaceRegistry::instance()->profileByName(dlg.profile());
                 }
-                QApplication::setOverrideCursor(Qt::WaitCursor);
 
             }
         }
@@ -644,18 +645,20 @@ KisImageBuilder_Result KisPNGConverter::buildImage(QIODevice* iod)
         dbgFile << "There are " << num_comments << " comments in the text";
         for (int i = 0; i < num_comments; i++) {
             QString key = QString(text_ptr[i].key).toLower();
-            dbgFile << "key is |" << text_ptr[i].key << "| containing " << text_ptr[i].text << " " << (key ==  "Raw profile type exif ");
+            dbgFile << "key: " << text_ptr[i].key
+                    << ", containing: " << text_ptr[i].text
+                    << ": " << (key == "raw profile type exif " ? "isExif" : "something else");
             if (key == "title") {
                 info->setAboutInfo("title", text_ptr[i].text);
             } else if (key == "description") {
                 info->setAboutInfo("comment", text_ptr[i].text);
             } else if (key == "author") {
                 info->setAuthorInfo("creator", text_ptr[i].text);
-            } else if (key.contains("Raw profile type exif")) {
+            } else if (key.contains("raw profile type exif")) {
                 decode_meta_data(text_ptr + i, layer->metaData(), "exif", 6);
-            } else if (key.contains("Raw profile type iptc")) {
+            } else if (key.contains("raw profile type iptc")) {
                 decode_meta_data(text_ptr + i, layer->metaData(), "iptc", 14);
-            } else if (key.contains("Raw profile type xmp")) {
+            } else if (key.contains("raw profile type xmp")) {
                 decode_meta_data(text_ptr + i, layer->metaData(), "xmp", 0);
             } else if (key == "version") {
                 m_image->addAnnotation(new KisAnnotation("kpp_version", "version", QByteArray(text_ptr[i].text)));
@@ -1082,7 +1085,7 @@ KisImageBuilder_Result KisPNGConverter::buildFile(QIODevice* iodevice, const QRe
     }
 
     // save comments from the document information
-    // warning: according to the official png spec, the keys need to be capitalised!
+    // warning: according to the official png spec, the keys need to be capitalized!
     if (m_doc) {
         png_text texts[4];
         int nbtexts = 0;
@@ -1097,9 +1100,9 @@ KisImageBuilder_Result KisPNGConverter::buildFile(QIODevice* iodevice, const QRe
             abstract = info->aboutInfo("abstract");
         }
         if (!abstract.isEmpty() && options.storeMetaData) {
-            QString keywords = info->aboutInfo("keywords");
+            QString keywords = info->aboutInfo("keyword");
             if (!keywords.isEmpty()) {
-                abstract = abstract + "keywords: " + keywords;
+                abstract = abstract + " keywords: " + keywords;
             }
             fillText(texts + nbtexts, "Description", abstract);
             nbtexts++;
@@ -1113,9 +1116,11 @@ KisImageBuilder_Result KisPNGConverter::buildFile(QIODevice* iodevice, const QRe
 
         QString author = info->authorInfo("creator");
         if (!author.isEmpty() && options.storeAuthor) {
-            QString contact = info->authorContactInfo().at(0);
-            if (!contact.isEmpty()) {
-                author = author+"("+contact+")";
+            if (!info->authorContactInfo().isEmpty()) {
+                QString contact = info->authorContactInfo().at(0);
+                if (!contact.isEmpty()) {
+                    author = author+"("+contact+")";
+                }
             }
             fillText(texts + nbtexts, "Author", author);
             nbtexts++;
