@@ -21,8 +21,11 @@
 #define KIS_OPENGL_CANVAS_2_H
 
 #include <QOpenGLWidget>
-#include <QOpenGLFunctions_3_0>
+#ifndef Q_OS_OSX
+#include <QOpenGLFunctions>
+#else
 #include <QOpenGLFunctions_3_2_Core>
+#endif
 #include "canvas/kis_canvas_widget_base.h"
 #include "opengl/kis_opengl_image_textures.h"
 
@@ -35,8 +38,8 @@ class QOpenGLShaderProgram;
 class QPainterPath;
 
 #ifndef Q_MOC_RUN
-#ifndef Q_OS_MAC
-#define GLFunctions QOpenGLFunctions_3_0
+#ifndef Q_OS_OSX
+#define GLFunctions QOpenGLFunctions
 #else
 #define GLFunctions QOpenGLFunctions_3_2_Core
 #endif
@@ -78,8 +81,6 @@ public:
     void renderDecorations(QPainter *painter);
     void paintToolOutline(const QPainterPath &path);
 
-    bool needsFpsDebugging() const;
-
 public: // Implement kis_abstract_canvas_widget interface
     void setDisplayFilter(QSharedPointer<KisDisplayFilter> displayFilter) override;
     void setWrapAroundViewingMode(bool value) override;
@@ -99,8 +100,9 @@ public: // Implement kis_abstract_canvas_widget interface
 
     KisOpenGLImageTexturesSP openGLImageTextures() const;
 
-private Q_SLOTS:
+public Q_SLOTS:
     void slotConfigChanged();
+    void slotPixelGridModeChanged();
 
 protected: // KisCanvasWidgetBase
     bool callFocusNextPrevChild(bool next) override;
@@ -112,6 +114,7 @@ private:
     void reportFailedShaderCompilation(const QString &context);
     void drawImage();
     void drawCheckers();
+    void drawGrid();
 
 private:
 
