@@ -90,8 +90,6 @@ KisToolPaint::KisToolPaint(KoCanvasBase * canvas, const QCursor & cursor)
 
     m_opacity = OPACITY_OPAQUE_U8;
 
-    updateTabletPressureSamples();
-
     m_supportOutline = false;
 
     {
@@ -163,7 +161,6 @@ void KisToolPaint::canvasResourceChanged(int key, const QVariant& v)
     }
 
     connect(KisConfigNotifier::instance(), SIGNAL(configChanged()), SLOT(resetCursorStyle()), Qt::UniqueConnection);
-    connect(KisConfigNotifier::instance(), SIGNAL(configChanged()), SLOT(updateTabletPressureSamples()), Qt::UniqueConnection);
 
 }
 
@@ -381,7 +378,7 @@ void KisToolPaint::addPickerJob(const PickingJob &pickingJob)
     m_pickingResource = colorPreviewResourceId(pickingJob.action);
 
     KisPaintDeviceSP device = fromCurrentNode ?
-        currentNode()->projection() : image()->projection();
+        currentNode()->colorPickSourceDevice() : image()->projection();
 
     image()->addJob(m_pickerStrokeId,
                     new KisColorPickerStrokeStrategy::Data(device, imagePoint));
@@ -601,14 +598,6 @@ void KisToolPaint::slotPopupQuickHelp()
     QWhatsThis::showText(QCursor::pos(), quickHelp());
 }
 
-void KisToolPaint::updateTabletPressureSamples()
-{
-    KisConfig cfg;
-    KisCubicCurve curve;
-    curve.fromString(cfg.pressureTabletCurve());
-    m_pressureSamples = curve.floatTransfer(LEVEL_OF_PRESSURE_RESOLUTION + 1);
-}
-
 void KisToolPaint::setupPaintAction(KisRecordedPaintAction* action)
 {
     KisTool::setupPaintAction(action);
@@ -628,6 +617,9 @@ KisToolPaint::NodePaintAbility KisToolPaint::nodePaintAbility()
     if (node->inherits("KisShapeLayer")) {
         return VECTOR;
     }
+    if (node->inherits("KisCloneLayer")) {
+        return CLONE;
+    }
     if (node->paintDevice()) {
         return PAINT;
     }
