@@ -191,9 +191,28 @@ void KisLodAvailabilityWidget::setLimitations(const KisPaintopLodLimitations &l)
         m_d->btnLod->setFont(font);
         m_d->btnLod->setText(text);
         m_d->btnLod->setToolTip(toolTip);
+
+        if (isBlocked) {
+            /**
+             * If LoD is really blocked by some limitation we sneakly reset
+             * the checkbox to let the user know it is fully disabled.
+             */
+
+            KisSignalsBlocker b(m_d->chkLod);
+            m_d->chkLod->setChecked(false);
+        }
     }
 
     m_d->limitations = l;
+
+    if (m_d->resourceManager) {
+        const bool lodAvailableForUse =
+            !isBlocked && !isBlockedByThreshold &&
+            m_d->resourceManager->resource(KisCanvasResourceProvider::LodAvailability).toBool();
+
+        m_d->resourceManager->setResource(KisCanvasResourceProvider::EffectiveLodAvailablility, lodAvailableForUse);
+    }
+
 }
 
 void KisLodAvailabilityWidget::slotUserChangedLodAvailability(bool value)
