@@ -26,6 +26,11 @@
 #include <KoID.h>
 #include <kis_types.h>
 #include <brushengine/kis_paintop_factory.h>
+#include "../kis_paint_ops_model.h"
+#include <kis_action.h>
+#include <widgets/kis_paintop_presets_save.h>
+#include "widgets/kis_paintop_presets_popup.h"
+#include "kis_favorite_resource_manager.h"
 
 class QString;
 class KisCanvasResourceProvider;
@@ -41,16 +46,15 @@ class KisPaintOpPresetsPopup : public QWidget
 
 public:
 
-    KisPaintOpPresetsPopup(KisCanvasResourceProvider * resourceProvider, QWidget * parent = 0);
+    KisPaintOpPresetsPopup(KisCanvasResourceProvider * resourceProvider,
+                           KisFavoriteResourceManager* favoriteResourceManager,
+                           KisPresetSaveWidget* savePresetWidget,
+                           QWidget * parent = 0);
 
-    ~KisPaintOpPresetsPopup();
+    ~KisPaintOpPresetsPopup() override;
 
     void setPaintOpSettingsWidget(QWidget * widget);
 
-    /**
-     * @return the name entered in the preset name lineedit
-     */
-    QString getPresetName() const;
 
     ///Image for preset preview
     ///@return image cut out from the scratchpad
@@ -58,14 +62,16 @@ public:
 
     void setPaintOpList(const QList<KisPaintOpFactory*>& list);
 
-    void setCurrentPaintOp(const QString & paintOpId);
-    QString currentPaintOp();
-    
+    void setCurrentPaintOpId(const QString & paintOpId);
+
+    /// returns the internal ID for the paint op (brush engine)
+    QString currentPaintOpId();
+
     ///fill the cutoutOverlay rect with the cotent of an image, used to get the image back when selecting a preset
     ///@param image image that will be used, should be image of an existing preset resource
     void setPresetImage(const QImage& image);
 
-    virtual void resizeEvent(QResizeEvent* );
+    void resizeEvent(QResizeEvent* ) override;
 
     bool detached() const;
 
@@ -73,23 +79,32 @@ public:
 
     void currentPresetChanged(KisPaintOpPresetSP  preset);
 
+    KisPresetSaveWidget * saveDialog;
+
+    // toggle the state when we are creating a brush from scratch
+    void setCreatingBrushFromScratch(bool enable);
+
 protected:
-    void contextMenuEvent(QContextMenuEvent *);
-    void hideEvent(QHideEvent *);
-    void showEvent(QShowEvent *);
+    void contextMenuEvent(QContextMenuEvent *) override;
+    void hideEvent(QHideEvent *) override;
+    void showEvent(QShowEvent *) override;
 
 public Q_SLOTS:
-    void slotWatchPresetNameLineEdit();
     void switchDetached(bool show = true);
-    void hideScratchPad();
-    void showScratchPad();
     void resourceSelected(KoResource* resource);
     void updateThemedIcons();
 
+
+    void slotUpdatePresetSettings();
     void slotUpdateLodAvailability();
+    void slotRenameBrushActivated();
+    void slotRenameBrushDeactivated();
+    void slotSaveRenameCurrentBrush();
+    void slotCreateNewBrushPresetEngine();
 
 Q_SIGNALS:
     void savePresetClicked();
+    void saveBrushPreset();
     void defaultPresetClicked();
     void paintopActivated(const QString& presetName);
     void signalResourceSelected(KoResource* resource);
@@ -97,21 +112,37 @@ Q_SIGNALS:
     void dirtyPresetToggled(bool value);
     void eraserBrushSizeToggled(bool value);
     void eraserBrushOpacityToggled(bool value);
-    
     void sizeChanged();
     void brushEditorShown();
+    void createPresetFromScratch(const QString& paintOpName);
 
 private Q_SLOTS:
-    void slotSwitchPresetStrip(bool visible);
     void slotSwitchScratchpad(bool visible);
     void slotResourceChanged(int key, const QVariant &value);
     void slotLodAvailabilityChanged(bool value);
+    void slotLodThresholdChanged(qreal value);
+    void slotSwitchShowEditor(bool visible);
+    void slotUpdatePaintOpFilter();
+    void slotSwitchShowPresets(bool visible);
+    void slotSaveBrushPreset();
+    void slotSaveNewBrushPreset();
+
+    /// we do not delete brushe presets, but blacklist them so they disappear from the interface
+    void slotBlackListCurrentPreset();
 
 private:
 
     struct Private;
     Private * const m_d;
+    QString current_paintOpId;
+    QList<KisPaintOpInfo> sortedBrushEnginesList;
 
+
+    QMenu * newPresetBrushEnginesMenu;
+    QList<KisAction*> newBrushEngineOptions;
+
+
+    void toggleBrushRenameUIActive(bool isRenaming);
 };
 
 #endif
