@@ -32,7 +32,7 @@
 #include <QTimer>
 #include <QtDebug>
 #include <QDoubleSpinBox>
-
+#include "kis_cursor.h"
 #include "KisPart.h"
 #include "input/kis_input_manager.h"
 
@@ -111,6 +111,7 @@ KisAbstractSliderSpinBox::KisAbstractSliderSpinBox(QWidget* parent, KisAbstractS
     d->parseInt = false;
 
     setExponentRatio(1.0);
+    setCursor(KisCursor::splitHCursor());
 
     //Set sane defaults
     setFocusPolicy(Qt::StrongFocus);
@@ -142,7 +143,6 @@ void KisAbstractSliderSpinBox::showEdit()
     d->edit->show();
     d->edit->setFocus(Qt::OtherFocusReason);
     update();
-    KisPart::currentInputManager()->slotFocusOnEnter(false);
 }
 
 void KisAbstractSliderSpinBox::hideEdit()
@@ -150,7 +150,6 @@ void KisAbstractSliderSpinBox::hideEdit()
     Q_D(KisAbstractSliderSpinBox);
     d->edit->hide();
     update();
-    KisPart::currentInputManager()->slotFocusOnEnter(true);
 }
 
 void KisAbstractSliderSpinBox::paintEvent(QPaintEvent* e)
@@ -496,6 +495,25 @@ void KisAbstractSliderSpinBox::wheelEvent(QWheelEvent *e)
     e->accept();
 }
 
+bool KisAbstractSliderSpinBox::event(QEvent *event)
+{
+    if (event->type() == QEvent::ShortcutOverride){
+        QKeyEvent* key = static_cast<QKeyEvent*>(event);
+        if (key->modifiers() == Qt::NoModifier){
+            switch(key->key()){
+            case Qt::Key_Up:
+            case Qt::Key_Right:
+            case Qt::Key_Down:
+            case Qt::Key_Left:
+                event->accept();
+                return true;
+            default: break;
+            }
+        }
+    }
+    return QWidget::event(event);
+}
+
 void KisAbstractSliderSpinBox::commitEnteredValue()
 {
     Q_D(KisAbstractSliderSpinBox);
