@@ -49,7 +49,7 @@ KoEditColorSetWidget::KoEditColorSetWidget(const QList<KoColorSet *> &palettes,
 {
     widget.setupUi(this);
     foreach (KoColorSet *colorSet, m_colorSets) {
-        colorSet->load();
+        //colorSet->load(); resources are loaded at startup...
         widget.selector->addItem(colorSet->name());
     }
     connect(widget.selector, SIGNAL(currentIndexChanged(int)), this, SLOT(setActiveColorSet(int)));
@@ -117,6 +117,7 @@ KoEditColorSetWidget::~KoEditColorSetWidget()
 void KoEditColorSetWidget::setActiveColorSet(int index)
 {
     if (m_gridLayout) {
+        qDeleteAll(m_gridLayout->children());
         delete m_gridLayout;
         m_activePatch = 0;
     }
@@ -129,14 +130,16 @@ void KoEditColorSetWidget::setActiveColorSet(int index)
     m_activeColorSet = m_colorSets.value(index);
     setEnabled(m_activeColorSet != 0);
     int columns = 16;
+
     if (m_activeColorSet) {
         columns = m_activeColorSet->columnCount();
         if (columns==0){columns=16;}
         widget.remove->setEnabled(false);
-        for (int i = 0; i < m_activeColorSet->nColors(); i++) {
+        for (quint32 i = 0; i < m_activeColorSet->nColors(); i++) {
             KoColorPatch *patch = new KoColorPatch(widget.patchesFrame);
-            patch->setColor(m_activeColorSet->getColor(i).color);
-            patch->setToolTip(m_activeColorSet->getColor(i).name);
+            KoColorSetEntry c = m_activeColorSet->getColorGlobal(i);
+            patch->setColor(c.color);
+            patch->setToolTip(c.name);
             connect(patch, SIGNAL(triggered(KoColorPatch *)), this, SLOT(setTextLabel(KoColorPatch *)));
             m_gridLayout->addWidget(patch, i/columns, i%columns);
         }
@@ -183,9 +186,10 @@ void KoEditColorSetWidget::addColor()
 void KoEditColorSetWidget::removeColor()
 {
     Q_ASSERT(m_activeColorSet);
-    for (int i = 0; i < m_activeColorSet->nColors(); i++) {
-        if (m_activePatch->color() == m_activeColorSet->getColor(i).color) {
-            m_activeColorSet->remove(m_activeColorSet->getColor(i));
+    for (quint32 i = 0; i < m_activeColorSet->nColors(); i++) {
+        KoColorSetEntry c = m_activeColorSet->getColorGlobal(i);
+        if (m_activePatch->color() == c.color) {
+            m_activeColorSet->removeAt(i);
             setActiveColorSet(widget.selector->currentIndex());
             break;
         }
@@ -197,7 +201,7 @@ void KoEditColorSetWidget::open()
     Q_ASSERT(m_activeColorSet);
     KoFileDialog dialog(this, KoFileDialog::OpenFile, "OpenColorSet");
     dialog.setDefaultDir(m_activeColorSet->filename());
-    dialog.setMimeTypeFilters(QStringList() << "application/x-gimp-color-palette", "application/x-gimp-color-palette");
+    dialog.setMimeTypeFilters(QStringList() << "application/x-gimp-color-palette");
     QString fileName = dialog.filename();
     KoColorSet *colorSet = new KoColorSet(fileName);
     colorSet->load();
