@@ -30,6 +30,7 @@
 #include <QScroller>
 
 #include "kritawidgets_export.h"
+#include <QPushButton>
 
 class QModelIndex;
 class QAbstractProxyModel;
@@ -129,12 +130,10 @@ private Q_SLOTS:
     void clicked(const QModelIndex &index);
     void contextMenuRequested(const QPoint &pos);
     void baseLengthChanged(int length);
-
+    void updateView();
     void slotBeforeResourcesLayoutReset(KoResource *activateAfterReset);
     void slotAfterResourcesLayoutReset();
 
-    void updateView();
-
 protected:
     void showEvent(QShowEvent *event) override;
 
@@ -152,6 +151,10 @@ private:
 
     class Private;
     Private *const d;
+
+   QPushButton *importButton;
+   QPushButton *deleteButton;
+
 };
 
 #endif // KO_RESOURCE_ITEM_CHOOSER
