@@ -40,6 +40,10 @@
 #include "KoResourceTagStore.h"
 #include "KoResourcePaths.h"
 
+
+#include <kconfiggroup.h>
+#include <ksharedconfig.h>
+
 #include "kritawidgets_export.h"
 #include "WidgetsDebug.h"
 
@@ -66,7 +70,7 @@ public:
 
     virtual int resourceCount() const = 0;
     virtual void loadResources(QStringList filenames) = 0;
-    virtual QStringList blackListedFiles() const = 0;
+    virtual QStringList blackListedFiles() = 0;
     virtual QStringList queryResources(const QString &query) const = 0;
     QString type() const { return m_type; }
 
@@ -76,20 +80,21 @@ public:
     */
     QString extensions() const { return m_extensions; }
 
-    QStringList fileNames() const
+    QStringList fileNames()
     {
         QStringList extensionList = m_extensions.split(':');
         QStringList fileNames;
 
         foreach (const QString &extension, extensionList) {
             fileNames += KoResourcePaths::findAllResources(type().toLatin1(), extension, KoResourcePaths::Recursive);
-
         }
         return fileNames;
     }
 
 protected:
 
+    QStringList m_blackListFileNames;
+
     friend class KoResourceTagStore;
     virtual KoResource *byMd5(const QByteArray &md5) const = 0;
     virtual KoResource *byFileName(const QString &fileName) const = 0;
@@ -137,7 +142,6 @@ public:
         m_blackListFile = KoResourcePaths::locateLocal("data", type + ".blacklist");
         m_blackListFileNames = readBlackListFile();
         m_tagStore = new KoResourceTagStore(this);
-        m_tagStore->loadTags();
     }
 
     ~KoResourceServer() override
@@ -197,8 +201,7 @@ public:
                 Q_FOREACH (PointerType resource, resources) {
                     Q_CHECK_PTR(resource);
                     if (resource->load() && resource->valid() && !resource->md5().isEmpty()) {
-                        QByteArray md5 = resource->md5();
-                        m_resourcesByMd5[md5] = resource;
+                        addResourceToMd5Registry(resource);
 
                         m_resourcesByFilename[resource->shortFilename()] = resource;
 
@@ -225,10 +228,16 @@ public:
         Q_FOREACH (ObserverType* observer, m_observers) {
             observer->syncTaggedResourceView();
         }
-
-        debugWidgets << "done loading  resources for type " << type();
+//        qDebug() << "done loading  resources for type " << type();
     }
 
+    void loadTags() {
+        m_tagStore->loadTags();
+    }
+
+    void clearOldSystemTags() {
+        m_tagStore->clearOldSystemTags();
+    }
 
     /// Adds an already loaded resource to the server
     bool addResource(PointerType resource, bool save = true, bool infront = false) {
@@ -270,7 +279,7 @@ public:
         }
 
         m_resourcesByFilename[resource->shortFilename()] = resource;
-        m_resourcesByMd5[resource->md5()] = resource;
+        addResourceToMd5Registry(resource);
         m_resourcesByName[resource->name()] = resource;
         if (infront) {
             m_resources.insert(0, resource);
@@ -284,28 +293,24 @@ public:
         return true;
     }
 
-    /*Removes a given resource from the blacklist.
+    /**
+     * Removes a given resource from the blacklist.
      */
     bool removeFromBlacklist(PointerType resource) {
         if (m_blackListFileNames.contains(resource->filename())) {
             m_blackListFileNames.removeAll(resource->filename());
             writeBlackListFile();
-            }
-            else{
-                warnWidgets<<"Doesn't contain filename";
-                return false;
-            }
-
-
-        //then return true//
-        return true;
+            return true;
+        }
+        return false;
     }
+
     /// Remove a resource from Resource Server but not from a file
     bool removeResourceFromServer(PointerType resource){
         if ( !m_resourcesByFilename.contains( resource->shortFilename() ) ) {
             return false;
         }
-        m_resourcesByMd5.remove(resource->md5());
+        removeResourceFromMd5Registry(resource);
         m_resourcesByName.remove(resource->name());
         m_resourcesByFilename.remove(resource->shortFilename());
         m_resources.removeAt(m_resources.indexOf(resource));
@@ -323,7 +328,7 @@ public:
         if ( !m_resourcesByFilename.contains( resource->shortFilename() ) ) {
             return false;
         }
-        m_resourcesByMd5.remove(resource->md5());
+        removeResourceFromMd5Registry(resource);
         m_resourcesByName.remove(resource->name());
         m_resourcesByFilename.remove(resource->shortFilename());
         m_resources.removeAt(m_resources.indexOf(resource));
@@ -479,8 +484,21 @@ public:
         notifyResourceChanged(resource);
     }
 
-    QStringList blackListedFiles() const override
+    QStringList blackListedFiles() override
     {
+        if (type() == "kis_resourcebundles") {
+            KConfigGroup group = KSharedConfig::openConfig()->group("BundleHack");
+            if (group.readEntry("HideKrita3Bundle", true)) {
+                Q_FOREACH(const QString &filename, fileNames()) {
+                    if (filename.endsWith("Krita_3_Default_Resources.bundle")) {
+                        if (!m_blackListFileNames.contains(filename)) {
+                            m_blackListFileNames.append(filename);
+                        }
+                    }
+                }
+            }
+//            qDebug() << "blacklisted filenames" << m_blackListFileNames;
+        }
         return m_blackListFileNames;
     }
 
@@ -629,10 +647,20 @@ protected:
             QDomNode n = file.firstChild();
             QDomElement e = n.toElement();
             if (e.tagName() == "name") {
-                filenameList.append((e.text()).replace(QString("~"),QDir::homePath()));
+                // If the krita bundle has landed in the blacklist, skip it.
+                if (type() == "kis_resourcebundles") {
+//                    qDebug() << "Checking for not reading bundle" << e.text();
+                    if (e.text().endsWith("Krita_3_Default_Resources.bundle")) {
+                        file = file.nextSiblingElement("file");
+                    }
+                }
+                filenameList.append(e.text().replace(QString("~"), QDir::homePath()));
             }
             file = file.nextSiblingElement("file");
         }
+//        if (type() == "kis_resourcebundles") {
+//            qDebug() << "Read bundle blacklist" << filenameList;
+//        }
         return filenameList;
     }
 
@@ -656,9 +684,16 @@ protected:
         doc.appendChild(root);
 
         Q_FOREACH (QString filename, m_blackListFileNames) {
+
+            // Don't write the krita3 bundle to the blacklist, since its location will change
+            // when using the appimate.
+            if (type() == "kis_resourcebundles") {
+//                qDebug() << "Checking for Not writing krita 3 bundle" << filename;
+                if (filename.endsWith("Krita_3_Default_Resources.bundle")) continue;
+            }
             QDomElement fileEl = doc.createElement("file");
             QDomElement nameEl = doc.createElement("name");
-            QDomText nameText = doc.createTextNode(filename.replace(QDir::homePath(),QString("~")));
+            QDomText nameText = doc.createTextNode(filename.replace(QDir::homePath(), QString("~")));
             nameEl.appendChild(nameText);
             fileEl.appendChild(nameEl);
             root.appendChild(fileEl);
@@ -681,6 +716,21 @@ protected:
         return Policy::toResourcePointer(resourceByFilename(fileName));
     }
 
+private:
+    void addResourceToMd5Registry(PointerType resource) {
+        const QByteArray md5 = resource->md5();
+        if (!md5.isEmpty()) {
+            m_resourcesByMd5.insert(md5, resource);
+        }
+    }
+
+    void removeResourceFromMd5Registry(PointerType resource) {
+        const QByteArray md5 = resource->md5();
+        if (!md5.isEmpty()) {
+            m_resourcesByMd5.remove(md5);
+        }
+    }
+
 private:
 
     QHash<QString, PointerType> m_resourcesByName;
@@ -691,21 +741,20 @@ private:
     QList<PointerType> m_resources; ///< list of resources in order of addition
     QList<ObserverType*> m_observers;
     QString m_blackListFile;
-    QStringList m_blackListFileNames;
     KoResourceTagStore* m_tagStore;
 
 };
 
 template <class T, class Policy = PointerStoragePolicy<T> >
-    class KoResourceServerSimpleConstruction : public KoResourceServer<T, Policy>
+class KoResourceServerSimpleConstruction : public KoResourceServer<T, Policy>
 {
 public:
     KoResourceServerSimpleConstruction(const QString& type, const QString& extensions)
-: KoResourceServer<T, Policy>(type, extensions)
+        : KoResourceServer<T, Policy>(type, extensions)
     {
     }
 
-typename KoResourceServer<T, Policy>::PointerType createResource( const QString & filename ) override {
+    typename KoResourceServer<T, Policy>::PointerType createResource( const QString & filename ) override {
         return new T(filename);
     }
 };
