@@ -1,4 +1,4 @@
- /*  This file is part of the KDE project
+/*  This file is part of the KDE project
 
     Copyright (c) 2011 Sven Langkamp <sven.langkamp@gmail.com>
     Copyright (C) 2011 Srikanth Tiyyagura <srikanth.tulasiram@gmail.com>
@@ -28,6 +28,11 @@
 #include <KoResourcePaths.h>
 #include <KoResourceServer.h>
 
+#include <kis_debug.h>
+
+#define BLACKLISTED "blacklisted" ///< xml tag for blacklisted tags
+
+static const QStringList krita3PresetSystemTags = {"Ink", "Block", "Wet", "FX", "Erasers", "Circle", "Smudge", "Mix", "PixelArt", "ink", "sketch", "demo", "paint"};
 
 class Q_DECL_HIDDEN KoResourceTagStore::Private
 {
@@ -37,6 +42,8 @@ public:
 
     QHash<QString, int> tagList;
 
+    QStringList blacklistedTags;
+
     KoResourceServerBase *resourceServer;
 };
 
@@ -80,36 +87,48 @@ void KoResourceTagStore::removeResource(const KoResource *resource)
 
 QStringList KoResourceTagStore::tagNamesList() const
 {
-    return d->tagList.uniqueKeys();
+    QStringList tagList = d->tagList.uniqueKeys();
+    Q_FOREACH(const QString &tag, d->blacklistedTags) {
+        tagList.removeAll(tag);
+    }
+    return tagList;
 }
 
 void KoResourceTagStore::addTag(KoResource* resource, const QString& tag)
 {
-    if (!resource) {
+//    if (d->resourceServer->type() == "kis_paintoppresets" && resource) {
+//        qDebug() << "\t\t\taddTag" << tag << resource->filename() << d->tagList[tag] << d->md5ToTag.value(resource->md5()) << d->identifierToTag.values(resource->filename());
+//    }
+
+    if (d->blacklistedTags.contains(tag)) {
+        d->blacklistedTags.removeAll(tag);
+    }
+
+    if (!d->tagList.contains(tag)) {
         d->tagList.insert(tag, 0);
-        return;
     }
 
-    bool added = false;
+    if (resource) {
+        bool added = false;
 
-    if (!d->md5ToTag.contains(resource->md5(), tag)) {
-        added = true;
-        d->md5ToTag.insert(resource->md5(), tag);
-    }
+        if (!d->md5ToTag.contains(resource->md5(), tag)) {
+            added = true;
+            d->md5ToTag.insert(resource->md5(), tag);
+        }
 
-    if (!d->identifierToTag.contains(resource->filename())) {
-        added = true;
-        d->identifierToTag.insert(resource->filename(), tag);
-    }
+        if (!d->identifierToTag.contains(resource->filename())) {
+            added = true;
+            d->identifierToTag.insert(resource->filename(), tag);
+        }
 
-    if (added) {
-        if (d->tagList.contains(tag)) {
+        if (added) {
             d->tagList[tag]++;
         }
-        else {
-            d->tagList.insert(tag, 1);
-        }
     }
+//    if (d->resourceServer->type() == "kis_paintoppresets" && resource) {
+//        qDebug() << "\t\t\t\tafter addTag" << tag << resource->filename() << d->tagList[tag] << d->md5ToTag.value(resource->md5()) << d->identifierToTag.values(resource->filename());
+//    }
+
 }
 
 void KoResourceTagStore::delTag(KoResource* resource, const QString& tag)
@@ -138,6 +157,8 @@ void KoResourceTagStore::delTag(const QString& tag)
     Q_ASSERT(!d->md5ToTag.values().contains(tag));
     Q_ASSERT(!d->identifierToTag.values().contains(tag));
     d->tagList.remove(tag);
+    d->blacklistedTags << tag;
+    serializeTags();
 }
 
 QStringList KoResourceTagStore::searchTag(const QString& query) const
@@ -149,7 +170,7 @@ QStringList KoResourceTagStore::searchTag(const QString& query) const
 
     QSet<const KoResource*> resources;
 
-    foreach (QString tag, tagsList) {
+    Q_FOREACH (QString tag, tagsList) {
         Q_FOREACH (const QByteArray &md5, d->md5ToTag.keys(tag)) {
             KoResource *res = d->resourceServer->byMd5(md5);
             if (res)
@@ -163,30 +184,40 @@ QStringList KoResourceTagStore::searchTag(const QString& query) const
     }
 
     QStringList filenames;
-    foreach (const KoResource *res, resources) {
+    Q_FOREACH (const KoResource *res, resources) {
         if (res) {
-            filenames << adjustedFileName(res->shortFilename());
+            filenames << res->shortFilename();
         }
     }
-
-    return removeAdjustedFileNames(filenames);
+    return filenames;
 }
 
 void KoResourceTagStore::loadTags()
 {
     QStringList tagFiles = KoResourcePaths::findDirs("tags");
-
-    //qDebug() << "Going to load tags" << tagFiles;
-
     Q_FOREACH (const QString &tagFile, tagFiles) {
-        readXMLFile(tagFile + d->resourceServer->type() + "_tags.xml");
+        QString fileName = tagFile + d->resourceServer->type() + "_tags.xml";
+        if (QFileInfo(fileName).exists()) {
+            readXMLFile(fileName);
+        }
+    }
+}
+
+void KoResourceTagStore::clearOldSystemTags()
+{
+    if (d->resourceServer->type() == "kis_paintoppresets") {
+//        qDebug() << "clearOldSystemTags" << d->tagList;
+        Q_FOREACH(const QString &systemTag, krita3PresetSystemTags) {
+//            qDebug() << "\t" << systemTag << d->tagList[systemTag];
+            if (d->tagList[systemTag] == 0) {
+                d->tagList.remove(systemTag);
+            }
+        }
     }
 }
 
 void KoResourceTagStore::writeXMLFile(const QString &tagstore)
 {
-    //qDebug() << "writing tags to" << tagstore;
-
     QFile f(tagstore);
     if (!f.open(QIODevice::WriteOnly | QIODevice::Text)) {
         warnWidgets << "Cannot write meta information to '" << tagstore << "'.";
@@ -202,28 +233,29 @@ void KoResourceTagStore::writeXMLFile(const QString &tagstore)
     doc.appendChild(root);
 
     QSet<KoResource*> taggedResources;
-    foreach (const QByteArray &md5, d->md5ToTag.keys()) {
+    Q_FOREACH (const QByteArray &md5, d->md5ToTag.keys()) {
         KoResource *res = d->resourceServer->byMd5(md5);
         if (res) {
             taggedResources << res;
         }
     }
 
-    foreach (const QString &identifier, d->identifierToTag.keys()) {
+    Q_FOREACH (const QString &identifier, d->identifierToTag.keys()) {
         KoResource *res = d->resourceServer->byFileName(identifier);
         if (res) {
             taggedResources << res;
         }
     }
 
-    foreach (const KoResource *res, taggedResources) {
+    Q_FOREACH (const KoResource *res, taggedResources) {
 
         QDomElement resourceEl = doc.createElement("resource");
         resourceEl.setAttribute("identifier", res->filename().replace(QDir::homePath(), QString("~")));
         resourceEl.setAttribute("md5", QString(res->md5().toBase64()));
 
-        foreach (const QString &tag, assignedTagsList(res)) {
+        Q_FOREACH (const QString &tag, assignedTagsList(res)) {
             QDomElement tagEl = doc.createElement("tag");
+            tagEl.setAttribute(BLACKLISTED, "false");
             tagEl.appendChild(doc.createTextNode(tag));
             resourceEl.appendChild(tagEl);
         }
@@ -232,11 +264,25 @@ void KoResourceTagStore::writeXMLFile(const QString &tagstore)
     }
 
     // Now write empty tags
-    foreach (const QString &tag, d->tagList.uniqueKeys())  {
+    Q_FOREACH (const QString &tag, d->tagList.uniqueKeys())  {
         if (d->tagList[tag] == 0) {
             QDomElement resourceEl = doc.createElement("resource");
             resourceEl.setAttribute("identifier", "dummy");
             QDomElement tagEl = doc.createElement("tag");
+            tagEl.setAttribute(BLACKLISTED, d->blacklistedTags.contains(tag) ? "true" : "false");
+            tagEl.appendChild(doc.createTextNode(tag));
+            resourceEl.appendChild(tagEl);
+            root.appendChild(resourceEl);
+        }
+    }
+
+    // Now write blacklisted tags.
+    Q_FOREACH (const QString &tag, d->blacklistedTags)  {
+        if (d->tagList[tag] == 0) {
+            QDomElement resourceEl = doc.createElement("resource");
+            resourceEl.setAttribute("identifier", "dummy");
+            QDomElement tagEl = doc.createElement("tag");
+            tagEl.setAttribute(BLACKLISTED, "true");
             tagEl.appendChild(doc.createTextNode(tag));
             resourceEl.appendChild(tagEl);
             root.appendChild(resourceEl);
@@ -253,18 +299,24 @@ void KoResourceTagStore::writeXMLFile(const QString &tagstore)
 
 void KoResourceTagStore::readXMLFile(const QString &tagstore)
 {
-    //qDebug() << "Reading tags from" << tagstore;
-
     QString inputFile;
     if (QFile::exists(tagstore)) {
         inputFile = tagstore;
-    } else {
-        //qDebug() << "\tdoesn't exist";
+    }
+    else {
         return;
     }
 
+//    qDebug() << "\treadXMLFile()." << tagstore  << d->resourceServer->type() << "Server has" << d->resourceServer->resourceCount() << "resources";
+    if (d->resourceServer->type() == "kis_paintoppresets") {
+        Q_FOREACH(const QString &line, kisBacktrace().split("\n")) {
+//            qDebug() << line;
+        }
+    }
+
     QFile f(inputFile);
     if (!f.open(QIODevice::ReadOnly)) {
+        qWarning() << "Could not open tag file" << tagstore;
         return;
     }
 
@@ -304,24 +356,21 @@ void KoResourceTagStore::readXMLFile(const QString &tagstore)
                 resByFileName = d->resourceServer->byFileName(fi.fileName());
             }
 
-            if (identifier == "dummy" || isServerResource(identifier)) {
+//            qDebug() << "\t\tmd5" << QString::fromLatin1(resourceMD5.toHex()) << "resByMd5" << resByMd5 << "identifier" << identifier << "resByFileName" << resByFileName;
 
+            if (identifier == "dummy") {
                 QDomNodeList tagNodesList = resourceNodesList.at(i).childNodes();
-
                 for (int j = 0; j < tagNodesList.count() ; j++) {
-
                     QDomElement tagEl = tagNodesList.at(j).toElement();
-
-                    if (identifier != "dummy") {
-                        QFileInfo fi(identifier);
-                        KoResource *res = d->resourceServer->byFileName(fi.fileName());
-                        addTag(res, tagEl.text());
+                    bool blacklisted = (tagEl.attribute(BLACKLISTED, "false") == "true");
+                    if (blacklisted || d->blacklistedTags.contains(tagEl.text())) {
+                        if (!d->blacklistedTags.contains(tagEl.text())) {
+                            d->blacklistedTags << tagEl.text();
+                        }
                     }
                     else {
                         addTag(0, tagEl.text());
                     }
-                    d->md5ToTag.insert(resourceMD5, tagEl.text());
-                    d->identifierToTag.insert(identifier, tagEl.text());
                 }
             }
             else {
@@ -342,48 +391,24 @@ void KoResourceTagStore::readXMLFile(const QString &tagstore)
                 QDomNodeList tagNodesList = resourceNodesList.at(i).childNodes();
                 for (int j = 0; j < tagNodesList.count() ; j++) {
                     QDomElement tagEl = tagNodesList.at(j).toElement();
-
-                    if (res) {
-                        addTag(res, tagEl.text());
+                    bool blacklisted = (tagEl.attribute(BLACKLISTED, "false") == "true");
+                    if (blacklisted || d->blacklistedTags.contains(tagEl.text())) {
+                        if (!d->blacklistedTags.contains(tagEl.text())) {
+                            d->blacklistedTags << tagEl.text();
+                        }
+                    }
+                    else {
+                        if (res) {
+                            addTag(res, tagEl.text());
+                        }
+                        d->md5ToTag.insert(resourceMD5, tagEl.text());
+                        d->identifierToTag.insert(identifier, tagEl.text());
                     }
-                    d->md5ToTag.insert(resourceMD5, tagEl.text());
-                    d->identifierToTag.insert(identifier, tagEl.text());
                 }
             }
         }
     }
-}
-
-bool KoResourceTagStore::isServerResource(const QString &resourceName) const
-{
-    bool removeChild = false;
-    QStringList extensionsList = d->resourceServer->extensions().split(':');
-    foreach (QString extension, extensionsList) {
-        if (resourceName.contains(extension.remove('*'))) {
-            removeChild = true;
-            break;
-        }
-    }
-    return removeChild;
-}
-
-QString KoResourceTagStore::adjustedFileName(const QString &fileName) const
-{
-    if (!isServerResource(fileName)) {
-        return fileName + "-krita" + d->resourceServer->extensions().split(':').takeFirst().remove('*');
-    }
-    return fileName;
-}
-
-QStringList KoResourceTagStore::removeAdjustedFileNames(QStringList fileNamesList) const
-{
-    foreach (const QString & fileName, fileNamesList) {
-        if (fileName.contains("-krita")) {
-            fileNamesList.append(fileName.split("-krita").takeFirst());
-            fileNamesList.removeAll(fileName);
-        }
-    }
-    return fileNamesList;
+//    qDebug() << "Done reading XML file from" << tagstore << d->tagList;
 }
 
 void KoResourceTagStore::serializeTags()
