@@ -21,8 +21,6 @@
  */
 #include "KoToolDocker.h"
 
-#include <KoDockWidgetTitleBarButton.h>
-#include <KoDockWidgetTitleBar.h>
 #include <KoIcon.h>
 
 #include <klocalizedstring.h>
@@ -99,8 +97,7 @@ public:
             currentAuxWidgets.insert(t);
             Q_FOREACH (QPointer<QWidget> widget, currentWidgetList) {
                 if (widget.isNull() || widget->objectName().isEmpty()) {
-                    Q_ASSERT(!(widget->objectName().isEmpty()));
-                    continue; // skip this docker in release build when assert don't crash
+                    continue;
                 }
                 t->addTab(widget, widget->windowTitle());
             }
@@ -115,7 +112,7 @@ public:
                 housekeeperLayout->setVerticalSpacing(0);
                 Q_FOREACH (QPointer<QWidget> widget, currentWidgetList) {
                     if (widget.isNull() || widget->objectName().isEmpty()) {
-                        KIS_SAFE_ASSERT_RECOVER(!(widget->objectName().isEmpty())) { continue; }
+                        continue;
                     }
                     if (!widget->windowTitle().isEmpty()) {
                         housekeeperLayout->addWidget(l = new QLabel(widget->windowTitle()), 0, 2*cnt);
@@ -138,7 +135,7 @@ public:
                 int specialCount = 0;
                 Q_FOREACH (QPointer<QWidget> widget, currentWidgetList) {
                     if (widget.isNull() || widget->objectName().isEmpty()) {
-                        KIS_SAFE_ASSERT_RECOVER(!(widget->objectName().isEmpty())) { continue; }
+                        continue;
                     }
                     if (!widget->windowTitle().isEmpty()) {
                         housekeeperLayout->addWidget(l = new QLabel(widget->windowTitle()), cnt++, 0);
@@ -201,7 +198,6 @@ KoToolDocker::KoToolDocker(QWidget *parent)
     d->tabbed = cfg.readEntry("TabbedMode", false);
 
     setFeatures(DockWidgetMovable|DockWidgetFloatable);
-    setTitleBarWidget(new KoDockWidgetTitleBar(this));
 
     connect(this, SIGNAL(dockLocationChanged(Qt::DockWidgetArea )), this, SLOT(locationChanged(Qt::DockWidgetArea)));
 
