@@ -75,7 +75,7 @@ public:
                      QObject *parent = 0);
 
     /// destructor
-    ~KoZoomController();
+    ~KoZoomController() override;
 
     /// returns the zoomAction that is maintained by this controller
     KoZoomAction *zoomAction() const;
@@ -86,6 +86,11 @@ public:
      */
     void setZoomMode(KoZoomMode::Mode mode);
 
+    /**
+     * @return the current zoom mode.
+     */
+    KoZoomMode::Mode zoomMode() const;
+
     /**
      * Set the resolution, zoom, the zoom mode for this zoom Controller.
      * Typically for use just after construction to restore the
