@@ -28,7 +28,6 @@
 #include <QApplication>
 #include <QMutex>
 #include "kis_debug.h"
-
 #include "WidgetUtilsDebug.h"
 
 Q_GLOBAL_STATIC(KoResourcePaths, s_instance);
@@ -80,14 +79,14 @@ static const Qt::CaseSensitivity cs = Qt::CaseInsensitive;
 static const Qt::CaseSensitivity cs = Qt::CaseSensitive;
 #endif
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_OSX
 #include <ApplicationServices/ApplicationServices.h>
 #include <CoreFoundation/CoreFoundation.h>
 #include <CoreServices/CoreServices.h>
 #endif
 
 QString getInstallationPrefix() {
-#ifdef Q_OS_MAC
+#ifdef Q_OS_OSX
      QString appPath = qApp->applicationDirPath();
 
      debugWidgetUtils << "1" << appPath;
@@ -115,9 +114,23 @@ QString getInstallationPrefix() {
 
      debugWidgetUtils << ">>>>>>>>>>>" << bundlePath;
      return bundlePath;
- #else
-     return qApp->applicationDirPath() + "/../";
- #endif
+#else
+    #ifdef Q_OS_QWIN
+        QDir appdir(qApp->applicationDirPath());
+
+        // Corrects for mismatched case errors in path (qtdeclarative fails to load)
+        wchar_t buffer[1024];
+        QString absolute = appdir.absolutePath();
+        DWORD rv = ::GetShortPathName((wchar_t*)absolute.utf16(), buffer, 1024);
+        rv = ::GetLongPathName(buffer, buffer, 1024);
+        QString correctedPath((QChar *)buffer);
+        appdir.setPath(correctedPath);
+        appdir.cdUp();
+        return appdir.canonicalPath();
+    #else
+        return qApp->applicationDirPath() + "/../";
+    #endif
+#endif
 }
 
 class Q_DECL_HIDDEN KoResourcePaths::Private {
@@ -128,6 +141,8 @@ public:
     QMutex relativesMutex;
     QMutex absolutesMutex;
 
+    bool ready = false; // Paths have been initialized
+
     QStringList aliases(const QString &type)
     {
         QStringList r;
@@ -307,6 +322,7 @@ QString KoResourcePaths::findResourceInternal(const QString &type, const QString
         Q_FOREACH (const QString &alias, aliases) {
             resource = approot + "/share/" + alias + '/' + fileName;
             debugWidgetUtils << "\t1" << resource;
+
             if (QFile::exists(resource)) {
                 continue;
             }
@@ -343,7 +359,7 @@ QStringList KoResourcePaths::findDirsInternal(const QString &type)
             QStandardPaths::locateAll(d->mapTypeToQStandardPaths(type), alias + '/', QStandardPaths::LocateDirectory);
         appendResources(&dirs, aliasDirs, true);
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_OSX
         debugWidgetUtils << "MAC:" << getApplicationRoot();
         QStringList bundlePaths;
         bundlePaths << getApplicationRoot() + "/share/krita/" + alias;
@@ -443,7 +459,9 @@ QStringList KoResourcePaths::findAllResourcesInternal(const QString &type,
 
     debugWidgetUtils << "\tresources also from aliases:" << resources.size();
 
-    QFileInfo fi(filter);
+    // if the original filter is "input/*", we only want share/input/* and share/krita/input/* here, but not
+    // share/*. therefore, use _filter here instead of filter which was split into alias and "*".
+    QFileInfo fi(_filter);
 
     QStringList prefixResources;
     prefixResources << filesInDir(getInstallationPrefix() + "share/" + fi.path(), fi.fileName(), false);
@@ -534,3 +552,13 @@ QString KoResourcePaths::locateLocalInternal(const QString &type, const QString
     debugWidgetUtils << "locateLocal: type" << type << "filename" << filename << "CreateDir" << createDir << "path" << path;
     return path + '/' + filename;
 }
+
+void KoResourcePaths::setReady()
+{
+    s_instance->d->ready = true;
+}
+
+bool KoResourcePaths::isReady()
+{
+    return s_instance->d->ready;
+}
