@@ -130,6 +130,9 @@ QIcon loadIcon(const QString &name)
     return icon;
 }
 
+
+
+
 bool useDarkIcons() {
     QColor background = qApp->palette().background().color();
     return  background.value() > 100;
@@ -183,6 +186,12 @@ void updateIconCommon(QObject *object)
     }
 }
 
+void clearIconCache() {
+    #if defined CACHE_ICONS
+        s_cache.clear();
+    #endif
+}
+
 void updateIcon(QAbstractButton *button)
 {
     QIcon icon = button->icon();
