@@ -120,6 +120,18 @@ void TimelineDocker::setCanvas(KoCanvasBase * canvas)
             m_d->canvas->viewManager()->nodeManager(), SLOT(slotNonUiActivatedNode(KisNodeSP)));
 
         m_d->model->slotCurrentNodeChanged(m_d->canvas->viewManager()->activeNode());
+
+        m_d->canvasConnections.addConnection(
+                    m_d->canvas->viewManager()->mainWindow(), SIGNAL(themeChanged()),
+                    this, SLOT(slotUpdateIcons()) );
+    }
+
+}
+
+void TimelineDocker::slotUpdateIcons()
+{
+    if (m_d->view) {
+        m_d->view->slotUpdateIcons();
     }
 }
 
