@@ -18,10 +18,14 @@
 #ifndef _DIGITALMIXER_DOCK_H_
 #define _DIGITALMIXER_DOCK_H_
 
+#include <QPointer>
 #include <QDockWidget>
+
 #include <KoColor.h>
 #include <KoCanvasObserverBase.h>
 
+#include <KoCanvasBase.h>
+
 class KoColorPopupAction;
 class KoColorSlider;
 class KoColorPatch;
@@ -31,10 +35,10 @@ class DigitalMixerDock : public QDockWidget, public KoCanvasObserverBase {
     Q_OBJECT
 public:
     DigitalMixerDock( );
-    QString observerName() { return "DigitalMixerDock"; }
+    QString observerName() override { return "DigitalMixerDock"; }
     /// reimplemented from KoCanvasObserverBase
-    virtual void setCanvas(KoCanvasBase *canvas);
-    virtual void unsetCanvas() { m_canvas = 0; setEnabled(false);}
+    void setCanvas(KoCanvasBase *canvas) override;
+    void unsetCanvas() override { m_canvas = 0; setEnabled(false);}
 public Q_SLOTS:
     void setCurrentColor(const KoColor& );
     void canvasResourceChanged(int, const QVariant&);
@@ -43,7 +47,7 @@ private Q_SLOTS:
     void colorSliderChanged(int i);
     void targetColorChanged(int);
 private:
-    KoCanvasBase* m_canvas;
+    QPointer<KoCanvasBase> m_canvas;
     KoColor m_currentColor;
     KoColorPatch* m_currentColorPatch;
     struct Mixer {
