@@ -45,11 +45,11 @@
 #include <kis_display_color_converter.h>
 #include <kis_canvas2.h>
 #include <KoDialog.h>
-#include <QComboBox>
 #include <kis_color_button.h>
 #include <QCheckBox>
 #include <QFormLayout>
 #include <QLineEdit>
+#include <squeezedcombobox.h>
 
 #include "KisPaletteModel.h"
 #include "KisColorsetChooser.h"
@@ -88,7 +88,7 @@ PaletteDockerDock::PaletteDockerDock( )
     connect(m_wdgPaletteDock->paletteView, SIGNAL(entrySelected(KoColorSetEntry)), this, SLOT(entrySelected(KoColorSetEntry)));
     connect(m_wdgPaletteDock->paletteView, SIGNAL(entrySelectedBackGround(KoColorSetEntry)), this, SLOT(entrySelectedBack(KoColorSetEntry)));
 
-    KoResourceServer<KoColorSet>* rServer = KoResourceServerProvider::instance()->paletteServer(false);
+    KoResourceServer<KoColorSet>* rServer = KoResourceServerProvider::instance()->paletteServer();
     m_serverAdapter = QSharedPointer<KoAbstractResourceServerAdapter>(new KoResourceServerAdapter<KoColorSet>(rServer));
     m_serverAdapter->connectToResourceServer();
     rServer->addObserver(this);
@@ -100,7 +100,7 @@ PaletteDockerDock::PaletteDockerDock( )
     m_wdgPaletteDock->bnColorSets->setToolTip(i18n("Choose palette"));
     m_wdgPaletteDock->bnColorSets->setPopupWidget(m_colorSetChooser);
 
-    connect(m_wdgPaletteDock->cmbNameList, SIGNAL(currentIndexChanged(int)), this, SLOT(setColorFromNameList()));
+    connect(m_wdgPaletteDock->cmbNameList, SIGNAL(currentIndexChanged(int)), this, SLOT(setColorFromNameList(int)));
     KisConfig cfg;
     QString defaultPalette = cfg.defaultPalette();
     KoColorSet* defaultColorSet = rServer->resourceByName(defaultPalette);
@@ -178,32 +178,34 @@ void PaletteDockerDock::setColorSet(KoColorSet* colorSet)
     m_wdgPaletteDock->paletteView->updateView();
     m_wdgPaletteDock->paletteView->updateRows();
     m_wdgPaletteDock->cmbNameList->clear();
-    for (quint32 i = 0; i< colorSet->nColors(); i++) {
-        KoColorSetEntry entry = colorSet->getColorGlobal(i);
-        QPixmap colorSquare = QPixmap(32, 32);
-        if (entry.spotColor) {
-            QImage img = QImage(32, 32, QImage::Format_ARGB32);
-            QPainter circlePainter;
-            img.fill(Qt::transparent);
-            circlePainter.begin(&img);
-            QBrush brush = QBrush(Qt::SolidPattern);
-            brush.setColor(entry.color.toQColor());
-            circlePainter.setBrush(brush);
-            QPen pen = circlePainter.pen();
-            pen.setColor(Qt::transparent);
-            pen.setWidth(0);
-            circlePainter.setPen(pen);
-            circlePainter.drawEllipse(0, 0, 32, 32);
-            circlePainter.end();
-            colorSquare = QPixmap::fromImage(img);
-        } else {
-            colorSquare.fill(entry.color.toQColor());
+    if (colorSet->nColors()>0) {
+        for (quint32 i = 0; i< colorSet->nColors(); i++) {
+            KoColorSetEntry entry = colorSet->getColorGlobal(i);
+            QPixmap colorSquare = QPixmap(32, 32);
+            if (entry.spotColor) {
+                QImage img = QImage(32, 32, QImage::Format_ARGB32);
+                QPainter circlePainter;
+                img.fill(Qt::transparent);
+                circlePainter.begin(&img);
+                QBrush brush = QBrush(Qt::SolidPattern);
+                brush.setColor(entry.color.toQColor());
+                circlePainter.setBrush(brush);
+                QPen pen = circlePainter.pen();
+                pen.setColor(Qt::transparent);
+                pen.setWidth(0);
+                circlePainter.setPen(pen);
+                circlePainter.drawEllipse(0, 0, 32, 32);
+                circlePainter.end();
+                colorSquare = QPixmap::fromImage(img);
+            } else {
+                colorSquare.fill(entry.color.toQColor());
+            }
+            QString name = entry.name;
+            if (!entry.id.isEmpty()){
+                name = entry.id + " - " + entry.name;
+            }
+            m_wdgPaletteDock->cmbNameList->addSqueezedItem(QIcon(colorSquare), name);
         }
-        QString name = entry.name;
-        if (!entry.id.isEmpty()){
-            name = entry.id + " - " + entry.name;
-        }
-        m_wdgPaletteDock->cmbNameList->addItem(QIcon(colorSquare), name);
     }
     QCompleter *completer = new QCompleter(m_wdgPaletteDock->cmbNameList->model());
     completer->setCompletionMode(QCompleter::PopupCompletion);
@@ -220,15 +222,17 @@ void PaletteDockerDock::setColorSet(KoColorSet* colorSet)
     m_currentColorSet = colorSet;
 }
 
-void PaletteDockerDock::setColorFromNameList()
+void PaletteDockerDock::setColorFromNameList(int index)
 {
-    int index  = m_wdgPaletteDock->cmbNameList->currentIndex();
     if (m_model && m_currentColorSet) {
         entrySelected(m_currentColorSet->getColorGlobal(index));
         m_wdgPaletteDock->paletteView->blockSignals(true);
+        m_wdgPaletteDock->cmbNameList->blockSignals(true);
+        m_wdgPaletteDock->cmbNameList->setCurrentIndex(index);
         m_wdgPaletteDock->paletteView->selectionModel()->clearSelection();
         m_wdgPaletteDock->paletteView->selectionModel()->setCurrentIndex(m_model->indexFromId(index), QItemSelectionModel::Select);
         m_wdgPaletteDock->paletteView->blockSignals(false);
+        m_wdgPaletteDock->cmbNameList->blockSignals(false);
     }
 }
 
