@@ -28,14 +28,14 @@ class TasksetResource : public KoResource
 
 public:
     TasksetResource(const QString& filename);
-    virtual ~TasksetResource();
+    ~TasksetResource() override;
     
-    virtual bool load();
-    virtual bool loadFromDevice(QIODevice *dev);
-    virtual bool save();
-    virtual bool saveToDevice(QIODevice* dev) const;
+    bool load() override;
+    bool loadFromDevice(QIODevice *dev) override;
+    bool save() override;
+    bool saveToDevice(QIODevice* dev) const override;
 
-    virtual QString defaultFileExtension() const;
+    QString defaultFileExtension() const override;
     
     void setActionList(const QStringList actions);
     QStringList actionList();
