@@ -46,6 +46,8 @@
 #include <kis_file_name_requester.h>
 #include <KisDocument.h>
 #include <KoDialog.h>
+#include "kis_slider_spin_box.h"
+#include "kis_acyclic_signal_connector.h"
 
 DlgAnimationRenderer::DlgAnimationRenderer(KisDocument *doc, QWidget *parent)
     : KoDialog(parent)
@@ -65,6 +67,7 @@ DlgAnimationRenderer::DlgAnimationRenderer(KisDocument *doc, QWidget *parent)
 
     m_page = new WdgAnimaterionRenderer(this);
     m_page->layout()->setMargin(0);
+
     m_page->dirRequester->setMode(KoFileDialog::OpenDirectory);
     QString lastLocation = cfg.readEntry<QString>("AnimationRenderer/last_sequence_export_location", QStandardPaths::writableLocation(QStandardPaths::PicturesLocation));
     m_page->dirRequester->setFileName(lastLocation);
@@ -74,9 +77,28 @@ DlgAnimationRenderer::DlgAnimationRenderer(KisDocument *doc, QWidget *parent)
     m_page->intStart->setValue(doc->image()->animationInterface()->playbackRange().start());
 
     m_page->intEnd->setMinimum(doc->image()->animationInterface()->fullClipRange().start());
-    m_page->intEnd->setMaximum(doc->image()->animationInterface()->fullClipRange().end());
+   //m_page->intEnd->setMaximum(doc->image()->animationInterface()->fullClipRange().end()); // animators sometimes want to export after end frame
     m_page->intEnd->setValue(doc->image()->animationInterface()->playbackRange().end());
 
+
+
+    m_page->intHeight->setMinimum(1);
+    m_page->intHeight->setMaximum(10000);
+    m_page->intHeight->setValue(doc->image()->height());
+
+    m_page->intWidth->setMinimum(1);
+    m_page->intWidth->setMaximum(10000);
+    m_page->intWidth->setValue(doc->image()->width());
+
+
+    // try to lock the width and height being updated
+
+    KisAcyclicSignalConnector *constrainsConnector = new KisAcyclicSignalConnector(this);
+    constrainsConnector->createCoordinatedConnector()->connectBackwardInt(m_page->intWidth, SIGNAL(valueChanged(int)), this, SLOT(slotLockAspectRatioDimensionsWidth(int)));
+    constrainsConnector->createCoordinatedConnector()->connectForwardInt(m_page->intHeight, SIGNAL(valueChanged(int)), this, SLOT(slotLockAspectRatioDimensionsHeight(int)));
+
+    m_page->intFramesPerSecond->setValue(doc->image()->animationInterface()->framerate());
+
     QFileInfo audioFileInfo(doc->image()->animationInterface()->audioChannelFileName());
     const bool hasAudio = audioFileInfo.exists();
     m_page->chkIncludeAudio->setEnabled(hasAudio);
@@ -97,10 +119,8 @@ DlgAnimationRenderer::DlgAnimationRenderer(KisDocument *doc, QWidget *parent)
     }
 
     setMainWidget(m_page);
-    resize(m_page->sizeHint());
 
-    KoJsonTrader trader;
-    QList<QPluginLoader *>list = trader.query("Krita/AnimationExporter", "");
+    QList<QPluginLoader *>list = KoJsonTrader::instance()->query("Krita/AnimationExporter", "");
     Q_FOREACH(QPluginLoader *loader, list) {
         QJsonObject json = loader->metaData().value("MetaData").toObject();
         QStringList mimetypes = json.value("X-KDE-Export").toString().split(",");
@@ -139,7 +159,6 @@ DlgAnimationRenderer::DlgAnimationRenderer(KisDocument *doc, QWidget *parent)
 
     qDeleteAll(list);
 
-    connect(m_page->grpRender, SIGNAL(toggled(bool)), this, SLOT(toggleSequenceType(bool)));
     connect(m_page->bnExportOptions, SIGNAL(clicked()), this, SLOT(sequenceMimeTypeSelected()));
     connect(m_page->bnRenderOptions, SIGNAL(clicked()), this, SLOT(selectRenderOptions()));
 
@@ -147,22 +166,28 @@ DlgAnimationRenderer::DlgAnimationRenderer(KisDocument *doc, QWidget *parent)
     m_page->ffmpegLocation->setMode(KoFileDialog::OpenFile);
     connect(m_page->ffmpegLocation, SIGNAL(fileSelected(QString)), this, SLOT(ffmpegLocationChanged(QString)));
 
-    m_page->grpRender->setChecked(cfg.readEntry<bool>("AnimationRenderer/render_animation", false));
-    m_page->chkDeleteSequence->setChecked(cfg.readEntry<bool>("AnimationRenderer/delete_sequence", false));
     m_page->cmbRenderType->setCurrentIndex(cfg.readEntry<int>("AnimationRenderer/render_type", 0));
 
+
+    connect(m_page->shouldExportOnlyImageSequence, SIGNAL(toggled(bool)), this, SLOT(slotExportTypeChanged()));
+    connect(m_page->shouldExportOnlyVideo, SIGNAL(toggled(bool)), this, SLOT(slotExportTypeChanged()));
+    connect(m_page->shouldExportAll, SIGNAL(toggled(bool)), this, SLOT(slotExportTypeChanged()));
+
+    updateExportUIOptions();
+
     // connect and cold init
     connect(m_page->cmbRenderType, SIGNAL(currentIndexChanged(int)), this, SLOT(selectRenderType(int)));
     selectRenderType(m_page->cmbRenderType->currentIndex());
+
+    resize(m_page->sizeHint());
 }
 
 DlgAnimationRenderer::~DlgAnimationRenderer()
 {
     KisConfig cfg;
-    cfg.writeEntry<bool>("AnimationRenderer/render_animation", m_page->grpRender->isChecked());
+
     cfg.writeEntry<QString>("AnimationRenderer/last_sequence_export_location", m_page->dirRequester->fileName());
     cfg.writeEntry<int>("AnimationRenderer/render_type", m_page->cmbRenderType->currentIndex());
-    cfg.writeEntry<bool>("AnimationRenderer/delete_sequence", m_page->chkDeleteSequence->isChecked());
     cfg.setCustomFFMpegPath(m_page->ffmpegLocation->fileName());
 
     if (m_encoderConfigWidget)  {
@@ -178,12 +203,52 @@ DlgAnimationRenderer::~DlgAnimationRenderer()
 
 }
 
+QString DlgAnimationRenderer::fetchRenderingDirectory() const
+{
+    QString result = m_page->dirRequester->fileName();
+
+    if (m_page->shouldExportOnlyVideo->isChecked()) {
+        const QFileInfo info(fetchRenderingFileName());
+
+        if (info.isAbsolute()) {
+            result = info.absolutePath();
+        }
+    }
+
+    return result;
+}
+
+QString DlgAnimationRenderer::fetchRenderingFileName() const
+{
+    QString filename = m_page->videoFilename->fileName();
+
+    if (QFileInfo(filename).completeSuffix().isEmpty()) {
+        QString mimetype = m_page->cmbRenderType->itemData(m_page->cmbRenderType->currentIndex()).toString();
+        filename += "." + KisMimeDatabase::suffixesForMimeType(mimetype).first();
+    }
+
+    if (QFileInfo(filename).isRelative()) {
+        QDir baseDir(m_page->dirRequester->fileName());
+
+        if (m_page->shouldExportOnlyVideo->isChecked()) {
+            QString documentDir = QFileInfo(m_doc->url().toLocalFile()).absolutePath();
+            if (!documentDir.isEmpty()) {
+                baseDir = documentDir;
+            }
+        }
+
+        filename = baseDir.absoluteFilePath(filename);
+    }
+
+    return filename;
+}
+
 KisPropertiesConfigurationSP DlgAnimationRenderer::getSequenceConfiguration() const
 {
     KisPropertiesConfigurationSP cfg = new KisPropertiesConfiguration();
     cfg->setProperty("basename", m_page->txtBasename->text());
     cfg->setProperty("last_document_path", m_doc->localFilePath());
-    cfg->setProperty("directory", m_page->dirRequester->fileName());
+    cfg->setProperty("directory", fetchRenderingDirectory());
     cfg->setProperty("first_frame", m_page->intStart->value());
     cfg->setProperty("last_frame", m_page->intEnd->value());
     cfg->setProperty("sequence_start", m_page->sequenceStart->value());
@@ -202,9 +267,10 @@ void DlgAnimationRenderer::setSequenceConfiguration(KisPropertiesConfigurationSP
     }
 
     m_page->dirRequester->setFileName(cfg->getString("directory", QStandardPaths::writableLocation(QStandardPaths::PicturesLocation)));
-    m_page->intStart->setValue(cfg->getInt("first_frame", m_image->animationInterface()->playbackRange().start()));
+    m_page->intStart->setValue(cfg->getInt("first_frame", m_image->animationInterface()->playbackRange().start()));    
     m_page->intEnd->setValue(cfg->getInt("last_frame", m_image->animationInterface()->playbackRange().end()));
     m_page->sequenceStart->setValue(cfg->getInt("sequence_start", m_image->animationInterface()->playbackRange().start()));
+
     QString mimetype = cfg->getString("mimetype");
     for (int i = 0; i < m_page->cmbMimetype->count(); ++i) {
         if (m_page->cmbMimetype->itemData(i).toString() == mimetype) {
@@ -219,7 +285,7 @@ KisPropertiesConfigurationSP DlgAnimationRenderer::getFrameExportConfiguration()
     if (m_frameExportConfigWidget) {
         KisPropertiesConfigurationSP cfg = m_frameExportConfigWidget->configuration();
         cfg->setProperty("basename", m_page->txtBasename->text());
-        cfg->setProperty("directory", m_page->dirRequester->fileName());
+        cfg->setProperty("directory", fetchRenderingDirectory());
         cfg->setProperty("first_frame", m_page->intStart->value());
         cfg->setProperty("last_frame", m_page->intEnd->value());
         cfg->setProperty("sequence_start", m_page->sequenceStart->value());
@@ -230,27 +296,23 @@ KisPropertiesConfigurationSP DlgAnimationRenderer::getFrameExportConfiguration()
     return 0;
 }
 
-bool DlgAnimationRenderer::renderToVideo() const
-{
-    return m_page->grpRender->isChecked();
-}
-
 KisPropertiesConfigurationSP DlgAnimationRenderer::getVideoConfiguration() const
 {
-    if (!m_page->grpRender->isChecked()) {
+    // don't continue if we are only exporting image sequence
+    if (m_page->shouldExportOnlyImageSequence->isChecked()) {
         return 0;
     }
+
     KisPropertiesConfigurationSP cfg = new KisPropertiesConfiguration();
-    QString filename = m_page->videoFilename->fileName();
-    if (QFileInfo(filename).completeSuffix().isEmpty()) {
-        QString mimetype = m_page->cmbRenderType->itemData(m_page->cmbRenderType->currentIndex()).toString();
-        filename += "." + KisMimeDatabase::suffixesForMimeType(mimetype).first();
-    }
-    cfg->setProperty("filename", filename);
-    cfg->setProperty("delete_sequence", m_page->chkDeleteSequence->isChecked());
+    cfg->setProperty("filename", fetchRenderingFileName());
     cfg->setProperty("first_frame", m_page->intStart->value());
     cfg->setProperty("last_frame", m_page->intEnd->value());
     cfg->setProperty("sequence_start", m_page->sequenceStart->value());
+
+    // delete image sequence if we are only exporting out video
+    cfg->setProperty("delete_sequence", m_page->shouldExportOnlyVideo->isChecked());
+
+
     return cfg;
 }
 
@@ -260,26 +322,37 @@ void DlgAnimationRenderer::setVideoConfiguration(KisPropertiesConfigurationSP /*
 
 KisPropertiesConfigurationSP DlgAnimationRenderer::getEncoderConfiguration() const
 {
-    if (!m_page->grpRender->isChecked()) {
+    // don't continue if we are only exporting image sequence
+    if (m_page->shouldExportOnlyImageSequence->isChecked()) {
         return 0;
     }
+
     KisPropertiesConfigurationSP cfg = new KisPropertiesConfiguration();
     if (m_encoderConfigWidget) {
         cfg = m_encoderConfigWidget->configuration();
     }
     cfg->setProperty("mimetype", m_page->cmbRenderType->currentData().toString());
-    cfg->setProperty("directory", m_page->dirRequester->fileName());
+    cfg->setProperty("directory", fetchRenderingDirectory());
     cfg->setProperty("first_frame", m_page->intStart->value());
     cfg->setProperty("last_frame", m_page->intEnd->value());
+    cfg->setProperty("framerate", m_page->intFramesPerSecond->value());
+    cfg->setProperty("height", m_page->intHeight->value());
+    cfg->setProperty("width", m_page->intWidth->value());
     cfg->setProperty("sequence_start", m_page->sequenceStart->value());
     cfg->setProperty("include_audio", m_page->chkIncludeAudio->isChecked());
 
     return cfg;
 }
 
-void DlgAnimationRenderer::setEncoderConfiguration(KisPropertiesConfigurationSP /*cfg*/)
+void DlgAnimationRenderer::setEncoderConfiguration(KisPropertiesConfigurationSP cfg)
 {
+    m_page->intHeight->setValue(cfg->getInt("height", int(m_image->height())));
+    m_page->intWidth->setValue(cfg->getInt("width", int(m_image->width())));
+    m_page->intFramesPerSecond->setValue(cfg->getInt("framerate", int(m_image->animationInterface()->framerate())));
 
+    if (m_encoderConfigWidget) {
+        m_encoderConfigWidget->setConfiguration(cfg);
+    }
 }
 
 QSharedPointer<KisImportExportFilter> DlgAnimationRenderer::encoderFilter() const
@@ -325,7 +398,9 @@ void DlgAnimationRenderer::selectRenderOptions()
             dlg.setButtons(KoDialog::Ok | KoDialog::Cancel);
             if (!dlg.exec()) {
                 m_encoderConfigWidget->setConfiguration(filter->lastSavedConfiguration());
-            } 
+            } else {
+                KisConfig().setExportConfiguration(mimetype.toLatin1(), m_encoderConfigWidget->configuration());
+            }
             dlg.setMainWidget(0);
             m_encoderConfigWidget->hide();
             m_encoderConfigWidget->setParent(0);
@@ -337,17 +412,6 @@ void DlgAnimationRenderer::selectRenderOptions()
 
 }
 
-void DlgAnimationRenderer::toggleSequenceType(bool toggle)
-{
-    m_page->cmbMimetype->setEnabled(!toggle);
-    for (int i = 0; i < m_page->cmbMimetype->count(); ++i) {
-        if (m_page->cmbMimetype->itemData(i).toString() == "image/png") {
-            m_page->cmbMimetype->setCurrentIndex(i);
-            break;
-        }
-    }
-}
-
 void DlgAnimationRenderer::sequenceMimeTypeSelected()
 {
     int index = m_page->cmbMimetype->currentIndex();
@@ -358,7 +422,7 @@ void DlgAnimationRenderer::sequenceMimeTypeSelected()
     }
 
     QString mimetype = m_page->cmbMimetype->itemData(index).toString();
-    KisImportExportFilter *filter = KisImportExportManager::filterForMimeType(mimetype, KisImportExportManager::Export);
+    QSharedPointer<KisImportExportFilter> filter(KisImportExportManager::filterForMimeType(mimetype, KisImportExportManager::Export));
     if (filter) {
         m_frameExportConfigWidget = filter->createConfigurationWidget(0, KisDocument::nativeFormatMimeType(), mimetype.toLatin1());
         if (m_frameExportConfigWidget) {
@@ -373,7 +437,6 @@ void DlgAnimationRenderer::sequenceMimeTypeSelected()
             m_frameExportConfigWidget->setParent(0);
             dlg.setMainWidget(0);
         }
-        delete filter;
     }
 }
 
@@ -383,9 +446,24 @@ void DlgAnimationRenderer::ffmpegLocationChanged(const QString &s)
     cfg.setCustomFFMpegPath(s);
 }
 
+void DlgAnimationRenderer::updateExportUIOptions() {
+
+    KisConfig cfg;
+
+    // read in what type to export to. Defaults to image sequence only
+    QString exportType = cfg.readEntry<QString>("AnimationRenderer/export_type", "ImageSequence");
+    if (exportType == "ImageSequence") {
+        m_page->shouldExportOnlyImageSequence->setChecked(true);
+    } else if (exportType == "Video") {
+        m_page->shouldExportOnlyVideo->setChecked(true);
+    } else {
+        m_page->shouldExportAll->setChecked(true); // export to both
+    }
+}
+
 void DlgAnimationRenderer::slotButtonClicked(int button)
 {
-    if (button == KoDialog::Ok && m_page->grpRender->isChecked()) {
+    if (button == KoDialog::Ok && !m_page->shouldExportOnlyImageSequence->isChecked()) {
         QString ffmpeg = m_page->ffmpegLocation->fileName();
         if (m_page->videoFilename->fileName().isEmpty()) {
             QMessageBox::warning(this, i18nc("@title:window", "Krita"), i18n("Please enter a file name to render to."));
@@ -427,7 +505,9 @@ QString DlgAnimationRenderer::findFFMpeg()
 
         QProcess testProcess;
         testProcess.start(path, QStringList() << "-version");
-        testProcess.waitForFinished(1000);
+        if (testProcess.waitForStarted(1000)) {
+            testProcess.waitForFinished(1000);
+        }
 
         const bool successfulStart =
             testProcess.state() == QProcess::NotRunning &&
@@ -442,3 +522,88 @@ QString DlgAnimationRenderer::findFFMpeg()
     return result;
 }
 
+void DlgAnimationRenderer::slotExportTypeChanged()
+{
+    KisConfig cfg;
+
+    bool willEncodeVideo =
+        m_page->shouldExportAll->isChecked() || m_page->shouldExportOnlyVideo->isChecked();
+
+    // if a video format needs to be outputted
+    if (willEncodeVideo) {
+         // videos always uses PNG for creating video, so disable the ability to change the format
+         m_page->cmbMimetype->setEnabled(false);
+         for (int i = 0; i < m_page->cmbMimetype->count(); ++i) {
+             if (m_page->cmbMimetype->itemData(i).toString() == "image/png") {
+                 m_page->cmbMimetype->setCurrentIndex(i);
+                 break;
+             }
+         }
+    }
+
+    m_page->intWidth->setVisible(willEncodeVideo);
+    m_page->intHeight->setVisible(willEncodeVideo);
+    m_page->intFramesPerSecond->setVisible(willEncodeVideo);
+    m_page->fpsLabel->setVisible(willEncodeVideo);
+    m_page->lblWidth->setVisible(willEncodeVideo);
+    m_page->lblHeight->setVisible(willEncodeVideo);
+
+    // if only exporting video
+    if (m_page->shouldExportOnlyVideo->isChecked()) {
+        m_page->cmbMimetype->setEnabled(false); // allow to change image format
+        m_page->imageSequenceOptionsGroup->setVisible(false);
+        m_page->videoOptionsGroup->setVisible(false); //shrinks the horizontal space temporarily to help resize() work
+        m_page->videoOptionsGroup->setVisible(true);
+
+        cfg.writeEntry<QString>("AnimationRenderer/export_type", "Video");
+    }
+
+
+    // if only an image sequence needs to be output
+    if (m_page->shouldExportOnlyImageSequence->isChecked()) {
+        m_page->cmbMimetype->setEnabled(true); // allow to change image format
+        m_page->videoOptionsGroup->setVisible(false);
+        m_page->imageSequenceOptionsGroup->setVisible(false);
+        m_page->imageSequenceOptionsGroup->setVisible(true);
+
+        cfg.writeEntry<QString>("AnimationRenderer/export_type", "ImageSequence");
+    }
+
+    // show all options
+     if (m_page->shouldExportAll->isChecked() ) {
+         m_page->imageSequenceOptionsGroup->setVisible(true);
+         m_page->videoOptionsGroup->setVisible(true);
+
+         cfg.writeEntry<QString>("AnimationRenderer/export_type", "VideoAndImageSequence");
+     }
+
+
+     // for the resize to work as expected, try to hide elements first before displaying other ones.
+     // if the widget gets bigger at any point, the resize will use that, even if elements are hidden later to make it smaller
+     resize(m_page->sizeHint());
+}
+
+void DlgAnimationRenderer::slotLockAspectRatioDimensionsWidth(int width)
+{
+    Q_UNUSED(width);
+
+    float aspectRatio = (float)m_image->width() / (float)m_image->height();
+
+    // update height here
+    float newHeight = m_page->intWidth->value() / aspectRatio  ;
+
+    m_page->intHeight->setValue(newHeight);
+
+}
+
+void DlgAnimationRenderer::slotLockAspectRatioDimensionsHeight(int height)
+{
+    Q_UNUSED(height);
+
+    float aspectRatio = (float)m_image->width() / (float)m_image->height();
+
+    // update width here
+     float newWidth = aspectRatio *  m_page->intHeight->value();
+
+     m_page->intWidth->setValue(newWidth);
+}
