@@ -58,8 +58,6 @@ public:
 
     KisPropertiesConfigurationSP getFrameExportConfiguration() const;
 
-    bool renderToVideo() const;
-
     KisPropertiesConfigurationSP getVideoConfiguration() const;
     void setVideoConfiguration(KisPropertiesConfigurationSP cfg);
 
@@ -68,18 +66,30 @@ public:
 
     QSharedPointer<KisImportExportFilter> encoderFilter() const;
 
+    // fires when the render animation action is called. makes sure the correct export type is selected for the UI
+    void updateExportUIOptions();
+
 private Q_SLOTS:
 
     void selectRenderType(int i);
     void selectRenderOptions();
-    void toggleSequenceType(bool toggle);
     void sequenceMimeTypeSelected();
     void ffmpegLocationChanged(const QString&);
 
+    void slotLockAspectRatioDimensionsWidth(int width);
+    void slotLockAspectRatioDimensionsHeight(int height);
+
+    void slotExportTypeChanged();
+
+
 protected Q_SLOTS:
 
     void slotButtonClicked(int button) override;
 
+private:
+    QString fetchRenderingDirectory() const;
+    QString fetchRenderingFileName() const;
+
 private:
 
     static QString findFFMpeg();
