@@ -80,7 +80,7 @@ QVector<VirtualChannelInfo> getVirtualChannels(const KoColorSpace *cs)
     return vchannels;
 }
 
-KisPerChannelConfigWidget::KisPerChannelConfigWidget(QWidget * parent, KisPaintDeviceSP dev, Qt::WFlags f)
+KisPerChannelConfigWidget::KisPerChannelConfigWidget(QWidget * parent, KisPaintDeviceSP dev, Qt::WindowFlags f)
         : KisConfigWidget(parent, f), m_histogram(0)
 {
     Q_ASSERT(dev);
@@ -110,6 +110,8 @@ KisPerChannelConfigWidget::KisPerChannelConfigWidget(QWidget * parent, KisPaintD
     }
 
     connect(m_page->cmbChannel, SIGNAL(activated(int)), this, SLOT(setActiveChannel(int)));
+    connect((QObject*)(m_page->chkLogarithmic), SIGNAL(toggled(bool)), this, SLOT(logHistView()));
+    connect((QObject*)(m_page->resetButton), SIGNAL(clicked()), this, SLOT(resetCurve()));
 
     // create the horizontal and vertical gradient labels
     m_page->hgradient->setPixmap(createGradient(Qt::Horizontal));
@@ -172,6 +174,14 @@ inline QPixmap KisPerChannelConfigWidget::getHistogram()
     int height = 256;
     QPixmap pix(256, height);
 
+    bool logarithmic = m_page->chkLogarithmic->isChecked();
+
+    if (logarithmic)
+        m_histogram->setHistogramType(LOGARITHMIC);
+    else
+        m_histogram->setHistogramType(LINEAR);
+
+
     QPalette appPalette = QApplication::palette();
 
     pix.fill(QColor(appPalette.color(QPalette::Base)));
@@ -183,11 +193,13 @@ inline QPixmap KisPerChannelConfigWidget::getHistogram()
 
     const VirtualChannelInfo &info = m_virtualChannels[m_activeVChannel];
 
+
     if (m_histogram && info.type() == VirtualChannelInfo::REAL)
     {
         m_histogram->setChannel(info.pixelIndex());
 
         double highest = (double)m_histogram->calculations().getHighest();
+
         qint32 bins = m_histogram->producer()->numberOfBins();
 
         if (m_histogram->getHistogramType() == LINEAR) {
@@ -404,6 +416,24 @@ void KisPerChannelFilterConfiguration::fromXML(const QDomElement& root)
         e = e.nextSiblingElement();
     }
 
+    //prepend empty curves for the brightness contrast filter.
+    if(getString("legacy") == "brightnesscontrast") {
+        if (getString("colorModel") == LABAColorModelID.id()) {
+            curves.append(KisCubicCurve());
+            curves.append(KisCubicCurve());
+            curves.append(KisCubicCurve());
+        } else {
+            int extraChannels = 5;
+            if (getString("colorModel") == CMYKAColorModelID.id()) {
+                extraChannels = 6;
+            } else if (getString("colorModel") == GrayAColorModelID.id()) {
+                extraChannels = 0;
+            }
+            for(int c = 0; c < extraChannels; c ++) {
+                curves.insert(0, KisCubicCurve());
+            }
+        }
+    }
     if (!numTransfers)
         return;
 
@@ -475,7 +505,7 @@ KisConfigWidget * KisPerChannelFilter::createConfigurationWidget(QWidget *parent
     return new KisPerChannelConfigWidget(parent, dev);
 }
 
-KisFilterConfigurationSP  KisPerChannelFilter::factoryConfiguration(const KisPaintDeviceSP) const
+KisFilterConfigurationSP  KisPerChannelFilter::factoryConfiguration() const
 {
     return new KisPerChannelFilterConfiguration(0);
 }
@@ -596,3 +626,13 @@ bool KisPerChannelFilter::needsTransparentPixels(const KisFilterConfigurationSP
     Q_UNUSED(config);
     return cs->colorModelId() == AlphaColorModelID;
 }
+
+void KisPerChannelConfigWidget::logHistView()
+{
+    m_page->curveWidget->setPixmap(getHistogram());
+}
+
+void KisPerChannelConfigWidget::resetCurve()
+{
+        m_page->curveWidget->reset();
+}
