@@ -57,7 +57,7 @@ CSVLoader::~CSVLoader()
 {
 }
 
-KisImageBuilder_Result CSVLoader::decode(const QString &filename)
+KisImageBuilder_Result CSVLoader::decode(QIODevice *io, const QString &filename)
 {
     QString     field;
     int         idx;
@@ -79,17 +79,9 @@ KisImageBuilder_Result CSVLoader::decode(const QString &filename)
 
     QVector<CSVLayerRecord*> layers;
 
-    // open the csv file
-    QFile f(filename);
-    if (!f.exists())
-        return KisImageBuilder_RESULT_NOT_EXIST;
-
-    if (!f.open(QIODevice::ReadOnly))
-        return KisImageBuilder_RESULT_NOT_EXIST;
-
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-    idx= filename.lastIndexOf(QRegExp("[\\/]"));
+    idx = filename.lastIndexOf(QRegExp("[\\/]"));
     QString base = (idx == -1) ? QString() : filename.left(idx + 1); //include separator
     QString path = filename;
 
@@ -101,34 +93,37 @@ KisImageBuilder_Result CSVLoader::decode(const QString &filename)
 
     KisImageBuilder_Result retval = KisImageBuilder_RESULT_OK;
 
-    dbgFile << "pos:" << f.pos();
+    dbgFile << "pos:" << io->pos();
 
     CSVReadLine readLine;
     QScopedPointer<KisDocument> importDoc(KisPart::instance()->createDocument());
-    importDoc->setAutoSave(0);
+    importDoc->setAutoSaveDelay(0);
     importDoc->setFileBatchMode(true);
 
-    KisView* setView(0);
+    KisView *setView(0);
 
     if (!m_batchMode) {
-        //show the statusbar message even if no view
-        Q_FOREACH (KisView* view, KisPart::instance()->views()) {
-            if (view && view->document() == m_doc) {
-                setView= view;
-                break;
-            }
-        }
+        // TODO: use other systems of progress reporting (KisViewManager::createUnthreadedUpdater()
 
-        if (!setView) {
-            QStatusBar *sb = KisPart::instance()->currentMainwindow()->statusBar();
-            if (sb) {
-                sb->showMessage(i18n("Loading CSV file..."));
-            }
-        } else {
-            emit m_doc->statusBarMessage(i18n("Loading CSV file..."));
-        }
-        emit m_doc->sigProgress(0);
-        connect(m_doc, SIGNAL(sigProgressCanceled()), this, SLOT(cancel()));
+//        //show the statusbar message even if no view
+//        Q_FOREACH (KisView* view, KisPart::instance()->views()) {
+//            if (view && view->document() == m_doc) {
+//                setView = view;
+//                break;
+//            }
+//        }
+
+//        if (!setView) {
+//            QStatusBar *sb = KisPart::instance()->currentMainwindow()->statusBar();
+//            if (sb) {
+//                sb->showMessage(i18n("Loading CSV file..."));
+//            }
+//        } else {
+//            emit m_doc->statusBarMessage(i18n("Loading CSV file..."));
+//        }
+
+//        emit m_doc->sigProgress(0);
+//        connect(m_doc, SIGNAL(sigProgressCanceled()), this, SLOT(cancel()));
     }
     int step = 0;
 
@@ -140,7 +135,7 @@ KisImageBuilder_Result CSVLoader::decode(const QString &filename)
             break;
         }
 
-        if ((idx = readLine.nextLine(&f)) <= 0) {
+        if ((idx = readLine.nextLine(io)) <= 0) {
             if ((idx < 0) ||(step < 5))
                 retval = KisImageBuilder_RESULT_FAILURE;
 
@@ -282,8 +277,8 @@ KisImageBuilder_Result CSVLoader::decode(const QString &filename)
 
                 if (layer->last != field) {
                     if (!m_batchMode) {
-                        emit m_doc->sigProgress((frame * layers.size() + idx) * 100 /
-                                                (frameCount * layers.size()));
+                        //emit m_doc->sigProgress((frame * layers.size() + idx) * 100 /
+                        //                        (frameCount * layers.size()));
                     }
                     retval = setLayer(layer, importDoc.data(), path);
                     layer->last = field;
@@ -333,11 +328,11 @@ KisImageBuilder_Result CSVLoader::decode(const QString &filename)
         m_image->unlock();
     }
     qDeleteAll(layers);
-    f.close();
+    io->close();
 
     if (!m_batchMode) {
-        disconnect(m_doc, SIGNAL(sigProgressCanceled()), this, SLOT(cancel()));
-        emit m_doc->sigProgress(100);
+        // disconnect(m_doc, SIGNAL(sigProgressCanceled()), this, SLOT(cancel()));
+        // emit m_doc->sigProgress(100);
 
         if (!setView) {
             QStatusBar *sb = KisPart::instance()->currentMainwindow()->statusBar();
@@ -366,7 +361,7 @@ QString CSVLoader::convertBlending(const QString &blending)
     if (blending == "Multiply") return COMPOSITE_MULT;
     if (blending == "Screen") return COMPOSITE_SCREEN;
     // "Replace"
-    // "Subtitute"
+    // "Substitute"
     if (blending == "Difference") return COMPOSITE_DIFF;
     if (blending == "Divide") return COMPOSITE_DIVIDE;
     if (blending == "Overlay") return COMPOSITE_OVERLAY;
@@ -449,7 +444,7 @@ KisImageBuilder_Result CSVLoader::setLayer(CSVLayerRecord* layer, KisDocument *i
         filename.append(layer->last);
 
         result = importDoc->openUrl(QUrl::fromLocalFile(filename),
-                                    KisDocument::OPEN_URL_FLAG_DO_NOT_ADD_TO_RECENT_FILES);
+                                    KisDocument::DontAddToRecent);
         if (result)
             layer->channel->importFrame(layer->frame, importDoc->image()->projection(), 0);
 
@@ -478,12 +473,12 @@ KisImageBuilder_Result CSVLoader::createNewImage(int width, int height, float ra
     return KisImageBuilder_RESULT_OK;
 }
 
-KisImageBuilder_Result CSVLoader::buildAnimation(QString &filename)
+KisImageBuilder_Result CSVLoader::buildAnimation(QIODevice *io, const QString &filename)
 {
-    return decode(filename);
+    return decode(io, filename);
 }
 
-KisImageWSP CSVLoader::image()
+KisImageSP CSVLoader::image()
 {
     return m_image;
 }
