@@ -28,12 +28,12 @@
 #include <KisImageBuilderResult.h>
 class KisDocument;
 
-class exrConverter : public QObject
+class EXRConverter : public QObject
 {
     Q_OBJECT
 public:
-    exrConverter(KisDocument *doc, bool showNotifications);
-    ~exrConverter() override;
+    EXRConverter(KisDocument *doc, bool showNotifications);
+    ~EXRConverter() override;
 public:
     KisImageBuilder_Result buildImage(const QString &filename);
     KisImageBuilder_Result buildFile(const QString &filename, KisPaintLayerSP layer);
@@ -42,13 +42,15 @@ public:
      * Retrieve the constructed image
      */
     KisImageSP image();
+    QString errorMessage() const;
 private:
     KisImageBuilder_Result decode(const QString &filename);
+
 public Q_SLOTS:
     virtual void cancel();
 private:
     struct Private;
-    const QScopedPointer<Private> m_d;
+    const QScopedPointer<Private> d;
 };
 
 #endif
