@@ -186,12 +186,12 @@ void KisWdgOptionsPNG::setConfiguration(const KisPropertiesConfigurationSP cfg)
 
     tryToSaveAsIndexed->setVisible(!isThereAlpha);
 
-    const bool sRGB = cfg->getBool(KisImportExportFilter::sRGBTag, false);
+    //const bool sRGB = cfg->getBool(KisImportExportFilter::sRGBTag, false);
 
-    chkSRGB->setEnabled(sRGB);
+    //chkSRGB->setEnabled(sRGB);
     chkSRGB->setChecked(cfg->getBool("saveSRGBProfile", true));
 
-    chkForceSRGB->setEnabled(!sRGB);
+    //chkForceSRGB->setEnabled(!sRGB);
     chkForceSRGB->setChecked(cfg->getBool("forceSRGB", false));
 
     chkAuthor->setChecked(cfg->getBool("storeAuthor", false));
