@@ -109,8 +109,9 @@ class KisSpriterExport : public KisImportExportFilter
 public:
     KisSpriterExport(QObject *parent, const QVariantList &);
     ~KisSpriterExport() override;
-public:
-    KisImportExportFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration = 0) override;
+    bool supportsIO() const override { return false; }
+    KisImportExportFilter::ConversionStatus convert(KisDocument *document, QIODevice *io,  KisPropertiesConfigurationSP configuration = 0) override;
+    void initializeCapabilities() override;
 private:
 
     bool savePaintDevice(KisPaintDeviceSP dev, const QString &fileName);
