@@ -22,13 +22,12 @@
 #include <QCheckBox>
 #include <QSlider>
 
-#include <KoDialog.h>
 #include <kpluginfactory.h>
 #include <QFileInfo>
 #include <QApplication>
-
-#include <KisFilterChain.h>
-
+#include <KoColorModelStandardIds.h>
+#include <KisExportCheckRegistry.h>
+#include <KisImportExportManager.h>
 #include <kis_paint_device.h>
 #include <KisDocument.h>
 #include <kis_image.h>
@@ -46,28 +45,13 @@ KisTGAExport::~KisTGAExport()
 {
 }
 
-KisImportExportFilter::ConversionStatus KisTGAExport::convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration)
+KisImportExportFilter::ConversionStatus KisTGAExport::convert(KisDocument *document, QIODevice *io,  KisPropertiesConfigurationSP configuration)
 {
     Q_UNUSED(configuration);
-    dbgFile << "TGA export! From:" << from << ", To:" << to << "";
+    QRect rc = document->savingImage()->bounds();
+    QImage image = document->savingImage()->projection()->convertToQImage(0, 0, 0, rc.width(), rc.height(), KoColorConversionTransformation::internalRenderingIntent(), KoColorConversionTransformation::internalConversionFlags());
 
-    KisDocument *input = inputDocument();
-    QString filename = outputFile();
-
-    if (!input)
-        return KisImportExportFilter::NoDocumentCreated;
-
-    if (filename.isEmpty()) return KisImportExportFilter::FileNotFound;
-
-    if (from != "application/x-krita")
-        return KisImportExportFilter::NotImplemented;
-
-    QRect rc = input->savingImage()->bounds();
-    QImage image = input->savingImage()->projection()->convertToQImage(0, 0, 0, rc.width(), rc.height(), KoColorConversionTransformation::internalRenderingIntent(), KoColorConversionTransformation::internalConversionFlags());
-
-    QFile f(filename);
-    f.open(QIODevice::WriteOnly);
-    QDataStream s(&f);
+    QDataStream s(io);
     s.setByteOrder(QDataStream::LittleEndian);
 
     const QImage& img = image;
@@ -95,5 +79,16 @@ KisImportExportFilter::ConversionStatus KisTGAExport::convert(const QByteArray&
     return KisImportExportFilter::OK;
 }
 
+void KisTGAExport::initializeCapabilities()
+{
+
+    QList<QPair<KoID, KoID> > supportedColorModels;
+    supportedColorModels << QPair<KoID, KoID>()
+            << QPair<KoID, KoID>(RGBAColorModelID, Integer8BitsColorDepthID);
+    addSupportedColorModels(supportedColorModels, "TGA");
+}
+
+
+
 #include "kis_tga_export.moc"
 
