@@ -25,13 +25,12 @@
 #include <kpluginfactory.h>
 #include <QFileInfo>
 
-#include <KoDialog.h>
-#include <KisFilterChain.h>
+#include <KoColorSpaceRegistry.h>
 #include <KoColorSpace.h>
 #include <KoChannelInfo.h>
 #include <KoColorModelStandardIds.h>
 #include <KisImportExportManager.h>
-
+#include <KisExportCheckRegistry.h>
 #include <KisDocument.h>
 #include <kis_group_layer.h>
 #include <kis_image.h>
@@ -53,49 +52,23 @@ KisTIFFExport::~KisTIFFExport()
 {
 }
 
-KisImportExportFilter::ConversionStatus KisTIFFExport::convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration)
+KisImportExportFilter::ConversionStatus KisTIFFExport::convert(KisDocument *document, QIODevice */*io*/,  KisPropertiesConfigurationSP configuration)
 {
-    dbgFile << "Tiff export! From:" << from << ", To:" << to << "";
-
-    if (from != "application/x-krita")
-        return KisImportExportFilter::NotImplemented;
-
-    KisDocument *input = inputDocument();
-    if (!input) {
-        return KisImportExportFilter::NoDocumentCreated;
-    }
-
-    KoDialog kdb;
-    kdb.setWindowTitle(i18n("TIFF Export Options"));
-    kdb.setButtons(KoDialog::Ok | KoDialog::Cancel);
-    KisTIFFOptionsWidget *wdg = static_cast<KisTIFFOptionsWidget*>(createConfigurationWidget(&kdb, from, to));
-    kdb.setMainWidget(wdg);
-    kdb.resize(kdb.minimumSize());
-
     // If a configuration object was passed to the convert method, we use that, otherwise we load from the settings
     KisPropertiesConfigurationSP cfg(new KisPropertiesConfiguration());
     if (configuration) {
         cfg->fromXML(configuration->toXML());
     }
     else {
-        cfg = lastSavedConfiguration(from, to);
+        cfg = lastSavedConfiguration(KisDocument::nativeFormatMimeType(), "image/tiff");
     }
 
-    const KoColorSpace* cs = input->image()->colorSpace();
+    const KoColorSpace* cs = document->savingImage()->colorSpace();
     cfg->setProperty("type", (int)cs->channels()[0]->channelValueType());
     cfg->setProperty("isCMYK", (cs->colorModelId() == CMYKAColorModelID));
 
-    wdg->setConfiguration(cfg);
-
-    if (!getBatchMode()) {
-        if (kdb.exec() == QDialog::Rejected) {
-            return KisImportExportFilter::UserCancelled;
-        }
-        cfg = wdg->configuration();
-        KisConfig().setExportConfiguration("TIFF", *cfg.data());
-    }
-
-    KisTIFFOptions options = wdg->options();
+    KisTIFFOptions options;
+    options.fromProperties(configuration);
 
     if ((cs->channels()[0]->channelValueType() == KoChannelInfo::FLOAT16
          || cs->channels()[0]->channelValueType() == KoChannelInfo::FLOAT32) && options.predictor == 2) {
@@ -103,30 +76,21 @@ KisImportExportFilter::ConversionStatus KisTIFFExport::convert(const QByteArray&
         options.predictor = 3;
     }
 
-    QString filename = outputFile();
-
-    if (filename.isEmpty()) {
-        return KisImportExportFilter::FileNotFound;
-    }
-
     KisImageSP image;
 
     if (options.flatten) {
-        image = new KisImage(0, input->image()->width(), input->image()->height(), input->image()->colorSpace(), "");
-        image->setResolution(input->image()->xRes(), input->image()->yRes());
-        KisPaintDeviceSP pd = KisPaintDeviceSP(new KisPaintDevice(*input->image()->projection()));
+        image = new KisImage(0, document->savingImage()->width(), document->savingImage()->height(), document->savingImage()->colorSpace(), "");
+        image->setResolution(document->savingImage()->xRes(), document->savingImage()->yRes());
+        KisPaintDeviceSP pd = KisPaintDeviceSP(new KisPaintDevice(*document->savingImage()->projection()));
         KisPaintLayerSP l = KisPaintLayerSP(new KisPaintLayer(image.data(), "projection", OPACITY_OPAQUE_U8, pd));
         image->addNode(KisNodeSP(l.data()), image->rootLayer().data());
     } else {
-        image = input->image();
+        image = document->savingImage();
     }
 
-    // the image must be locked at the higher levels
-    KIS_SAFE_ASSERT_RECOVER_NOOP(input->image()->locked());
-
-    KisTIFFConverter ktc(input);
+    KisTIFFConverter tiffConverter(document);
     KisImageBuilder_Result res;
-    if ((res = ktc.buildFile(filename, image, options)) == KisImageBuilder_RESULT_OK) {
+    if ((res = tiffConverter.buildFile(filename(), image, options)) == KisImageBuilder_RESULT_OK) {
         dbgFile << "success !";
         return KisImportExportFilter::OK;
     }
@@ -137,26 +101,8 @@ KisImportExportFilter::ConversionStatus KisTIFFExport::convert(const QByteArray&
 
 KisPropertiesConfigurationSP KisTIFFExport::defaultConfiguration(const QByteArray &/*from*/, const QByteArray &/*to*/) const
 {
-    KisPropertiesConfigurationSP cfg = new KisPropertiesConfiguration();
-    cfg->setProperty("compressiontype", 0);
-    cfg->setProperty("predictor", 0);
-    cfg->setProperty("alpha", true);
-    cfg->setProperty("flatten", true);
-    cfg->setProperty("quality", 80);
-    cfg->setProperty("deflate", 6);
-    cfg->setProperty("faxmode", 0);
-    cfg->setProperty("pixarlog", 6);
-    cfg->setProperty("saveProfile", true);
-
-    return cfg;
-}
-
-KisPropertiesConfigurationSP KisTIFFExport::lastSavedConfiguration(const QByteArray &from, const QByteArray &to) const
-{
-    QString filterConfig = KisConfig().exportConfiguration("TIFF");
-    KisPropertiesConfigurationSP cfg = defaultConfiguration(from, to);
-    cfg->fromXML(filterConfig, false);
-    return cfg;
+    KisTIFFOptions options;
+    return options.toProperties();
 }
 
 KisConfigWidget *KisTIFFExport::createConfigurationWidget(QWidget *parent, const QByteArray &/*from*/, const QByteArray &/*to*/) const
@@ -164,5 +110,26 @@ KisConfigWidget *KisTIFFExport::createConfigurationWidget(QWidget *parent, const
     return new KisTIFFOptionsWidget(parent);
 }
 
+void KisTIFFExport::initializeCapabilities()
+{
+    addCapability(KisExportCheckRegistry::instance()->get("NodeTypeCheck/KisGroupLayer")->create(KisExportCheckBase::UNSUPPORTED));
+    addCapability(KisExportCheckRegistry::instance()->get("MultiLayerCheck")->create(KisExportCheckBase::SUPPORTED));
+    addCapability(KisExportCheckRegistry::instance()->get("sRGBProfileCheck")->create(KisExportCheckBase::SUPPORTED));
+
+    QList<QPair<KoID, KoID> > supportedColorModels;
+    supportedColorModels << QPair<KoID, KoID>()
+            << QPair<KoID, KoID>(RGBAColorModelID, Integer8BitsColorDepthID)
+            << QPair<KoID, KoID>(RGBAColorModelID, Integer16BitsColorDepthID)
+            << QPair<KoID, KoID>(RGBAColorModelID, Float16BitsColorDepthID)
+            << QPair<KoID, KoID>(RGBAColorModelID, Float32BitsColorDepthID)
+            << QPair<KoID, KoID>(GrayAColorModelID, Integer8BitsColorDepthID)
+            << QPair<KoID, KoID>(GrayAColorModelID, Integer16BitsColorDepthID)
+            << QPair<KoID, KoID>(CMYKAColorModelID, Integer8BitsColorDepthID)
+            << QPair<KoID, KoID>(CMYKAColorModelID, Integer16BitsColorDepthID)
+            << QPair<KoID, KoID>(LABAColorModelID, Integer16BitsColorDepthID);
+    addSupportedColorModels(supportedColorModels, "TIFF");
+
+}
+
 #include <kis_tiff_export.moc>
 
