@@ -38,8 +38,12 @@ public:
     ~KisExperimentPaintOp() override;
 
     void paintLine(const KisPaintInformation& pi1, const KisPaintInformation& pi2, KisDistanceInformation *currentDistance) override;
+
+protected:
     KisSpacingInformation paintAt(const KisPaintInformation& info) override;
 
+    KisSpacingInformation updateSpacingImpl(const KisPaintInformation &info) const override;
+
 private:
     void paintRegion(const QRegion &changedRegion);
     QPointF speedCorrectedPosition(const KisPaintInformation& pi1,
@@ -47,7 +51,6 @@ private:
 
 
     static qreal simplifyThreshold(const QRectF &bounds);
-    static QPainterPath trySimplifyPath(const QPainterPath &path, qreal lengthThreshold);
     static QPointF getAngle(const QPointF& p1, const QPointF& p2, qreal distance);
     static QPainterPath applyDisplace(const QPainterPath& path, int speed);
 
