@@ -28,6 +28,7 @@
 #include "hatching_brush.h"
 #include "kis_hatching_paintop_settings.h"
 
+#include <kis_hatching_pressure_angle_option.h>
 #include <kis_hatching_pressure_crosshatching_option.h>
 #include <kis_hatching_pressure_separation_option.h>
 #include <kis_hatching_pressure_thickness_option.h>
@@ -46,12 +47,6 @@ public:
     KisHatchingPaintOp(const KisPaintOpSettingsSP settings, KisPainter * painter, KisNodeSP node, KisImageSP image);
     ~KisHatchingPaintOp() override;
 
-    /**
-     *  Paint a hatched dab around the mouse cursor according to
-     *  sensor settings and user preferences.
-     */
-    KisSpacingInformation paintAt(const KisPaintInformation& info) override;
-
     /**
      *  Returns a number between -90 and 90, and corresponds to the
      *  angle that results from adding angle 'spin' to 'm_settings->angle',
@@ -59,6 +54,15 @@ public:
      */
     double spinAngle(double spin);
 
+protected:
+    /**
+     *  Paint a hatched dab around the mouse cursor according to
+     *  sensor settings and user preferences.
+     */
+    KisSpacingInformation paintAt(const KisPaintInformation& info) override;
+
+    KisSpacingInformation updateSpacingImpl(const KisPaintInformation &info) const override;
+
 private:
     KisHatchingPaintOpSettingsSP m_settings;
     KisImageWSP m_image;
@@ -70,6 +74,12 @@ private:
      */
     KisPaintDeviceSP m_hatchedDab;
 
+    /**
+     *  Curve to control the hatching angle
+     *  according to user preferences set in the GUI
+     */
+    KisHatchingPressureAngleOption m_angleOption;
+
     /**
      *  Curve to control the intensity of crosshatching
      *  according to user preferences set in the GUI
