@@ -33,10 +33,8 @@ class PAINTOP_EXPORT KisBrushOption : public KisBaseOption
 {
 public:
 
-    void writeOptionSettingImpl(KisPropertiesConfiguration *setting) const;
-    void readOptionSettingImpl(const KisPropertiesConfiguration *setting);
-    void readOptionSettingForceCopy(KisPropertiesConfigurationSP setting);
-    void readOptionSettingForceCopy(const KisPropertiesConfiguration *setting);
+    void writeOptionSettingImpl(KisPropertiesConfiguration *setting) const override;
+    void readOptionSettingImpl(const KisPropertiesConfiguration *setting) override;
 
     KisBrushSP brush() const;
     void setBrush(KisBrushSP brush);
@@ -45,9 +43,6 @@ public:
     static bool isTextBrush(const KisPropertiesConfiguration *setting);
 #endif /* HAVE_THREADED_TEXT_RENDERING_WORKAROUND */
 
-private:
-    void readOptionSettingInternal(const KisPropertiesConfiguration *setting, bool forceCopy);
-
 private:
     KisBrushSP m_brush;
 };
