@@ -37,21 +37,16 @@ KisParticlePaintOpSettings::~KisParticlePaintOpSettings()
 {
 }
 
+bool KisParticlePaintOpSettings::lodSizeThresholdSupported() const
+{
+    return false;
+}
+
 bool KisParticlePaintOpSettings::paintIncremental()
 {
     return (enumPaintActionType)getInt("PaintOpAction", WASH) == BUILDUP;
 }
 
-bool KisParticlePaintOpSettings::isAirbrushing() const
-{
-    return getBool(AIRBRUSH_ENABLED);
-}
-
-int KisParticlePaintOpSettings::rate() const
-{
-    return getInt(AIRBRUSH_RATE);
-}
-
 
 #include <brushengine/kis_slider_based_paintop_property.h>
 #include "kis_paintop_preset.h"
