@@ -59,7 +59,7 @@ void KisToolRectangle::resetCursorStyle()
 
 void KisToolRectangle::finishRect(const QRectF &rect)
 {
-    if (rect.isNull() || !blockUntillOperationsFinished())
+    if (rect.isNull() || !blockUntilOperationsFinished())
         return;
 
     if (image()) {
@@ -79,7 +79,11 @@ void KisToolRectangle::finishRect(const QRectF &rect)
     } else {
         QRectF r = convertToPt(rect);
         KoShape* shape = KisShapeToolHelper::createRectangleShape(r);
-        KoShapeStroke* border = new KoShapeStroke(1.0, currentFgColor().toQColor());
+
+        KoShapeStrokeSP border;
+        if (strokeStyle() == KisPainter::StrokeStyleBrush) {
+            border = toQShared(new KoShapeStroke(currentStrokeWidth(), currentFgColor().toQColor()));
+        }
         shape->setStroke(border);
         addShape(shape);
     }
