@@ -110,30 +110,6 @@ enum BooleanOp {
 
 }
 
-QPolygonF selectionPolygon(KoSelection *selection)
-{
-    QPolygonF result;
-
-    QList<KoShape*> selectedShapes = selection->selectedShapes();
-
-    if (!selectedShapes.size()) {
-        return result;
-    }
-
-    if (selectedShapes.size() > 1) {
-        QTransform matrix = selection->absoluteTransformation(0);
-        result = matrix.map(QPolygonF(QRectF(QPointF(0, 0), selection->size())));
-    } else {
-        KoShape *selectedShape = selectedShapes.first();
-        QTransform matrix = selectedShape->absoluteTransformation(0);
-        result = matrix.map(QPolygonF(QRectF(QPointF(0, 0), selectedShape->size())));
-    }
-
-    return result;
-}
-
-
-
 class NopInteractionStrategy : public KoInteractionStrategy
 {
 public:
@@ -701,12 +677,12 @@ void DefaultTool::paint(QPainter &painter, const KoViewConverter &converter)
     // this tool only works on a vector layer right now, so give a warning if another layer type is trying to use it
     KisNodeSP currentNode = canvas()->resourceManager()->resource(KisCanvasResourceProvider::CurrentKritaNode).value<KisNodeWSP>();
 
-    if (currentNode.isNull() || !currentNode->inherits("KisShapeLayer")) {
+    if (currentNode.isNull() || (!currentNode->inherits("KisShapeLayer") && !currentNode->inherits("KisSelectionMask"))) {
 
         KisCanvas2 * kiscanvas = static_cast<KisCanvas2*>(canvas());
         kiscanvas->viewManager()->showFloatingMessage(
             i18n("This tool only works on vector layers. You probably want the move tool."),
-            QIcon(), 2000, KisFloatingMessage::Medium, Qt::AlignCenter);
+            QIcon(), 500, KisFloatingMessage::Medium, Qt::AlignCenter);
 
         return;
     }
@@ -1033,14 +1009,18 @@ void DefaultTool::selectionGroup()
 
     QList<KoShape *> selectedShapes = selection->selectedEditableShapes();
     std::sort(selectedShapes.begin(), selectedShapes.end(), KoShape::compareShapeZIndex);
+    if (selectedShapes.isEmpty()) return;
+
+    const int groupZIndex = selectedShapes.last()->zIndex();
 
     KoShapeGroup *group = new KoShapeGroup();
+    group->setZIndex(groupZIndex);
     // TODO what if only one shape is left?
     KUndo2Command *cmd = new KUndo2Command(kundo2_i18n("Group shapes"));
-    new KoKeepShapesSelectedCommand(selectedShapes, {}, selection, false, cmd);
+    new KoKeepShapesSelectedCommand(selectedShapes, {}, canvas()->selectedShapesProxy(), false, cmd);
     canvas()->shapeController()->addShapeDirect(group, 0, cmd);
-    new KoShapeGroupCommand(group, selectedShapes, false, true, true, cmd);
-    new KoKeepShapesSelectedCommand({}, {group}, selection, true, cmd);
+    new KoShapeGroupCommand(group, selectedShapes, true, cmd);
+    new KoKeepShapesSelectedCommand({}, {group}, canvas()->selectedShapesProxy(), true, cmd);
     canvas()->addCommand(cmd);
 
     // update selection so we can ungroup immediately again
@@ -1065,7 +1045,7 @@ void DefaultTool::selectionUngroup()
         if (group) {
             if (!cmd) {
                 cmd = new KUndo2Command(kundo2_i18n("Ungroup shapes"));
-                new KoKeepShapesSelectedCommand(selectedShapes, {}, selection, false, cmd);
+                new KoKeepShapesSelectedCommand(selectedShapes, {}, canvas()->selectedShapesProxy(), false, cmd);
             }
             newShapes << group->shapes();
             new KoShapeUngroupCommand(group, group->shapes(),
@@ -1075,7 +1055,7 @@ void DefaultTool::selectionUngroup()
         }
     }
     if (cmd) {
-        new KoKeepShapesSelectedCommand({}, newShapes, selection, true, cmd);
+        new KoKeepShapesSelectedCommand({}, newShapes, canvas()->selectedShapesProxy(), true, cmd);
         canvas()->addCommand(cmd);
     }
 }
@@ -1219,7 +1199,7 @@ void DefaultTool::selectionBooleanOp(int booleanOp)
 
     KUndo2Command *cmd = new KUndo2Command(actionName);
 
-    new KoKeepShapesSelectedCommand(editableShapes, {}, selection, false, cmd);
+    new KoKeepShapesSelectedCommand(editableShapes, {}, canvas()->selectedShapesProxy(), false, cmd);
 
     QList<KoShape*> newSelectedShapes;
 
@@ -1236,7 +1216,7 @@ void DefaultTool::selectionBooleanOp(int booleanOp)
 
     canvas()->shapeController()->removeShapes(editableShapes, cmd);
 
-    new KoKeepShapesSelectedCommand({}, newSelectedShapes, selection, true, cmd);
+    new KoKeepShapesSelectedCommand({}, newSelectedShapes, canvas()->selectedShapesProxy(), true, cmd);
 
     canvas()->addCommand(cmd);
 }
@@ -1253,7 +1233,7 @@ void DefaultTool::selectionSplitShapes()
 
     KUndo2Command *cmd = new KUndo2Command(kundo2_i18n("Split Shapes"));
 
-    new KoKeepShapesSelectedCommand(editableShapes, {}, selection, false, cmd);
+    new KoKeepShapesSelectedCommand(editableShapes, {}, canvas()->selectedShapesProxy(), false, cmd);
     QList<KoShape*> newShapes;
 
     Q_FOREACH (KoShape *shape, editableShapes) {
@@ -1271,7 +1251,7 @@ void DefaultTool::selectionSplitShapes()
         }
     }
 
-    new KoKeepShapesSelectedCommand({}, newShapes, selection, true, cmd);
+    new KoKeepShapesSelectedCommand({}, newShapes, canvas()->selectedShapesProxy(), true, cmd);
 
     canvas()->addCommand(cmd);
 }
@@ -1463,7 +1443,7 @@ KoInteractionStrategy *DefaultTool::createStrategy(KoPointerEvent *event)
         if (handle != KoFlake::NoHandle) {
             // resizing or shearing only with left mouse button
             if (insideSelection) {
-                return new ShapeResizeStrategy(this, event->point, handle);
+                return new ShapeResizeStrategy(this, event->point, handle, m_tabbedOptionWidget->useUniformScaling());
             }
 
             if (handle == KoFlake::TopMiddleHandle || handle == KoFlake::RightMiddleHandle ||
