@@ -30,9 +30,12 @@
 #include <QPolygonF>
 #include <QTime>
 
+class QSignalMapper;
 class KoInteractionStrategy;
 class KoShapeMoveCommand;
 class KoSelection;
+class DefaultToolTabbedWidget;
+class KisViewManager;
 
 /**
  * The default tool (associated with the arrow icon) implements the default
@@ -74,10 +77,10 @@ public:
     ///reimplemented
     bool paste() override;
     ///reimplemented
-    QStringList supportedPasteMimeTypes() const override;
-    ///reimplemented
     KoToolSelection *selection() override;
 
+    QMenu* popupActionsMenu() override;
+
     /**
      * Returns which selection handle is at params point (or NoHandle if none).
      * @return which selection handle is at params point (or NoHandle if none).
@@ -89,15 +92,12 @@ public:
     KoFlake::SelectionHandle handleAt(const QPointF &point, bool *innerHandleMeaning = 0);
 
 public Q_SLOTS:
-    void activate(ToolActivation toolActivation, const QSet<KoShape *> &shapes) override;
+    void activate(ToolActivation activation, const QSet<KoShape *> &shapes) override;
+    void deactivate() override;
 
 private Q_SLOTS:
-    void selectionAlignHorizontalLeft();
-    void selectionAlignHorizontalCenter();
-    void selectionAlignHorizontalRight();
-    void selectionAlignVerticalTop();
-    void selectionAlignVerticalCenter();
-    void selectionAlignVerticalBottom();
+    void selectionAlign(int _align);
+    void selectionDistribute(int _distribute);
 
     void selectionBringToFront();
     void selectionSendToBack();
@@ -107,6 +107,13 @@ private Q_SLOTS:
     void selectionGroup();
     void selectionUngroup();
 
+    void selectionTransform(int transformAction);
+    void selectionBooleanOp(int booleanOp);
+    void selectionSplitShapes();
+
+    void slotActivateEditFillGradient(bool value);
+    void slotActivateEditStrokeGradient(bool value);
+
     /// Update actions on selection change
     void updateActions();
 
@@ -119,19 +126,24 @@ public: // Events
 
     void keyPressEvent(QKeyEvent *event) override;
 
+    void explicitUserStrokeEndRequest() override;
 protected:
     QList<QPointer<QWidget> > createOptionWidgets() override;
 
     KoInteractionStrategy *createStrategy(KoPointerEvent *event) override;
 
+private:
+    class MoveGradientHandleInteractionFactory;
+
 private:
     void setupActions();
-    void recalcSelectionBox();
+    void recalcSelectionBox(KoSelection *selection);
     void updateCursor();
     /// Returns rotation angle of given handle of the current selection
     qreal rotationOfHandle(KoFlake::SelectionHandle handle, bool useEdgeRotation);
 
-    void selectionAlign(KoShapeAlignCommand::Align align);
+    void addMappedAction(QSignalMapper *mapper, const QString &actionId, int type);
+
     void selectionReorder(KoShapeReorderCommand::MoveShapeType order);
     bool moveSelection(int direction, Qt::KeyboardModifiers modifiers);
 
@@ -143,20 +155,12 @@ private:
 
     void canvasResourceChanged(int key, const QVariant &res) override;
 
-    /// Returns list of editable shapes from the given list of shapes
-    QList<KoShape *> filterEditableShapes(const QList<KoShape *> &shapes);
-
-    /// Returns the number of editable shapes from the given list of shapes
-    uint editableShapesCount(const QList<KoShape *> &shapes);
-
     KoFlake::SelectionHandle m_lastHandle;
-    KoFlake::Position m_hotPosition;
+    KoFlake::AnchorPosition m_hotPosition;
     bool m_mouseWasInsideHandles;
     QPointF m_selectionBox[8];
     QPolygonF m_selectionOutline;
     QPointF m_lastPoint;
-    KoShapeMoveCommand *m_moveCommand;
-    QTime m_lastUsedMoveCommand;
 
     // TODO alter these 3 arrays to be static const instead
     QCursor m_sizeCursors[8];
@@ -165,7 +169,10 @@ private:
     qreal m_angle;
     KoToolSelection *m_selectionHandler;
     friend class SelectionHandler;
-    QPointer<QAction> m_separatorAction;
+    KoInteractionStrategy *m_customEventStrategy;
+    QScopedPointer<QMenu> m_contextMenu;
+
+    DefaultToolTabbedWidget *m_tabbedOptionWidget;
 };
 
 #endif
