@@ -27,8 +27,8 @@
 DefaultToolFactory::DefaultToolFactory()
     : KoToolFactoryBase(KoInteractionTool_ID)
 {
-    setToolTip(i18n("Shape Manipulation Tool"));
-    setToolType(mainToolType());
+    setToolTip(i18n("Select Shapes Tool"));
+    setSection(mainToolType());
     setPriority(0);
     setIconName(koIconNameCStr("select"));
     setActivationShapeId("flake/always");
