@@ -40,6 +40,8 @@ public:
     /// Sets the unit used by the unit aware child widgets
     void setUnit(const KoUnit &unit);
 
+    bool useUniformScaling() const;
+
 protected:
     void showEvent(QShowEvent *event) override;
 
@@ -50,7 +52,8 @@ private Q_SLOTS:
     void slotUpdatePositionBoxes();
     void slotRepositionShapes();
 
-    void slotUpdateSizeBoxes();
+    void slotUpdateSizeBoxes(bool updateAspect = true);
+    void slotUpdateSizeBoxesNoAspectChange();
     void slotResizeShapes();
 
     void slotUpdateCheckboxes();
