@@ -43,7 +43,7 @@ public:
     /**
      * Constructor
      */
-    ShapeResizeStrategy(KoToolBase *tool, const QPointF &clicked, KoFlake::SelectionHandle direction);
+    ShapeResizeStrategy(KoToolBase *tool, const QPointF &clicked, KoFlake::SelectionHandle direction, bool forceUniformScalingMode);
     ~ShapeResizeStrategy() override;
 
     void handleMouseMove(const QPointF &mouseLocation, Qt::KeyboardModifiers modifiers) override;
@@ -64,6 +64,8 @@ private:
     QPointF m_globalStillPoint;
     QPointF m_globalCenterPoint;
     QScopedPointer<KoShapeResizeCommand> m_executedCommand;
+
+    bool m_forceUniformScalingMode = false;
 };
 
 #endif
