@@ -28,8 +28,6 @@
 #include "KisViewManager.h"
 #include "kis_transform_utils.h"
 
-#include "kis_transform_utils.h"
-
 
 template<typename T> inline T sign(T x) {
     return x > 0 ? 1 : x == (T)0 ? 0 : -1;
@@ -64,7 +62,7 @@ KisToolTransformConfigWidget::KisToolTransformConfigWidget(TransformTransactionP
                                 "<ul>"
                                 "<li><b>Bilinear</b> for areas with uniform color to avoid artifacts</li>"
                                 "<li><b>Bicubic</b> for smoother results</li>"
-                                "<li><b>Lanczos3</b> for sharp results. May produce aerials.</il>"
+                                "<li><b>Lanczos3</b> for sharp results. May produce aerials.</li>"
                                 "</ul></p>"));
     connect(cmbFilter, SIGNAL(activated(const KoID &)),
             this, SLOT(slotFilterChanged(const KoID &)));
@@ -847,8 +845,6 @@ void KisToolTransformConfigWidget::slotRotationCenterChanged(int index)
         notifyConfigChanged();
         updateConfig(*config);
     }
-
-
 }
 
 void KisToolTransformConfigWidget::slotTransformAroundRotationCenter(bool value)
@@ -879,7 +875,10 @@ void KisToolTransformConfigWidget::slotSetScaleX(int value)
 
         scaleYBox->blockSignals(true);
         scaleYBox->setValue(calculatedValue);
-        config->setScaleY(calculatedValue / 100.);
+        {
+            KisTransformUtils::AnchorHolder keeper(config->transformAroundRotationCenter(), config);
+            config->setScaleY(calculatedValue / 100.);
+        }
         scaleYBox->blockSignals(false);
 
         unblockNotifications();
@@ -905,7 +904,10 @@ void KisToolTransformConfigWidget::slotSetScaleY(int value)
         int calculatedValue = int(m_scaleRatio * value);
         scaleXBox->blockSignals(true);
         scaleXBox->setValue(calculatedValue);
-        config->setScaleX(calculatedValue / 100.);
+        {
+            KisTransformUtils::AnchorHolder keeper(config->transformAroundRotationCenter(), config);
+            config->setScaleX(calculatedValue / 100.);
+        }
         scaleXBox->blockSignals(false);
         unblockNotifications();
     }
